# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ibc/core/port/v1/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ibc/core/port/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cibc/core/port/v1/query.proto\x12\x10ibc.core.port.v1\x1a!ibc/core/channel/v1/channel.proto\"\xc1\x01\n\x16QueryAppVersionRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x15\n\rconnection_id\x18\x02 \x01(\t\x12,\n\x08ordering\x18\x03 \x01(\x0e\x32\x1a.ibc.core.channel.v1.Order\x12\x37\n\x0c\x63ounterparty\x18\x04 \x01(\x0b\x32!.ibc.core.channel.v1.Counterparty\x12\x18\n\x10proposed_version\x18\x05 \x01(\t\";\n\x17QueryAppVersionResponse\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t2l\n\x05Query\x12\x63\n\nAppVersion\x12(.ibc.core.port.v1.QueryAppVersionRequest\x1a).ibc.core.port.v1.QueryAppVersionResponse\"\x00\x42\x38Z6github.com/cosmos/ibc-go/v2/modules/core/05-port/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.port.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/cosmos/ibc-go/v2/modules/core/05-port/types'
  _globals['_QUERYAPPVERSIONREQUEST']._serialized_start=86
  _globals['_QUERYAPPVERSIONREQUEST']._serialized_end=279
  _globals['_QUERYAPPVERSIONRESPONSE']._serialized_start=281
  _globals['_QUERYAPPVERSIONRESPONSE']._serialized_end=340
  _globals['_QUERY']._serialized_start=342
  _globals['_QUERY']._serialized_end=450
# @@protoc_insertion_point(module_scope)
