# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/sanctum/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/sanctum/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from neurion.sanctum import params_pb2 as neurion_dot_sanctum_dot_params__pb2
from neurion.sanctum import dataset_application_pb2 as neurion_dot_sanctum_dot_dataset__application__pb2
from neurion.sanctum import dataset_usage_request_pb2 as neurion_dot_sanctum_dot_dataset__usage__request__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bneurion/sanctum/query.proto\x12\x0fneurion.sanctum\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cneurion/sanctum/params.proto\x1a)neurion/sanctum/dataset_application.proto\x1a+neurion/sanctum/dataset_usage_request.proto\"\x14\n\x12QueryParamsRequest\"I\n\x13QueryParamsResponse\x12\x32\n\x06params\x18\x01 \x01(\x0b\x32\x17.neurion.sanctum.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"A\n QueryGetAvailableDatasetsRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x04\"\xa2\x01\n!QueryGetAvailableDatasetsResponse\x12@\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32#.neurion.sanctum.DatasetApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"&\n$QueryGetApprovedUsageRequestsRequest\"j\n%QueryGetApprovedUsageRequestsResponse\x12\x41\n\x08requests\x18\x01 \x03(\x0b\x32$.neurion.sanctum.DatasetUsageRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"%\n\x15QueryGetRewardRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"(\n\x16QueryGetRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"$\n\x14QueryGetStakeRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"&\n\x15QueryGetStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\" \n\x1eQueryGetPendingDatasetsRequest\"c\n\x1fQueryGetPendingDatasetsResponse\x12@\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32#.neurion.sanctum.DatasetApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"3\n#QueryGetPendingUsageRequestsRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"i\n$QueryGetPendingUsageRequestsResponse\x12\x41\n\x08requests\x18\x01 \x03(\x0b\x32$.neurion.sanctum.DatasetUsageRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"$\n\x16QueryGetDatasetRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"Z\n\x17QueryGetDatasetResponse\x12?\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32#.neurion.sanctum.DatasetApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\")\n\x1bQueryGetUsageRequestRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"`\n\x1cQueryGetUsageRequestResponse\x12@\n\x07request\x18\x01 \x01(\x0b\x32$.neurion.sanctum.DatasetUsageRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"[\n&QueryGetUsageRequestsForDatasetRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x04\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\xa9\x01\n\'QueryGetUsageRequestsForDatasetResponse\x12\x41\n\x08requests\x18\x01 \x03(\x0b\x32$.neurion.sanctum.DatasetUsageRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"R\n#QueryGetUsageRequestsForUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\xa6\x01\n$QueryGetUsageRequestsForUserResponse\x12\x41\n\x08requests\x18\x01 \x03(\x0b\x32$.neurion.sanctum.DatasetUsageRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"M\n\x1eQueryGetDatasetsForUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\xa0\x01\n\x1fQueryGetDatasetsForUserResponse\x12@\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32#.neurion.sanctum.DatasetApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xa1\x10\n\x05Query\x12t\n\x06Params\x12#.neurion.sanctum.QueryParamsRequest\x1a$.neurion.sanctum.QueryParamsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/neurion/sanctum/params\x12\xae\x01\n\x14GetAvailableDatasets\x12\x31.neurion.sanctum.QueryGetAvailableDatasetsRequest\x1a\x32.neurion.sanctum.QueryGetAvailableDatasetsResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/neurion/sanctum/get_available_datasets\x12\xbf\x01\n\x18GetApprovedUsageRequests\x12\x35.neurion.sanctum.QueryGetApprovedUsageRequestsRequest\x1a\x36.neurion.sanctum.QueryGetApprovedUsageRequestsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/neurion/sanctum/get_approved_usage_requests\x12\x88\x01\n\tGetReward\x12&.neurion.sanctum.QueryGetRewardRequest\x1a\'.neurion.sanctum.QueryGetRewardResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/neurion/sanctum/get_reward/{user}\x12\x84\x01\n\x08GetStake\x12%.neurion.sanctum.QueryGetStakeRequest\x1a&.neurion.sanctum.QueryGetStakeResponse\")\x82\xd3\xe4\x93\x02#\x12!/neurion/sanctum/get_stake/{user}\x12\xa6\x01\n\x12GetPendingDatasets\x12/.neurion.sanctum.QueryGetPendingDatasetsRequest\x1a\x30.neurion.sanctum.QueryGetPendingDatasetsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/neurion/sanctum/get_pending_datasets\x12\xc2\x01\n\x17GetPendingUsageRequests\x12\x34.neurion.sanctum.QueryGetPendingUsageRequestsRequest\x1a\x35.neurion.sanctum.QueryGetPendingUsageRequestsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/sanctum/get_pending_usage_requests/{user}\x12\x8a\x01\n\nGetDataset\x12\'.neurion.sanctum.QueryGetDatasetRequest\x1a(.neurion.sanctum.QueryGetDatasetResponse\")\x82\xd3\xe4\x93\x02#\x12!/neurion/sanctum/get_dataset/{id}\x12\x9f\x01\n\x0fGetUsageRequest\x12,.neurion.sanctum.QueryGetUsageRequestRequest\x1a-.neurion.sanctum.QueryGetUsageRequestResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/neurion/sanctum/get_usage_request/{id}\x12\xe6\x01\n\x1aGetUsageRequestsForDataset\x12\x37.neurion.sanctum.QueryGetUsageRequestsForDatasetRequest\x1a\x38.neurion.sanctum.QueryGetUsageRequestsForDatasetResponse\"U\x82\xd3\xe4\x93\x02O\x12M/neurion/sanctum/get_usage_requests_for_dataset/{dataset_id}/{offset}/{limit}\x12\xd4\x01\n\x17GetUsageRequestsForUser\x12\x34.neurion.sanctum.QueryGetUsageRequestsForUserRequest\x1a\x35.neurion.sanctum.QueryGetUsageRequestsForUserResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/neurion/sanctum/get_usage_requests_for_user/{user}/{offset}/{limit}\x12\xbf\x01\n\x12GetDatasetsForUser\x12/.neurion.sanctum.QueryGetDatasetsForUserRequest\x1a\x30.neurion.sanctum.QueryGetDatasetsForUserResponse\"F\x82\xd3\xe4\x93\x02@\x12>/neurion/sanctum/get_datasets_for_user/{user}/{offset}/{limit}B\x19Z\x17neurion/x/sanctum/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.sanctum.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\027neurion/x/sanctum/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETAVAILABLEDATASETSRESPONSE'].fields_by_name['datasets']._loaded_options = None
  _globals['_QUERYGETAVAILABLEDATASETSRESPONSE'].fields_by_name['datasets']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETAPPROVEDUSAGEREQUESTSRESPONSE'].fields_by_name['requests']._loaded_options = None
  _globals['_QUERYGETAPPROVEDUSAGEREQUESTSRESPONSE'].fields_by_name['requests']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGDATASETSRESPONSE'].fields_by_name['datasets']._loaded_options = None
  _globals['_QUERYGETPENDINGDATASETSRESPONSE'].fields_by_name['datasets']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGUSAGEREQUESTSRESPONSE'].fields_by_name['requests']._loaded_options = None
  _globals['_QUERYGETPENDINGUSAGEREQUESTSRESPONSE'].fields_by_name['requests']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETDATASETRESPONSE'].fields_by_name['dataset']._loaded_options = None
  _globals['_QUERYGETDATASETRESPONSE'].fields_by_name['dataset']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETUSAGEREQUESTRESPONSE'].fields_by_name['request']._loaded_options = None
  _globals['_QUERYGETUSAGEREQUESTRESPONSE'].fields_by_name['request']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETUSAGEREQUESTSFORDATASETRESPONSE'].fields_by_name['requests']._loaded_options = None
  _globals['_QUERYGETUSAGEREQUESTSFORDATASETRESPONSE'].fields_by_name['requests']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETUSAGEREQUESTSFORUSERRESPONSE'].fields_by_name['requests']._loaded_options = None
  _globals['_QUERYGETUSAGEREQUESTSFORUSERRESPONSE'].fields_by_name['requests']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETDATASETSFORUSERRESPONSE'].fields_by_name['datasets']._loaded_options = None
  _globals['_QUERYGETDATASETSFORUSERRESPONSE'].fields_by_name['datasets']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\031\022\027/neurion/sanctum/params'
  _globals['_QUERY'].methods_by_name['GetAvailableDatasets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetAvailableDatasets']._serialized_options = b'\202\323\344\223\002)\022\'/neurion/sanctum/get_available_datasets'
  _globals['_QUERY'].methods_by_name['GetApprovedUsageRequests']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetApprovedUsageRequests']._serialized_options = b'\202\323\344\223\002.\022,/neurion/sanctum/get_approved_usage_requests'
  _globals['_QUERY'].methods_by_name['GetReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetReward']._serialized_options = b'\202\323\344\223\002$\022\"/neurion/sanctum/get_reward/{user}'
  _globals['_QUERY'].methods_by_name['GetStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetStake']._serialized_options = b'\202\323\344\223\002#\022!/neurion/sanctum/get_stake/{user}'
  _globals['_QUERY'].methods_by_name['GetPendingDatasets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingDatasets']._serialized_options = b'\202\323\344\223\002\'\022%/neurion/sanctum/get_pending_datasets'
  _globals['_QUERY'].methods_by_name['GetPendingUsageRequests']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingUsageRequests']._serialized_options = b'\202\323\344\223\0024\0222/neurion/sanctum/get_pending_usage_requests/{user}'
  _globals['_QUERY'].methods_by_name['GetDataset']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetDataset']._serialized_options = b'\202\323\344\223\002#\022!/neurion/sanctum/get_dataset/{id}'
  _globals['_QUERY'].methods_by_name['GetUsageRequest']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetUsageRequest']._serialized_options = b'\202\323\344\223\002)\022\'/neurion/sanctum/get_usage_request/{id}'
  _globals['_QUERY'].methods_by_name['GetUsageRequestsForDataset']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetUsageRequestsForDataset']._serialized_options = b'\202\323\344\223\002O\022M/neurion/sanctum/get_usage_requests_for_dataset/{dataset_id}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['GetUsageRequestsForUser']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetUsageRequestsForUser']._serialized_options = b'\202\323\344\223\002F\022D/neurion/sanctum/get_usage_requests_for_user/{user}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['GetDatasetsForUser']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetDatasetsForUser']._serialized_options = b'\202\323\344\223\002@\022>/neurion/sanctum/get_datasets_for_user/{user}/{offset}/{limit}'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=281
  _globals['_QUERYPARAMSREQUEST']._serialized_end=301
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=303
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=376
  _globals['_QUERYGETAVAILABLEDATASETSREQUEST']._serialized_start=378
  _globals['_QUERYGETAVAILABLEDATASETSREQUEST']._serialized_end=443
  _globals['_QUERYGETAVAILABLEDATASETSRESPONSE']._serialized_start=446
  _globals['_QUERYGETAVAILABLEDATASETSRESPONSE']._serialized_end=608
  _globals['_QUERYGETAPPROVEDUSAGEREQUESTSREQUEST']._serialized_start=610
  _globals['_QUERYGETAPPROVEDUSAGEREQUESTSREQUEST']._serialized_end=648
  _globals['_QUERYGETAPPROVEDUSAGEREQUESTSRESPONSE']._serialized_start=650
  _globals['_QUERYGETAPPROVEDUSAGEREQUESTSRESPONSE']._serialized_end=756
  _globals['_QUERYGETREWARDREQUEST']._serialized_start=758
  _globals['_QUERYGETREWARDREQUEST']._serialized_end=795
  _globals['_QUERYGETREWARDRESPONSE']._serialized_start=797
  _globals['_QUERYGETREWARDRESPONSE']._serialized_end=837
  _globals['_QUERYGETSTAKEREQUEST']._serialized_start=839
  _globals['_QUERYGETSTAKEREQUEST']._serialized_end=875
  _globals['_QUERYGETSTAKERESPONSE']._serialized_start=877
  _globals['_QUERYGETSTAKERESPONSE']._serialized_end=915
  _globals['_QUERYGETPENDINGDATASETSREQUEST']._serialized_start=917
  _globals['_QUERYGETPENDINGDATASETSREQUEST']._serialized_end=949
  _globals['_QUERYGETPENDINGDATASETSRESPONSE']._serialized_start=951
  _globals['_QUERYGETPENDINGDATASETSRESPONSE']._serialized_end=1050
  _globals['_QUERYGETPENDINGUSAGEREQUESTSREQUEST']._serialized_start=1052
  _globals['_QUERYGETPENDINGUSAGEREQUESTSREQUEST']._serialized_end=1103
  _globals['_QUERYGETPENDINGUSAGEREQUESTSRESPONSE']._serialized_start=1105
  _globals['_QUERYGETPENDINGUSAGEREQUESTSRESPONSE']._serialized_end=1210
  _globals['_QUERYGETDATASETREQUEST']._serialized_start=1212
  _globals['_QUERYGETDATASETREQUEST']._serialized_end=1248
  _globals['_QUERYGETDATASETRESPONSE']._serialized_start=1250
  _globals['_QUERYGETDATASETRESPONSE']._serialized_end=1340
  _globals['_QUERYGETUSAGEREQUESTREQUEST']._serialized_start=1342
  _globals['_QUERYGETUSAGEREQUESTREQUEST']._serialized_end=1383
  _globals['_QUERYGETUSAGEREQUESTRESPONSE']._serialized_start=1385
  _globals['_QUERYGETUSAGEREQUESTRESPONSE']._serialized_end=1481
  _globals['_QUERYGETUSAGEREQUESTSFORDATASETREQUEST']._serialized_start=1483
  _globals['_QUERYGETUSAGEREQUESTSFORDATASETREQUEST']._serialized_end=1574
  _globals['_QUERYGETUSAGEREQUESTSFORDATASETRESPONSE']._serialized_start=1577
  _globals['_QUERYGETUSAGEREQUESTSFORDATASETRESPONSE']._serialized_end=1746
  _globals['_QUERYGETUSAGEREQUESTSFORUSERREQUEST']._serialized_start=1748
  _globals['_QUERYGETUSAGEREQUESTSFORUSERREQUEST']._serialized_end=1830
  _globals['_QUERYGETUSAGEREQUESTSFORUSERRESPONSE']._serialized_start=1833
  _globals['_QUERYGETUSAGEREQUESTSFORUSERRESPONSE']._serialized_end=1999
  _globals['_QUERYGETDATASETSFORUSERREQUEST']._serialized_start=2001
  _globals['_QUERYGETDATASETSFORUSERREQUEST']._serialized_end=2078
  _globals['_QUERYGETDATASETSFORUSERRESPONSE']._serialized_start=2081
  _globals['_QUERYGETDATASETSFORUSERRESPONSE']._serialized_end=2241
  _globals['_QUERY']._serialized_start=2244
  _globals['_QUERY']._serialized_end=4325
# @@protoc_insertion_point(module_scope)
