from cometbft.services.block_results.v1 import block_results_pb2 as _block_results_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
