# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/error_code.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/error_code.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fneurion/fusion/error_code.proto\x12\x0eneurion.fusion*\xf5\x03\n\tErrorCode\x12\x15\n\x11\x45rrorCode_NOERROR\x10\x00\x12\x1d\n\x19\x45rrorCode_INVALID_ADDRESS\x10\x01\x12!\n\x1d\x45rrorCode_INVALID_TASK_STATUS\x10\x02\x12\x1a\n\x16\x45rrorCode_NOT_PROPOSER\x10\x03\x12\x1b\n\x17\x45rrorCode_NOT_VALIDATOR\x10\x04\x12\x1e\n\x1a\x45rrorCode_ALREADY_ASSIGNED\x10\x05\x12\x1e\n\x1a\x45rrorCode_STAKE_NOT_ENOUGH\x10\x06\x12\x1f\n\x1b\x45rrorCode_ALREADY_SUBMITTED\x10\x07\x12\x1c\n\x18\x45rrorCode_NOT_AUTHORIZED\x10\x08\x12!\n\x1d\x45rrorCode_MIN_TIME_NOT_PASSED\x10\t\x12\x1e\n\x1a\x45rrorCode_COLLECTION_ERROR\x10\n\x12\x19\n\x15\x45rrorCode_BLACKLISTED\x10\x0b\x12\x1f\n\x1b\x45rrorCode_ALREADY_VALIDATOR\x10\x0c\x12\x1e\n\x1a\x45rrorCode_ALREADY_PROPOSER\x10\r\x12\x19\n\x15\x45rrorCode_WRONG_ROUND\x10\x0e\x12\x1d\n\x19\x45rrorCode_PENDING_DISPUTE\x10\x0f\x42\x18Z\x16neurion/x/fusion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.error_code_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\026neurion/x/fusion/types'
  _globals['_ERRORCODE']._serialized_start=52
  _globals['_ERRORCODE']._serialized_end=553
# @@protoc_insertion_point(module_scope)
