# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from neurion.fusion import params_pb2 as neurion_dot_fusion_dot_params__pb2
from neurion.fusion import task_pb2 as neurion_dot_fusion_dot_task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17neurion/fusion/tx.proto\x12\x0eneurion.fusion\x1a\x11\x61mino/amino.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1bneurion/fusion/params.proto\x1a\x19neurion/fusion/task.proto\"\xa6\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x31\n\x06params\x18\x02 \x01(\x0b\x32\x16.neurion.fusion.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:3\x82\xe7\xb0*\tauthority\x8a\xe7\xb0* neurion/x/fusion/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"E\n\x0fMsgApplyCreator\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgApplyCreatorResponse\"^\n\x15MsgApproveApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgApproveApplicationResponse\"]\n\x14MsgRejectApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1e\n\x1cMsgRejectApplicationResponse\"\x89\x01\n\rMsgCreateTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nbase_model\x18\x02 \x01(\t\x12\x12\n\nmax_rounds\x18\x03 \x01(\x04\x12\x0e\n\x06reward\x18\x04 \x01(\x04\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"F\n\x15MsgCreateTaskResponse\x12-\n\x04task\x18\x01 \x01(\x0b\x32\x14.neurion.fusion.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\">\n\x0cMsgStartTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"E\n\x14MsgStartTaskResponse\x12-\n\x04task\x18\x01 \x01(\x0b\x32\x14.neurion.fusion.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"q\n\x0fMsgProposeModel\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\r\n\x05model\x18\x03 \x01(\t\x12\x10\n\x08metainfo\x18\x04 \x01(\t\x12\r\n\x05round\x18\x06 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgProposeModelResponse\"T\n\x13MsgRegisterProposer\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\r\n\x05stake\x18\x02 \x01(\x04\x12\x0f\n\x07task_id\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1d\n\x1bMsgRegisterProposerResponse\"U\n\x14MsgRegisterValidator\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\r\n\x05stake\x18\x02 \x01(\x04\x12\x0f\n\x07task_id\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1e\n\x1cMsgRegisterValidatorResponse\"a\n\x0fMsgStartTesting\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\r\n\x05round\x18\x02 \x01(\x04\x12\x0f\n\x07testset\x18\x03 \x01(\t\x12\x0f\n\x07task_id\x18\x04 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgStartTestingResponse\"J\n\x18MsgRequestValidationTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\"\n MsgRequestValidationTaskResponse\"Z\n\x0eMsgSubmitScore\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x1a\n\x12validation_task_id\x18\x02 \x01(\x04\x12\r\n\x05score\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x18\n\x16MsgSubmitScoreResponse\"V\n\x14MsgDisputeModelScore\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\x04\x12\r\n\x05score\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1e\n\x1cMsgDisputeModelScoreResponse\"e\n\x10MsgStartNewRound\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\r\n\x05round\x18\x02 \x01(\x04\x12\x12\n\nbase_model\x18\x03 \x01(\t\x12\x0f\n\x07task_id\x18\x04 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgStartNewRoundResponse\"B\n\x10MsgTerminateTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgTerminateTaskResponse\"P\n\x0eMsgStakeToTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x18\n\x16MsgStakeToTaskResponse\"D\n\x12MsgClaimTaskReward\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgClaimTaskRewardResponse\"D\n\x12MsgUnstakeFromTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgUnstakeFromTaskResponse\"I\n\x18MsgDisclaimCreatorStatus\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\"\n MsgDisclaimCreatorStatusResponse\">\n\x0cMsgAbortTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x16\n\x14MsgAbortTaskResponse2\x8f\x0f\n\x03Msg\x12X\n\x0cUpdateParams\x12\x1f.neurion.fusion.MsgUpdateParams\x1a\'.neurion.fusion.MsgUpdateParamsResponse\x12X\n\x0c\x41pplyCreator\x12\x1f.neurion.fusion.MsgApplyCreator\x1a\'.neurion.fusion.MsgApplyCreatorResponse\x12j\n\x12\x41pproveApplication\x12%.neurion.fusion.MsgApproveApplication\x1a-.neurion.fusion.MsgApproveApplicationResponse\x12g\n\x11RejectApplication\x12$.neurion.fusion.MsgRejectApplication\x1a,.neurion.fusion.MsgRejectApplicationResponse\x12R\n\nCreateTask\x12\x1d.neurion.fusion.MsgCreateTask\x1a%.neurion.fusion.MsgCreateTaskResponse\x12O\n\tStartTask\x12\x1c.neurion.fusion.MsgStartTask\x1a$.neurion.fusion.MsgStartTaskResponse\x12X\n\x0cProposeModel\x12\x1f.neurion.fusion.MsgProposeModel\x1a\'.neurion.fusion.MsgProposeModelResponse\x12\x64\n\x10RegisterProposer\x12#.neurion.fusion.MsgRegisterProposer\x1a+.neurion.fusion.MsgRegisterProposerResponse\x12g\n\x11RegisterValidator\x12$.neurion.fusion.MsgRegisterValidator\x1a,.neurion.fusion.MsgRegisterValidatorResponse\x12X\n\x0cStartTesting\x12\x1f.neurion.fusion.MsgStartTesting\x1a\'.neurion.fusion.MsgStartTestingResponse\x12s\n\x15RequestValidationTask\x12(.neurion.fusion.MsgRequestValidationTask\x1a\x30.neurion.fusion.MsgRequestValidationTaskResponse\x12U\n\x0bSubmitScore\x12\x1e.neurion.fusion.MsgSubmitScore\x1a&.neurion.fusion.MsgSubmitScoreResponse\x12g\n\x11\x44isputeModelScore\x12$.neurion.fusion.MsgDisputeModelScore\x1a,.neurion.fusion.MsgDisputeModelScoreResponse\x12[\n\rStartNewRound\x12 .neurion.fusion.MsgStartNewRound\x1a(.neurion.fusion.MsgStartNewRoundResponse\x12[\n\rTerminateTask\x12 .neurion.fusion.MsgTerminateTask\x1a(.neurion.fusion.MsgTerminateTaskResponse\x12U\n\x0bStakeToTask\x12\x1e.neurion.fusion.MsgStakeToTask\x1a&.neurion.fusion.MsgStakeToTaskResponse\x12\x61\n\x0f\x43laimTaskReward\x12\".neurion.fusion.MsgClaimTaskReward\x1a*.neurion.fusion.MsgClaimTaskRewardResponse\x12\x61\n\x0fUnstakeFromTask\x12\".neurion.fusion.MsgUnstakeFromTask\x1a*.neurion.fusion.MsgUnstakeFromTaskResponse\x12s\n\x15\x44isclaimCreatorStatus\x12(.neurion.fusion.MsgDisclaimCreatorStatus\x1a\x30.neurion.fusion.MsgDisclaimCreatorStatusResponse\x12O\n\tAbortTask\x12\x1c.neurion.fusion.MsgAbortTask\x1a$.neurion.fusion.MsgAbortTaskResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x18Z\x16neurion/x/fusion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\026neurion/x/fusion/types'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260* neurion/x/fusion/MsgUpdateParams'
  _globals['_MSGAPPLYCREATOR']._loaded_options = None
  _globals['_MSGAPPLYCREATOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGAPPROVEAPPLICATION']._loaded_options = None
  _globals['_MSGAPPROVEAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREJECTAPPLICATION']._loaded_options = None
  _globals['_MSGREJECTAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCREATETASK']._loaded_options = None
  _globals['_MSGCREATETASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCREATETASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_MSGCREATETASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGSTARTTASK']._loaded_options = None
  _globals['_MSGSTARTTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTARTTASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_MSGSTARTTASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGPROPOSEMODEL']._loaded_options = None
  _globals['_MSGPROPOSEMODEL']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREGISTERPROPOSER']._loaded_options = None
  _globals['_MSGREGISTERPROPOSER']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREGISTERVALIDATOR']._loaded_options = None
  _globals['_MSGREGISTERVALIDATOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTARTTESTING']._loaded_options = None
  _globals['_MSGSTARTTESTING']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREQUESTVALIDATIONTASK']._loaded_options = None
  _globals['_MSGREQUESTVALIDATIONTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSUBMITSCORE']._loaded_options = None
  _globals['_MSGSUBMITSCORE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGDISPUTEMODELSCORE']._loaded_options = None
  _globals['_MSGDISPUTEMODELSCORE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTARTNEWROUND']._loaded_options = None
  _globals['_MSGSTARTNEWROUND']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGTERMINATETASK']._loaded_options = None
  _globals['_MSGTERMINATETASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTAKETOTASK']._loaded_options = None
  _globals['_MSGSTAKETOTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCLAIMTASKREWARD']._loaded_options = None
  _globals['_MSGCLAIMTASKREWARD']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGUNSTAKEFROMTASK']._loaded_options = None
  _globals['_MSGUNSTAKEFROMTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGDISCLAIMCREATORSTATUS']._loaded_options = None
  _globals['_MSGDISCLAIMCREATORSTATUS']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGABORTTASK']._loaded_options = None
  _globals['_MSGABORTTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=193
  _globals['_MSGUPDATEPARAMS']._serialized_end=359
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=361
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=386
  _globals['_MSGAPPLYCREATOR']._serialized_start=388
  _globals['_MSGAPPLYCREATOR']._serialized_end=457
  _globals['_MSGAPPLYCREATORRESPONSE']._serialized_start=459
  _globals['_MSGAPPLYCREATORRESPONSE']._serialized_end=484
  _globals['_MSGAPPROVEAPPLICATION']._serialized_start=486
  _globals['_MSGAPPROVEAPPLICATION']._serialized_end=580
  _globals['_MSGAPPROVEAPPLICATIONRESPONSE']._serialized_start=582
  _globals['_MSGAPPROVEAPPLICATIONRESPONSE']._serialized_end=613
  _globals['_MSGREJECTAPPLICATION']._serialized_start=615
  _globals['_MSGREJECTAPPLICATION']._serialized_end=708
  _globals['_MSGREJECTAPPLICATIONRESPONSE']._serialized_start=710
  _globals['_MSGREJECTAPPLICATIONRESPONSE']._serialized_end=740
  _globals['_MSGCREATETASK']._serialized_start=743
  _globals['_MSGCREATETASK']._serialized_end=880
  _globals['_MSGCREATETASKRESPONSE']._serialized_start=882
  _globals['_MSGCREATETASKRESPONSE']._serialized_end=952
  _globals['_MSGSTARTTASK']._serialized_start=954
  _globals['_MSGSTARTTASK']._serialized_end=1016
  _globals['_MSGSTARTTASKRESPONSE']._serialized_start=1018
  _globals['_MSGSTARTTASKRESPONSE']._serialized_end=1087
  _globals['_MSGPROPOSEMODEL']._serialized_start=1089
  _globals['_MSGPROPOSEMODEL']._serialized_end=1202
  _globals['_MSGPROPOSEMODELRESPONSE']._serialized_start=1204
  _globals['_MSGPROPOSEMODELRESPONSE']._serialized_end=1229
  _globals['_MSGREGISTERPROPOSER']._serialized_start=1231
  _globals['_MSGREGISTERPROPOSER']._serialized_end=1315
  _globals['_MSGREGISTERPROPOSERRESPONSE']._serialized_start=1317
  _globals['_MSGREGISTERPROPOSERRESPONSE']._serialized_end=1346
  _globals['_MSGREGISTERVALIDATOR']._serialized_start=1348
  _globals['_MSGREGISTERVALIDATOR']._serialized_end=1433
  _globals['_MSGREGISTERVALIDATORRESPONSE']._serialized_start=1435
  _globals['_MSGREGISTERVALIDATORRESPONSE']._serialized_end=1465
  _globals['_MSGSTARTTESTING']._serialized_start=1467
  _globals['_MSGSTARTTESTING']._serialized_end=1564
  _globals['_MSGSTARTTESTINGRESPONSE']._serialized_start=1566
  _globals['_MSGSTARTTESTINGRESPONSE']._serialized_end=1591
  _globals['_MSGREQUESTVALIDATIONTASK']._serialized_start=1593
  _globals['_MSGREQUESTVALIDATIONTASK']._serialized_end=1667
  _globals['_MSGREQUESTVALIDATIONTASKRESPONSE']._serialized_start=1669
  _globals['_MSGREQUESTVALIDATIONTASKRESPONSE']._serialized_end=1703
  _globals['_MSGSUBMITSCORE']._serialized_start=1705
  _globals['_MSGSUBMITSCORE']._serialized_end=1795
  _globals['_MSGSUBMITSCORERESPONSE']._serialized_start=1797
  _globals['_MSGSUBMITSCORERESPONSE']._serialized_end=1821
  _globals['_MSGDISPUTEMODELSCORE']._serialized_start=1823
  _globals['_MSGDISPUTEMODELSCORE']._serialized_end=1909
  _globals['_MSGDISPUTEMODELSCORERESPONSE']._serialized_start=1911
  _globals['_MSGDISPUTEMODELSCORERESPONSE']._serialized_end=1941
  _globals['_MSGSTARTNEWROUND']._serialized_start=1943
  _globals['_MSGSTARTNEWROUND']._serialized_end=2044
  _globals['_MSGSTARTNEWROUNDRESPONSE']._serialized_start=2046
  _globals['_MSGSTARTNEWROUNDRESPONSE']._serialized_end=2072
  _globals['_MSGTERMINATETASK']._serialized_start=2074
  _globals['_MSGTERMINATETASK']._serialized_end=2140
  _globals['_MSGTERMINATETASKRESPONSE']._serialized_start=2142
  _globals['_MSGTERMINATETASKRESPONSE']._serialized_end=2168
  _globals['_MSGSTAKETOTASK']._serialized_start=2170
  _globals['_MSGSTAKETOTASK']._serialized_end=2250
  _globals['_MSGSTAKETOTASKRESPONSE']._serialized_start=2252
  _globals['_MSGSTAKETOTASKRESPONSE']._serialized_end=2276
  _globals['_MSGCLAIMTASKREWARD']._serialized_start=2278
  _globals['_MSGCLAIMTASKREWARD']._serialized_end=2346
  _globals['_MSGCLAIMTASKREWARDRESPONSE']._serialized_start=2348
  _globals['_MSGCLAIMTASKREWARDRESPONSE']._serialized_end=2376
  _globals['_MSGUNSTAKEFROMTASK']._serialized_start=2378
  _globals['_MSGUNSTAKEFROMTASK']._serialized_end=2446
  _globals['_MSGUNSTAKEFROMTASKRESPONSE']._serialized_start=2448
  _globals['_MSGUNSTAKEFROMTASKRESPONSE']._serialized_end=2476
  _globals['_MSGDISCLAIMCREATORSTATUS']._serialized_start=2478
  _globals['_MSGDISCLAIMCREATORSTATUS']._serialized_end=2551
  _globals['_MSGDISCLAIMCREATORSTATUSRESPONSE']._serialized_start=2553
  _globals['_MSGDISCLAIMCREATORSTATUSRESPONSE']._serialized_end=2587
  _globals['_MSGABORTTASK']._serialized_start=2589
  _globals['_MSGABORTTASK']._serialized_end=2651
  _globals['_MSGABORTTASKRESPONSE']._serialized_start=2653
  _globals['_MSGABORTTASKRESPONSE']._serialized_end=2675
  _globals['_MSG']._serialized_start=2678
  _globals['_MSG']._serialized_end=4613
# @@protoc_insertion_point(module_scope)
