# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from neurion.crucible import params_pb2 as neurion_dot_crucible_dot_params__pb2
from neurion.crucible import task_pb2 as neurion_dot_crucible_dot_task__pb2
from neurion.crucible import submission_pb2 as neurion_dot_crucible_dot_submission__pb2
from neurion.crucible import plagiarism_report_pb2 as neurion_dot_crucible_dot_plagiarism__report__pb2
from neurion.crucible import creator_application_pb2 as neurion_dot_crucible_dot_creator__application__pb2
from neurion.crucible import score_task_pb2 as neurion_dot_crucible_dot_score__task__pb2
from neurion.crucible import error_code_pb2 as neurion_dot_crucible_dot_error__code__pb2
from neurion.crucible import dispute_score_task_pb2 as neurion_dot_crucible_dot_dispute__score__task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cneurion/crucible/query.proto\x12\x10neurion.crucible\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1dneurion/crucible/params.proto\x1a\x1bneurion/crucible/task.proto\x1a!neurion/crucible/submission.proto\x1a(neurion/crucible/plagiarism_report.proto\x1a*neurion/crucible/creator_application.proto\x1a!neurion/crucible/score_task.proto\x1a!neurion/crucible/error_code.proto\x1a)neurion/crucible/dispute_score_task.proto\"\x14\n\x12QueryParamsRequest\"J\n\x13QueryParamsResponse\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x18.neurion.crucible.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x19\n\x17QueryGetCreatorsRequest\",\n\x18QueryGetCreatorsResponse\x12\x10\n\x08\x63reators\x18\x01 \x03(\t\"5\n\"QueryGetCreatorApplicationsRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\"l\n#QueryGetCreatorApplicationsResponse\x12\x45\n\x0c\x61pplications\x18\x01 \x03(\x0b\x32$.neurion.crucible.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"!\n\x13QueryGetTaskRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"G\n\x14QueryGetTaskResponse\x12/\n\x04task\x18\x01 \x01(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"9\n\x18QueryListAllTasksRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x04\"\x8a\x01\n\x19QueryListAllTasksResponse\x12\x30\n\x05tasks\x18\x01 \x03(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"l\n\x1dQueryListTasksByStatusRequest\x12,\n\x06status\x18\x01 \x01(\x0e\x32\x1c.neurion.crucible.TaskStatus\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\x8f\x01\n\x1eQueryListTasksByStatusResponse\x12\x30\n\x05tasks\x18\x01 \x03(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\'\n\x19QueryGetSubmissionRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"Y\n\x1aQueryGetSubmissionResponse\x12;\n\nsubmission\x18\x01 \x01(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"J\n&QueryGetSubmissionByTaskCreatorRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\"\xb7\x01\n\'QueryGetSubmissionByTaskCreatorResponse\x12\x42\n\x11\x66inal_submissions\x18\x01 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12H\n\x17provisional_submissions\x18\x02 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"2\n\x1fQueryGetSubmissionByTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\"\xb0\x01\n QueryGetSubmissionByTaskResponse\x12\x42\n\x11\x66inal_submissions\x18\x01 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12H\n\x17provisional_submissions\x18\x02 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"J\n(QueryGetEncryptedProofOfOwnershipRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\t\"?\n)QueryGetEncryptedProofOfOwnershipResponse\x12\x12\n\nciphertext\x18\x01 \x01(\t\"4\n\x1fQueryGetPlagiarismReportRequest\x12\x11\n\treport_id\x18\x01 \x01(\x04\"a\n QueryGetPlagiarismReportResponse\x12=\n\x06report\x18\x01 \x01(\x0b\x32\".neurion.crucible.PlagiarismReportB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\":\n\x19QueryGetTaskRewardRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\",\n\x1aQueryGetTaskRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"+\n)QueryGetPendingCreatorApplicationsRequest\"q\n*QueryGetPendingCreatorApplicationsResponse\x12\x43\n\napplicants\x18\x01 \x03(\x0b\x32$.neurion.crucible.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"9\n\x18QueryGetTaskStakeRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\"*\n\x19QueryGetTaskStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\";\n(QueryGetUnscoredSubmissionsByTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\"i\n)QueryGetUnscoredSubmissionsByTaskResponse\x12<\n\x0bsubmissions\x18\x01 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"I\n%QueryCanTriggerFinalSubmissionRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"e\n&QueryCanTriggerFinalSubmissionResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"F\n\"QueryCanTriggerFinalTestingRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"b\n#QueryCanTriggerFinalTestingResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"A\n QueryCanRegisterAsTrainerRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"`\n!QueryCanRegisterAsTrainerResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"@\n\x1fQueryCanRegisterAsScorerRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"_\n QueryCanRegisterAsScorerResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"6\n\x15QueryIsTrainerRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"U\n\x16QueryIsTrainerResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"5\n\x14QueryIsScorerRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"T\n\x15QueryIsScorerResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"D\n#QueryCanSubmitTrainingResultRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"c\n$QueryCanSubmitTrainingResultResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"A\n QueryCanSubmitFinalResultRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"`\n!QueryCanSubmitFinalResultResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"B\n!QueryCanRequestScoringTaskRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"a\n\"QueryCanRequestScoringTaskResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"C\n\"QueryGetPendingScoringTasksRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"b\n#QueryGetPendingScoringTasksResponse\x12;\n\x0bscore_tasks\x18\x01 \x03(\x0b\x32\x1b.neurion.crucible.ScoreTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"<\n\x18QueryCanTerminateRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"X\n\x19QueryCanTerminateResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12+\n\x06reason\x18\x02 \x01(\x0e\x32\x1b.neurion.crucible.ErrorCode\"7\n\'QueryGetPlagiarismReportFromUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"u\n(QueryGetPlagiarismReportFromUserResponse\x12I\n\x12plagiarism_reports\x18\x01 \x03(\x0b\x32\".neurion.crucible.PlagiarismReportB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"3\n#QueryGetScoreDisputeFromUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"r\n$QueryGetScoreDisputeFromUserResponse\x12J\n\x13\x64ispute_score_tasks\x18\x01 \x03(\x0b\x32\".neurion.crucible.DisputeScoreTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32\x80)\n\x05Query\x12w\n\x06Params\x12$.neurion.crucible.QueryParamsRequest\x1a%.neurion.crucible.QueryParamsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/neurion/crucible/params\x12\x8c\x01\n\x0bGetCreators\x12).neurion.crucible.QueryGetCreatorsRequest\x1a*.neurion.crucible.QueryGetCreatorsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/neurion/crucible/get_creators\x12\xc3\x01\n\x16GetCreatorApplications\x12\x34.neurion.crucible.QueryGetCreatorApplicationsRequest\x1a\x35.neurion.crucible.QueryGetCreatorApplicationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/neurion/crucible/get_creator_applications/{creator}\x12\x81\x01\n\x07GetTask\x12%.neurion.crucible.QueryGetTaskRequest\x1a&.neurion.crucible.QueryGetTaskResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/neurion/crucible/get_task/{id}\x12\xa2\x01\n\x0cListAllTasks\x12*.neurion.crucible.QueryListAllTasksRequest\x1a+.neurion.crucible.QueryListAllTasksResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/neurion/crucible/list_all_tasks/{offset}/{limit}\x12\xc0\x01\n\x11ListTasksByStatus\x12/.neurion.crucible.QueryListTasksByStatusRequest\x1a\x30.neurion.crucible.QueryListTasksByStatusResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/neurion/crucible/list_tasks_by_status/{status}/{offset}/{limit}\x12\x99\x01\n\rGetSubmission\x12+.neurion.crucible.QueryGetSubmissionRequest\x1a,.neurion.crucible.QueryGetSubmissionResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/neurion/crucible/get_submission/{id}\x12\xdf\x01\n\x1aGetSubmissionByTaskCreator\x12\x38.neurion.crucible.QueryGetSubmissionByTaskCreatorRequest\x1a\x39.neurion.crucible.QueryGetSubmissionByTaskCreatorResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/neurion/crucible/get_submission_by_task_creator/{task_id}/{creator}\x12\xb8\x01\n\x13GetSubmissionByTask\x12\x31.neurion.crucible.QueryGetSubmissionByTaskRequest\x1a\x32.neurion.crucible.QueryGetSubmissionByTaskResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/crucible/get_submission_by_task/{task_id}\x12\xe5\x01\n\x1cGetEncryptedProofOfOwnership\x12:.neurion.crucible.QueryGetEncryptedProofOfOwnershipRequest\x1a;.neurion.crucible.QueryGetEncryptedProofOfOwnershipResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/neurion/crucible/get_encrypted_proof_of_ownership/{key}/{plaintext}\x12\xb9\x01\n\x13GetPlagiarismReport\x12\x31.neurion.crucible.QueryGetPlagiarismReportRequest\x1a\x32.neurion.crucible.QueryGetPlagiarismReportResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/neurion/crucible/get_plagiarism_report/{report_id}\x12\xa6\x01\n\rGetTaskReward\x12+.neurion.crucible.QueryGetTaskRewardRequest\x1a,.neurion.crucible.QueryGetTaskRewardResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/crucible/get_task_reward/{task_id}/{user}\x12\xd6\x01\n\x1dGetPendingCreatorApplications\x12;.neurion.crucible.QueryGetPendingCreatorApplicationsRequest\x1a<.neurion.crucible.QueryGetPendingCreatorApplicationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/crucible/get_pending_creator_applications\x12\xa2\x01\n\x0cGetTaskStake\x12*.neurion.crucible.QueryGetTaskStakeRequest\x1a+.neurion.crucible.QueryGetTaskStakeResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/neurion/crucible/get_task_stake/{task_id}/{user}\x12\xdd\x01\n\x1cGetUnscoredSubmissionsByTask\x12:.neurion.crucible.QueryGetUnscoredSubmissionsByTaskRequest\x1a;.neurion.crucible.QueryGetUnscoredSubmissionsByTaskResponse\"D\x82\xd3\xe4\x93\x02>\x12</neurion/crucible/get_unscored_submissions_by_task/{task_id}\x12\xda\x01\n\x19\x43\x61nTriggerFinalSubmission\x12\x37.neurion.crucible.QueryCanTriggerFinalSubmissionRequest\x1a\x38.neurion.crucible.QueryCanTriggerFinalSubmissionResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/neurion/crucible/can_trigger_final_submission/{creator}/{task_id}\x12\xce\x01\n\x16\x43\x61nTriggerFinalTesting\x12\x34.neurion.crucible.QueryCanTriggerFinalTestingRequest\x1a\x35.neurion.crucible.QueryCanTriggerFinalTestingResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/neurion/crucible/can_trigger_final_testing/{creator}/{task_id}\x12\xc3\x01\n\x14\x43\x61nRegisterAsTrainer\x12\x32.neurion.crucible.QueryCanRegisterAsTrainerRequest\x1a\x33.neurion.crucible.QueryCanRegisterAsTrainerResponse\"B\x82\xd3\xe4\x93\x02<\x12:/neurion/crucible/can_register_as_trainer/{user}/{task_id}\x12\xbf\x01\n\x13\x43\x61nRegisterAsScorer\x12\x31.neurion.crucible.QueryCanRegisterAsScorerRequest\x1a\x32.neurion.crucible.QueryCanRegisterAsScorerResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/neurion/crucible/can_register_as_scorer/{user}/{task_id}\x12\x95\x01\n\tIsTrainer\x12\'.neurion.crucible.QueryIsTrainerRequest\x1a(.neurion.crucible.QueryIsTrainerResponse\"5\x82\xd3\xe4\x93\x02/\x12-/neurion/crucible/is_trainer/{user}/{task_id}\x12\x91\x01\n\x08IsScorer\x12&.neurion.crucible.QueryIsScorerRequest\x1a\'.neurion.crucible.QueryIsScorerResponse\"4\x82\xd3\xe4\x93\x02.\x12,/neurion/crucible/is_scorer/{user}/{task_id}\x12\xcf\x01\n\x17\x43\x61nSubmitTrainingResult\x12\x35.neurion.crucible.QueryCanSubmitTrainingResultRequest\x1a\x36.neurion.crucible.QueryCanSubmitTrainingResultResponse\"E\x82\xd3\xe4\x93\x02?\x12=/neurion/crucible/can_submit_training_result/{user}/{task_id}\x12\xc3\x01\n\x14\x43\x61nSubmitFinalResult\x12\x32.neurion.crucible.QueryCanSubmitFinalResultRequest\x1a\x33.neurion.crucible.QueryCanSubmitFinalResultResponse\"B\x82\xd3\xe4\x93\x02<\x12:/neurion/crucible/can_submit_final_result/{user}/{task_id}\x12\xc7\x01\n\x15\x43\x61nRequestScoringTask\x12\x33.neurion.crucible.QueryCanRequestScoringTaskRequest\x1a\x34.neurion.crucible.QueryCanRequestScoringTaskResponse\"C\x82\xd3\xe4\x93\x02=\x12;/neurion/crucible/can_request_scoring_task/{user}/{task_id}\x12\xcb\x01\n\x16GetPendingScoringTasks\x12\x34.neurion.crucible.QueryGetPendingScoringTasksRequest\x1a\x35.neurion.crucible.QueryGetPendingScoringTasksResponse\"D\x82\xd3\xe4\x93\x02>\x12</neurion/crucible/get_pending_scoring_tasks/{user}/{task_id}\x12\xa4\x01\n\x0c\x43\x61nTerminate\x12*.neurion.crucible.QueryCanTerminateRequest\x1a+.neurion.crucible.QueryCanTerminateResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/neurion/crucible/can_terminate/{creator}/{task_id}\x12\xd6\x01\n\x1bGetPlagiarismReportFromUser\x12\x39.neurion.crucible.QueryGetPlagiarismReportFromUserRequest\x1a:.neurion.crucible.QueryGetPlagiarismReportFromUserResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/neurion/crucible/get_plagiarism_report_from_user/{user}\x12\xc6\x01\n\x17GetScoreDisputeFromUser\x12\x35.neurion.crucible.QueryGetScoreDisputeFromUserRequest\x1a\x36.neurion.crucible.QueryGetScoreDisputeFromUserResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/neurion/crucible/get_score_dispute_from_user/{user}B\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE'].fields_by_name['applications']._loaded_options = None
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE'].fields_by_name['applications']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTALLTASKSRESPONSE'].fields_by_name['tasks']._loaded_options = None
  _globals['_QUERYLISTALLTASKSRESPONSE'].fields_by_name['tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE'].fields_by_name['tasks']._loaded_options = None
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE'].fields_by_name['tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONRESPONSE'].fields_by_name['submission']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONRESPONSE'].fields_by_name['submission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['final_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['final_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['provisional_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['provisional_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['final_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['final_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['provisional_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['provisional_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._loaded_options = None
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._loaded_options = None
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE'].fields_by_name['submissions']._loaded_options = None
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE'].fields_by_name['submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGSCORINGTASKSRESPONSE'].fields_by_name['score_tasks']._loaded_options = None
  _globals['_QUERYGETPENDINGSCORINGTASKSRESPONSE'].fields_by_name['score_tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPLAGIARISMREPORTFROMUSERRESPONSE'].fields_by_name['plagiarism_reports']._loaded_options = None
  _globals['_QUERYGETPLAGIARISMREPORTFROMUSERRESPONSE'].fields_by_name['plagiarism_reports']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE'].fields_by_name['dispute_score_tasks']._loaded_options = None
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE'].fields_by_name['dispute_score_tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\032\022\030/neurion/crucible/params'
  _globals['_QUERY'].methods_by_name['GetCreators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetCreators']._serialized_options = b'\202\323\344\223\002 \022\036/neurion/crucible/get_creators'
  _globals['_QUERY'].methods_by_name['GetCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetCreatorApplications']._serialized_options = b'\202\323\344\223\0026\0224/neurion/crucible/get_creator_applications/{creator}'
  _globals['_QUERY'].methods_by_name['GetTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTask']._serialized_options = b'\202\323\344\223\002!\022\037/neurion/crucible/get_task/{id}'
  _globals['_QUERY'].methods_by_name['ListAllTasks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListAllTasks']._serialized_options = b'\202\323\344\223\0023\0221/neurion/crucible/list_all_tasks/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['ListTasksByStatus']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListTasksByStatus']._serialized_options = b'\202\323\344\223\002B\022@/neurion/crucible/list_tasks_by_status/{status}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['GetSubmission']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetSubmission']._serialized_options = b'\202\323\344\223\002\'\022%/neurion/crucible/get_submission/{id}'
  _globals['_QUERY'].methods_by_name['GetSubmissionByTaskCreator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetSubmissionByTaskCreator']._serialized_options = b'\202\323\344\223\002F\022D/neurion/crucible/get_submission_by_task_creator/{task_id}/{creator}'
  _globals['_QUERY'].methods_by_name['GetSubmissionByTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetSubmissionByTask']._serialized_options = b'\202\323\344\223\0024\0222/neurion/crucible/get_submission_by_task/{task_id}'
  _globals['_QUERY'].methods_by_name['GetEncryptedProofOfOwnership']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetEncryptedProofOfOwnership']._serialized_options = b'\202\323\344\223\002F\022D/neurion/crucible/get_encrypted_proof_of_ownership/{key}/{plaintext}'
  _globals['_QUERY'].methods_by_name['GetPlagiarismReport']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPlagiarismReport']._serialized_options = b'\202\323\344\223\0025\0223/neurion/crucible/get_plagiarism_report/{report_id}'
  _globals['_QUERY'].methods_by_name['GetTaskReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskReward']._serialized_options = b'\202\323\344\223\0024\0222/neurion/crucible/get_task_reward/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._serialized_options = b'\202\323\344\223\0024\0222/neurion/crucible/get_pending_creator_applications'
  _globals['_QUERY'].methods_by_name['GetTaskStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskStake']._serialized_options = b'\202\323\344\223\0023\0221/neurion/crucible/get_task_stake/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetUnscoredSubmissionsByTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetUnscoredSubmissionsByTask']._serialized_options = b'\202\323\344\223\002>\022</neurion/crucible/get_unscored_submissions_by_task/{task_id}'
  _globals['_QUERY'].methods_by_name['CanTriggerFinalSubmission']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanTriggerFinalSubmission']._serialized_options = b'\202\323\344\223\002D\022B/neurion/crucible/can_trigger_final_submission/{creator}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanTriggerFinalTesting']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanTriggerFinalTesting']._serialized_options = b'\202\323\344\223\002A\022?/neurion/crucible/can_trigger_final_testing/{creator}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanRegisterAsTrainer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanRegisterAsTrainer']._serialized_options = b'\202\323\344\223\002<\022:/neurion/crucible/can_register_as_trainer/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanRegisterAsScorer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanRegisterAsScorer']._serialized_options = b'\202\323\344\223\002;\0229/neurion/crucible/can_register_as_scorer/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['IsTrainer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IsTrainer']._serialized_options = b'\202\323\344\223\002/\022-/neurion/crucible/is_trainer/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['IsScorer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IsScorer']._serialized_options = b'\202\323\344\223\002.\022,/neurion/crucible/is_scorer/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanSubmitTrainingResult']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanSubmitTrainingResult']._serialized_options = b'\202\323\344\223\002?\022=/neurion/crucible/can_submit_training_result/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanSubmitFinalResult']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanSubmitFinalResult']._serialized_options = b'\202\323\344\223\002<\022:/neurion/crucible/can_submit_final_result/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanRequestScoringTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanRequestScoringTask']._serialized_options = b'\202\323\344\223\002=\022;/neurion/crucible/can_request_scoring_task/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['GetPendingScoringTasks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingScoringTasks']._serialized_options = b'\202\323\344\223\002>\022</neurion/crucible/get_pending_scoring_tasks/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanTerminate']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanTerminate']._serialized_options = b'\202\323\344\223\0025\0223/neurion/crucible/can_terminate/{creator}/{task_id}'
  _globals['_QUERY'].methods_by_name['GetPlagiarismReportFromUser']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPlagiarismReportFromUser']._serialized_options = b'\202\323\344\223\002:\0228/neurion/crucible/get_plagiarism_report_from_user/{user}'
  _globals['_QUERY'].methods_by_name['GetScoreDisputeFromUser']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetScoreDisputeFromUser']._serialized_options = b'\202\323\344\223\0026\0224/neurion/crucible/get_score_dispute_from_user/{user}'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=459
  _globals['_QUERYPARAMSREQUEST']._serialized_end=479
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=481
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=555
  _globals['_QUERYGETCREATORSREQUEST']._serialized_start=557
  _globals['_QUERYGETCREATORSREQUEST']._serialized_end=582
  _globals['_QUERYGETCREATORSRESPONSE']._serialized_start=584
  _globals['_QUERYGETCREATORSRESPONSE']._serialized_end=628
  _globals['_QUERYGETCREATORAPPLICATIONSREQUEST']._serialized_start=630
  _globals['_QUERYGETCREATORAPPLICATIONSREQUEST']._serialized_end=683
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE']._serialized_start=685
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE']._serialized_end=793
  _globals['_QUERYGETTASKREQUEST']._serialized_start=795
  _globals['_QUERYGETTASKREQUEST']._serialized_end=828
  _globals['_QUERYGETTASKRESPONSE']._serialized_start=830
  _globals['_QUERYGETTASKRESPONSE']._serialized_end=901
  _globals['_QUERYLISTALLTASKSREQUEST']._serialized_start=903
  _globals['_QUERYLISTALLTASKSREQUEST']._serialized_end=960
  _globals['_QUERYLISTALLTASKSRESPONSE']._serialized_start=963
  _globals['_QUERYLISTALLTASKSRESPONSE']._serialized_end=1101
  _globals['_QUERYLISTTASKSBYSTATUSREQUEST']._serialized_start=1103
  _globals['_QUERYLISTTASKSBYSTATUSREQUEST']._serialized_end=1211
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE']._serialized_start=1214
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE']._serialized_end=1357
  _globals['_QUERYGETSUBMISSIONREQUEST']._serialized_start=1359
  _globals['_QUERYGETSUBMISSIONREQUEST']._serialized_end=1398
  _globals['_QUERYGETSUBMISSIONRESPONSE']._serialized_start=1400
  _globals['_QUERYGETSUBMISSIONRESPONSE']._serialized_end=1489
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORREQUEST']._serialized_start=1491
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORREQUEST']._serialized_end=1565
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE']._serialized_start=1568
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE']._serialized_end=1751
  _globals['_QUERYGETSUBMISSIONBYTASKREQUEST']._serialized_start=1753
  _globals['_QUERYGETSUBMISSIONBYTASKREQUEST']._serialized_end=1803
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE']._serialized_start=1806
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE']._serialized_end=1982
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPREQUEST']._serialized_start=1984
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPREQUEST']._serialized_end=2058
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPRESPONSE']._serialized_start=2060
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPRESPONSE']._serialized_end=2123
  _globals['_QUERYGETPLAGIARISMREPORTREQUEST']._serialized_start=2125
  _globals['_QUERYGETPLAGIARISMREPORTREQUEST']._serialized_end=2177
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE']._serialized_start=2179
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE']._serialized_end=2276
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_start=2278
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_end=2336
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_start=2338
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_end=2382
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_start=2384
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_end=2427
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_start=2429
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_end=2542
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_start=2544
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_end=2601
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_start=2603
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_end=2645
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKREQUEST']._serialized_start=2647
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKREQUEST']._serialized_end=2706
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE']._serialized_start=2708
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE']._serialized_end=2813
  _globals['_QUERYCANTRIGGERFINALSUBMISSIONREQUEST']._serialized_start=2815
  _globals['_QUERYCANTRIGGERFINALSUBMISSIONREQUEST']._serialized_end=2888
  _globals['_QUERYCANTRIGGERFINALSUBMISSIONRESPONSE']._serialized_start=2890
  _globals['_QUERYCANTRIGGERFINALSUBMISSIONRESPONSE']._serialized_end=2991
  _globals['_QUERYCANTRIGGERFINALTESTINGREQUEST']._serialized_start=2993
  _globals['_QUERYCANTRIGGERFINALTESTINGREQUEST']._serialized_end=3063
  _globals['_QUERYCANTRIGGERFINALTESTINGRESPONSE']._serialized_start=3065
  _globals['_QUERYCANTRIGGERFINALTESTINGRESPONSE']._serialized_end=3163
  _globals['_QUERYCANREGISTERASTRAINERREQUEST']._serialized_start=3165
  _globals['_QUERYCANREGISTERASTRAINERREQUEST']._serialized_end=3230
  _globals['_QUERYCANREGISTERASTRAINERRESPONSE']._serialized_start=3232
  _globals['_QUERYCANREGISTERASTRAINERRESPONSE']._serialized_end=3328
  _globals['_QUERYCANREGISTERASSCORERREQUEST']._serialized_start=3330
  _globals['_QUERYCANREGISTERASSCORERREQUEST']._serialized_end=3394
  _globals['_QUERYCANREGISTERASSCORERRESPONSE']._serialized_start=3396
  _globals['_QUERYCANREGISTERASSCORERRESPONSE']._serialized_end=3491
  _globals['_QUERYISTRAINERREQUEST']._serialized_start=3493
  _globals['_QUERYISTRAINERREQUEST']._serialized_end=3547
  _globals['_QUERYISTRAINERRESPONSE']._serialized_start=3549
  _globals['_QUERYISTRAINERRESPONSE']._serialized_end=3634
  _globals['_QUERYISSCORERREQUEST']._serialized_start=3636
  _globals['_QUERYISSCORERREQUEST']._serialized_end=3689
  _globals['_QUERYISSCORERRESPONSE']._serialized_start=3691
  _globals['_QUERYISSCORERRESPONSE']._serialized_end=3775
  _globals['_QUERYCANSUBMITTRAININGRESULTREQUEST']._serialized_start=3777
  _globals['_QUERYCANSUBMITTRAININGRESULTREQUEST']._serialized_end=3845
  _globals['_QUERYCANSUBMITTRAININGRESULTRESPONSE']._serialized_start=3847
  _globals['_QUERYCANSUBMITTRAININGRESULTRESPONSE']._serialized_end=3946
  _globals['_QUERYCANSUBMITFINALRESULTREQUEST']._serialized_start=3948
  _globals['_QUERYCANSUBMITFINALRESULTREQUEST']._serialized_end=4013
  _globals['_QUERYCANSUBMITFINALRESULTRESPONSE']._serialized_start=4015
  _globals['_QUERYCANSUBMITFINALRESULTRESPONSE']._serialized_end=4111
  _globals['_QUERYCANREQUESTSCORINGTASKREQUEST']._serialized_start=4113
  _globals['_QUERYCANREQUESTSCORINGTASKREQUEST']._serialized_end=4179
  _globals['_QUERYCANREQUESTSCORINGTASKRESPONSE']._serialized_start=4181
  _globals['_QUERYCANREQUESTSCORINGTASKRESPONSE']._serialized_end=4278
  _globals['_QUERYGETPENDINGSCORINGTASKSREQUEST']._serialized_start=4280
  _globals['_QUERYGETPENDINGSCORINGTASKSREQUEST']._serialized_end=4347
  _globals['_QUERYGETPENDINGSCORINGTASKSRESPONSE']._serialized_start=4349
  _globals['_QUERYGETPENDINGSCORINGTASKSRESPONSE']._serialized_end=4447
  _globals['_QUERYCANTERMINATEREQUEST']._serialized_start=4449
  _globals['_QUERYCANTERMINATEREQUEST']._serialized_end=4509
  _globals['_QUERYCANTERMINATERESPONSE']._serialized_start=4511
  _globals['_QUERYCANTERMINATERESPONSE']._serialized_end=4599
  _globals['_QUERYGETPLAGIARISMREPORTFROMUSERREQUEST']._serialized_start=4601
  _globals['_QUERYGETPLAGIARISMREPORTFROMUSERREQUEST']._serialized_end=4656
  _globals['_QUERYGETPLAGIARISMREPORTFROMUSERRESPONSE']._serialized_start=4658
  _globals['_QUERYGETPLAGIARISMREPORTFROMUSERRESPONSE']._serialized_end=4775
  _globals['_QUERYGETSCOREDISPUTEFROMUSERREQUEST']._serialized_start=4777
  _globals['_QUERYGETSCOREDISPUTEFROMUSERREQUEST']._serialized_end=4828
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE']._serialized_start=4830
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE']._serialized_end=4944
  _globals['_QUERY']._serialized_start=4947
  _globals['_QUERY']._serialized_end=10195
# @@protoc_insertion_point(module_scope)
