# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/services/pruning/v1/pruning.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/services/pruning/v1/pruning.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cometbft/services/pruning/v1/pruning.proto\x12\x1c\x63ometbft.services.pruning.v1\"-\n\x1bSetBlockRetainHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\"\x1e\n\x1cSetBlockRetainHeightResponse\"\x1d\n\x1bGetBlockRetainHeightRequest\"`\n\x1cGetBlockRetainHeightResponse\x12\x19\n\x11\x61pp_retain_height\x18\x01 \x01(\x04\x12%\n\x1dpruning_service_retain_height\x18\x02 \x01(\x04\"4\n\"SetBlockResultsRetainHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\"%\n#SetBlockResultsRetainHeightResponse\"$\n\"GetBlockResultsRetainHeightRequest\"L\n#GetBlockResultsRetainHeightResponse\x12%\n\x1dpruning_service_retain_height\x18\x01 \x01(\x04\"1\n\x1fSetTxIndexerRetainHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\"\"\n SetTxIndexerRetainHeightResponse\"!\n\x1fGetTxIndexerRetainHeightRequest\"2\n GetTxIndexerRetainHeightResponse\x12\x0e\n\x06height\x18\x01 \x01(\x04\"4\n\"SetBlockIndexerRetainHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\"%\n#SetBlockIndexerRetainHeightResponse\"$\n\"GetBlockIndexerRetainHeightRequest\"5\n#GetBlockIndexerRetainHeightResponse\x12\x0e\n\x06height\x18\x01 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.pruning.v1.pruning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SETBLOCKRETAINHEIGHTREQUEST']._serialized_start=76
  _globals['_SETBLOCKRETAINHEIGHTREQUEST']._serialized_end=121
  _globals['_SETBLOCKRETAINHEIGHTRESPONSE']._serialized_start=123
  _globals['_SETBLOCKRETAINHEIGHTRESPONSE']._serialized_end=153
  _globals['_GETBLOCKRETAINHEIGHTREQUEST']._serialized_start=155
  _globals['_GETBLOCKRETAINHEIGHTREQUEST']._serialized_end=184
  _globals['_GETBLOCKRETAINHEIGHTRESPONSE']._serialized_start=186
  _globals['_GETBLOCKRETAINHEIGHTRESPONSE']._serialized_end=282
  _globals['_SETBLOCKRESULTSRETAINHEIGHTREQUEST']._serialized_start=284
  _globals['_SETBLOCKRESULTSRETAINHEIGHTREQUEST']._serialized_end=336
  _globals['_SETBLOCKRESULTSRETAINHEIGHTRESPONSE']._serialized_start=338
  _globals['_SETBLOCKRESULTSRETAINHEIGHTRESPONSE']._serialized_end=375
  _globals['_GETBLOCKRESULTSRETAINHEIGHTREQUEST']._serialized_start=377
  _globals['_GETBLOCKRESULTSRETAINHEIGHTREQUEST']._serialized_end=413
  _globals['_GETBLOCKRESULTSRETAINHEIGHTRESPONSE']._serialized_start=415
  _globals['_GETBLOCKRESULTSRETAINHEIGHTRESPONSE']._serialized_end=491
  _globals['_SETTXINDEXERRETAINHEIGHTREQUEST']._serialized_start=493
  _globals['_SETTXINDEXERRETAINHEIGHTREQUEST']._serialized_end=542
  _globals['_SETTXINDEXERRETAINHEIGHTRESPONSE']._serialized_start=544
  _globals['_SETTXINDEXERRETAINHEIGHTRESPONSE']._serialized_end=578
  _globals['_GETTXINDEXERRETAINHEIGHTREQUEST']._serialized_start=580
  _globals['_GETTXINDEXERRETAINHEIGHTREQUEST']._serialized_end=613
  _globals['_GETTXINDEXERRETAINHEIGHTRESPONSE']._serialized_start=615
  _globals['_GETTXINDEXERRETAINHEIGHTRESPONSE']._serialized_end=665
  _globals['_SETBLOCKINDEXERRETAINHEIGHTREQUEST']._serialized_start=667
  _globals['_SETBLOCKINDEXERRETAINHEIGHTREQUEST']._serialized_end=719
  _globals['_SETBLOCKINDEXERRETAINHEIGHTRESPONSE']._serialized_start=721
  _globals['_SETBLOCKINDEXERRETAINHEIGHTRESPONSE']._serialized_end=758
  _globals['_GETBLOCKINDEXERRETAINHEIGHTREQUEST']._serialized_start=760
  _globals['_GETBLOCKINDEXERRETAINHEIGHTREQUEST']._serialized_end=796
  _globals['_GETBLOCKINDEXERRETAINHEIGHTRESPONSE']._serialized_start=798
  _globals['_GETBLOCKINDEXERRETAINHEIGHTRESPONSE']._serialized_end=851
# @@protoc_insertion_point(module_scope)
