# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from neurion.crucible import params_pb2 as neurion_dot_crucible_dot_params__pb2
from neurion.crucible import task_pb2 as neurion_dot_crucible_dot_task__pb2
from neurion.crucible import submission_pb2 as neurion_dot_crucible_dot_submission__pb2
from neurion.crucible import score_task_pb2 as neurion_dot_crucible_dot_score__task__pb2
from neurion.crucible import plagiarism_report_pb2 as neurion_dot_crucible_dot_plagiarism__report__pb2
from neurion.crucible import dispute_score_task_pb2 as neurion_dot_crucible_dot_dispute__score__task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19neurion/crucible/tx.proto\x12\x10neurion.crucible\x1a\x11\x61mino/amino.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1dneurion/crucible/params.proto\x1a\x1bneurion/crucible/task.proto\x1a!neurion/crucible/submission.proto\x1a!neurion/crucible/score_task.proto\x1a(neurion/crucible/plagiarism_report.proto\x1a)neurion/crucible/dispute_score_task.proto\"\xaa\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x06params\x18\x02 \x01(\x0b\x32\x18.neurion.crucible.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:5\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\"neurion/x/crucible/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"E\n\x0fMsgApplyCreator\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgApplyCreatorResponse\"^\n\x15MsgApproveApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgApproveApplicationResponse\"]\n\x14MsgRejectApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1e\n\x1cMsgRejectApplicationResponse\"\xa9\x01\n\rMsgCreateTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06reward\x18\x02 \x01(\x04\x12\x14\n\x0ctraining_kit\x18\x03 \x01(\t\x12\x16\n\x0evalidation_kit\x18\x04 \x01(\t\x12\x18\n\x10\x64uration_in_days\x18\x05 \x01(\x04\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"H\n\x15MsgCreateTaskResponse\x12/\n\x04task\x18\x01 \x01(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"S\n\x12MsgRegisterTrainer\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\r\n\x05stake\x18\x02 \x01(\x04\x12\x0f\n\x07task_id\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgRegisterTrainerResponse\"R\n\x11MsgRegisterScorer\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\r\n\x05stake\x18\x02 \x01(\x04\x12\x0f\n\x07task_id\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1b\n\x19MsgRegisterScorerResponse\"\x91\x01\n\x17MsgSubmitTrainingResult\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\x0e\n\x06result\x18\x03 \x01(\t\x12\x10\n\x08metainfo\x18\x04 \x01(\t\x12$\n\x1c\x65ncrypted_proof_of_ownership\x18\x05 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"^\n\x1fMsgSubmitTrainingResultResponse\x12;\n\nsubmission\x18\x01 \x01(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"P\n\x0eMsgStakeToTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x18\n\x16MsgStakeToTaskResponse\"G\n\x15MsgRequestScoringTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"[\n\x1dMsgRequestScoringTaskResponse\x12:\n\nscore_task\x18\x01 \x01(\x0b\x32\x1b.neurion.crucible.ScoreTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"U\n\x0eMsgSubmitScore\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x15\n\rscore_task_id\x18\x02 \x01(\x04\x12\r\n\x05score\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"T\n\x16MsgSubmitScoreResponse\x12:\n\nscore_task\x18\x01 \x01(\x0b\x32\x1b.neurion.crucible.ScoreTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x8e\x01\n\x14MsgSubmitFinalResult\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\x0e\n\x06result\x18\x03 \x01(\t\x12\x10\n\x08metainfo\x18\x04 \x01(\t\x12$\n\x1c\x65ncrypted_proof_of_ownership\x18\x05 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1e\n\x1cMsgSubmitFinalResultResponse\"\x89\x01\n\x18MsgReportModelPlagiarism\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x18\n\x10my_submission_id\x18\x02 \x01(\x04\x12\x1f\n\x17suspected_submission_id\x18\x03 \x01(\x04\x12\x13\n\x0b\x65ncrypt_key\x18\x04 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"a\n MsgReportModelPlagiarismResponse\x12=\n\x06report\x18\x01 \x01(\x0b\x32\".neurion.crucible.PlagiarismReportB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"j\n\x19MsgAcceptPlagiarismReport\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x11\n\treport_id\x18\x02 \x01(\x04\x12\x1b\n\x13proof_of_plagiarism\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"b\n!MsgAcceptPlagiarismReportResponse\x12=\n\x06report\x18\x01 \x01(\x0b\x32\".neurion.crucible.PlagiarismReportB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"]\n\x19MsgRejectPlagiarismReport\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x11\n\treport_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"b\n!MsgRejectPlagiarismReportResponse\x12=\n\x06report\x18\x01 \x01(\x0b\x32\".neurion.crucible.PlagiarismReportB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"`\n\x19MsgDisputeSubmissionScore\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\x04\x12\r\n\x05score\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"n\n!MsgDisputeSubmissionScoreResponse\x12I\n\x12\x64ispute_score_task\x18\x01 \x01(\x0b\x32\".neurion.crucible.DisputeScoreTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\">\n\x0cMsgStartTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x16\n\x14MsgStartTaskResponse\">\n\x0cMsgAbortTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x16\n\x14MsgAbortTaskResponse\"Q\n\x1fMsgTriggerTaskToFinalSubmission\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\")\n\'MsgTriggerTaskToFinalSubmissionResponse\"`\n\x1cMsgTriggerTaskToFinalTesting\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\x10\n\x08test_kit\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"&\n$MsgTriggerTaskToFinalTestingResponse\"B\n\x10MsgTerminateTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgTerminateTaskResponse\"D\n\x12MsgClaimTaskReward\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgClaimTaskRewardResponse\"D\n\x12MsgUnstakeFromTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgUnstakeFromTaskResponse\"I\n\x18MsgDisclaimCreatorStatus\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\"\n MsgDisclaimCreatorStatusResponse2\xa5\x14\n\x03Msg\x12\\\n\x0cUpdateParams\x12!.neurion.crucible.MsgUpdateParams\x1a).neurion.crucible.MsgUpdateParamsResponse\x12\\\n\x0c\x41pplyCreator\x12!.neurion.crucible.MsgApplyCreator\x1a).neurion.crucible.MsgApplyCreatorResponse\x12n\n\x12\x41pproveApplication\x12\'.neurion.crucible.MsgApproveApplication\x1a/.neurion.crucible.MsgApproveApplicationResponse\x12k\n\x11RejectApplication\x12&.neurion.crucible.MsgRejectApplication\x1a..neurion.crucible.MsgRejectApplicationResponse\x12V\n\nCreateTask\x12\x1f.neurion.crucible.MsgCreateTask\x1a\'.neurion.crucible.MsgCreateTaskResponse\x12\x65\n\x0fRegisterTrainer\x12$.neurion.crucible.MsgRegisterTrainer\x1a,.neurion.crucible.MsgRegisterTrainerResponse\x12\x62\n\x0eRegisterScorer\x12#.neurion.crucible.MsgRegisterScorer\x1a+.neurion.crucible.MsgRegisterScorerResponse\x12t\n\x14SubmitTrainingResult\x12).neurion.crucible.MsgSubmitTrainingResult\x1a\x31.neurion.crucible.MsgSubmitTrainingResultResponse\x12Y\n\x0bStakeToTask\x12 .neurion.crucible.MsgStakeToTask\x1a(.neurion.crucible.MsgStakeToTaskResponse\x12n\n\x12RequestScoringTask\x12\'.neurion.crucible.MsgRequestScoringTask\x1a/.neurion.crucible.MsgRequestScoringTaskResponse\x12Y\n\x0bSubmitScore\x12 .neurion.crucible.MsgSubmitScore\x1a(.neurion.crucible.MsgSubmitScoreResponse\x12k\n\x11SubmitFinalResult\x12&.neurion.crucible.MsgSubmitFinalResult\x1a..neurion.crucible.MsgSubmitFinalResultResponse\x12w\n\x15ReportModelPlagiarism\x12*.neurion.crucible.MsgReportModelPlagiarism\x1a\x32.neurion.crucible.MsgReportModelPlagiarismResponse\x12z\n\x16\x41\x63\x63\x65ptPlagiarismReport\x12+.neurion.crucible.MsgAcceptPlagiarismReport\x1a\x33.neurion.crucible.MsgAcceptPlagiarismReportResponse\x12z\n\x16RejectPlagiarismReport\x12+.neurion.crucible.MsgRejectPlagiarismReport\x1a\x33.neurion.crucible.MsgRejectPlagiarismReportResponse\x12z\n\x16\x44isputeSubmissionScore\x12+.neurion.crucible.MsgDisputeSubmissionScore\x1a\x33.neurion.crucible.MsgDisputeSubmissionScoreResponse\x12S\n\tStartTask\x12\x1e.neurion.crucible.MsgStartTask\x1a&.neurion.crucible.MsgStartTaskResponse\x12S\n\tAbortTask\x12\x1e.neurion.crucible.MsgAbortTask\x1a&.neurion.crucible.MsgAbortTaskResponse\x12\x8c\x01\n\x1cTriggerTaskToFinalSubmission\x12\x31.neurion.crucible.MsgTriggerTaskToFinalSubmission\x1a\x39.neurion.crucible.MsgTriggerTaskToFinalSubmissionResponse\x12\x83\x01\n\x19TriggerTaskToFinalTesting\x12..neurion.crucible.MsgTriggerTaskToFinalTesting\x1a\x36.neurion.crucible.MsgTriggerTaskToFinalTestingResponse\x12_\n\rTerminateTask\x12\".neurion.crucible.MsgTerminateTask\x1a*.neurion.crucible.MsgTerminateTaskResponse\x12\x65\n\x0f\x43laimTaskReward\x12$.neurion.crucible.MsgClaimTaskReward\x1a,.neurion.crucible.MsgClaimTaskRewardResponse\x12\x65\n\x0fUnstakeFromTask\x12$.neurion.crucible.MsgUnstakeFromTask\x1a,.neurion.crucible.MsgUnstakeFromTaskResponse\x12w\n\x15\x44isclaimCreatorStatus\x12*.neurion.crucible.MsgDisclaimCreatorStatus\x1a\x32.neurion.crucible.MsgDisclaimCreatorStatusResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\"neurion/x/crucible/MsgUpdateParams'
  _globals['_MSGAPPLYCREATOR']._loaded_options = None
  _globals['_MSGAPPLYCREATOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGAPPROVEAPPLICATION']._loaded_options = None
  _globals['_MSGAPPROVEAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREJECTAPPLICATION']._loaded_options = None
  _globals['_MSGREJECTAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCREATETASK']._loaded_options = None
  _globals['_MSGCREATETASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCREATETASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_MSGCREATETASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGREGISTERTRAINER']._loaded_options = None
  _globals['_MSGREGISTERTRAINER']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREGISTERSCORER']._loaded_options = None
  _globals['_MSGREGISTERSCORER']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSUBMITTRAININGRESULT']._loaded_options = None
  _globals['_MSGSUBMITTRAININGRESULT']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSUBMITTRAININGRESULTRESPONSE'].fields_by_name['submission']._loaded_options = None
  _globals['_MSGSUBMITTRAININGRESULTRESPONSE'].fields_by_name['submission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGSTAKETOTASK']._loaded_options = None
  _globals['_MSGSTAKETOTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREQUESTSCORINGTASK']._loaded_options = None
  _globals['_MSGREQUESTSCORINGTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREQUESTSCORINGTASKRESPONSE'].fields_by_name['score_task']._loaded_options = None
  _globals['_MSGREQUESTSCORINGTASKRESPONSE'].fields_by_name['score_task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGSUBMITSCORE']._loaded_options = None
  _globals['_MSGSUBMITSCORE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSUBMITSCORERESPONSE'].fields_by_name['score_task']._loaded_options = None
  _globals['_MSGSUBMITSCORERESPONSE'].fields_by_name['score_task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGSUBMITFINALRESULT']._loaded_options = None
  _globals['_MSGSUBMITFINALRESULT']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREPORTMODELPLAGIARISM']._loaded_options = None
  _globals['_MSGREPORTMODELPLAGIARISM']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREPORTMODELPLAGIARISMRESPONSE'].fields_by_name['report']._loaded_options = None
  _globals['_MSGREPORTMODELPLAGIARISMRESPONSE'].fields_by_name['report']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGACCEPTPLAGIARISMREPORT']._loaded_options = None
  _globals['_MSGACCEPTPLAGIARISMREPORT']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGACCEPTPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._loaded_options = None
  _globals['_MSGACCEPTPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGREJECTPLAGIARISMREPORT']._loaded_options = None
  _globals['_MSGREJECTPLAGIARISMREPORT']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREJECTPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._loaded_options = None
  _globals['_MSGREJECTPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGDISPUTESUBMISSIONSCORE']._loaded_options = None
  _globals['_MSGDISPUTESUBMISSIONSCORE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGDISPUTESUBMISSIONSCORERESPONSE'].fields_by_name['dispute_score_task']._loaded_options = None
  _globals['_MSGDISPUTESUBMISSIONSCORERESPONSE'].fields_by_name['dispute_score_task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGSTARTTASK']._loaded_options = None
  _globals['_MSGSTARTTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGABORTTASK']._loaded_options = None
  _globals['_MSGABORTTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGTRIGGERTASKTOFINALSUBMISSION']._loaded_options = None
  _globals['_MSGTRIGGERTASKTOFINALSUBMISSION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGTRIGGERTASKTOFINALTESTING']._loaded_options = None
  _globals['_MSGTRIGGERTASKTOFINALTESTING']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGTERMINATETASK']._loaded_options = None
  _globals['_MSGTERMINATETASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCLAIMTASKREWARD']._loaded_options = None
  _globals['_MSGCLAIMTASKREWARD']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGUNSTAKEFROMTASK']._loaded_options = None
  _globals['_MSGUNSTAKEFROMTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGDISCLAIMCREATORSTATUS']._loaded_options = None
  _globals['_MSGDISCLAIMCREATORSTATUS']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=356
  _globals['_MSGUPDATEPARAMS']._serialized_end=526
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=528
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=553
  _globals['_MSGAPPLYCREATOR']._serialized_start=555
  _globals['_MSGAPPLYCREATOR']._serialized_end=624
  _globals['_MSGAPPLYCREATORRESPONSE']._serialized_start=626
  _globals['_MSGAPPLYCREATORRESPONSE']._serialized_end=651
  _globals['_MSGAPPROVEAPPLICATION']._serialized_start=653
  _globals['_MSGAPPROVEAPPLICATION']._serialized_end=747
  _globals['_MSGAPPROVEAPPLICATIONRESPONSE']._serialized_start=749
  _globals['_MSGAPPROVEAPPLICATIONRESPONSE']._serialized_end=780
  _globals['_MSGREJECTAPPLICATION']._serialized_start=782
  _globals['_MSGREJECTAPPLICATION']._serialized_end=875
  _globals['_MSGREJECTAPPLICATIONRESPONSE']._serialized_start=877
  _globals['_MSGREJECTAPPLICATIONRESPONSE']._serialized_end=907
  _globals['_MSGCREATETASK']._serialized_start=910
  _globals['_MSGCREATETASK']._serialized_end=1079
  _globals['_MSGCREATETASKRESPONSE']._serialized_start=1081
  _globals['_MSGCREATETASKRESPONSE']._serialized_end=1153
  _globals['_MSGREGISTERTRAINER']._serialized_start=1155
  _globals['_MSGREGISTERTRAINER']._serialized_end=1238
  _globals['_MSGREGISTERTRAINERRESPONSE']._serialized_start=1240
  _globals['_MSGREGISTERTRAINERRESPONSE']._serialized_end=1268
  _globals['_MSGREGISTERSCORER']._serialized_start=1270
  _globals['_MSGREGISTERSCORER']._serialized_end=1352
  _globals['_MSGREGISTERSCORERRESPONSE']._serialized_start=1354
  _globals['_MSGREGISTERSCORERRESPONSE']._serialized_end=1381
  _globals['_MSGSUBMITTRAININGRESULT']._serialized_start=1384
  _globals['_MSGSUBMITTRAININGRESULT']._serialized_end=1529
  _globals['_MSGSUBMITTRAININGRESULTRESPONSE']._serialized_start=1531
  _globals['_MSGSUBMITTRAININGRESULTRESPONSE']._serialized_end=1625
  _globals['_MSGSTAKETOTASK']._serialized_start=1627
  _globals['_MSGSTAKETOTASK']._serialized_end=1707
  _globals['_MSGSTAKETOTASKRESPONSE']._serialized_start=1709
  _globals['_MSGSTAKETOTASKRESPONSE']._serialized_end=1733
  _globals['_MSGREQUESTSCORINGTASK']._serialized_start=1735
  _globals['_MSGREQUESTSCORINGTASK']._serialized_end=1806
  _globals['_MSGREQUESTSCORINGTASKRESPONSE']._serialized_start=1808
  _globals['_MSGREQUESTSCORINGTASKRESPONSE']._serialized_end=1899
  _globals['_MSGSUBMITSCORE']._serialized_start=1901
  _globals['_MSGSUBMITSCORE']._serialized_end=1986
  _globals['_MSGSUBMITSCORERESPONSE']._serialized_start=1988
  _globals['_MSGSUBMITSCORERESPONSE']._serialized_end=2072
  _globals['_MSGSUBMITFINALRESULT']._serialized_start=2075
  _globals['_MSGSUBMITFINALRESULT']._serialized_end=2217
  _globals['_MSGSUBMITFINALRESULTRESPONSE']._serialized_start=2219
  _globals['_MSGSUBMITFINALRESULTRESPONSE']._serialized_end=2249
  _globals['_MSGREPORTMODELPLAGIARISM']._serialized_start=2252
  _globals['_MSGREPORTMODELPLAGIARISM']._serialized_end=2389
  _globals['_MSGREPORTMODELPLAGIARISMRESPONSE']._serialized_start=2391
  _globals['_MSGREPORTMODELPLAGIARISMRESPONSE']._serialized_end=2488
  _globals['_MSGACCEPTPLAGIARISMREPORT']._serialized_start=2490
  _globals['_MSGACCEPTPLAGIARISMREPORT']._serialized_end=2596
  _globals['_MSGACCEPTPLAGIARISMREPORTRESPONSE']._serialized_start=2598
  _globals['_MSGACCEPTPLAGIARISMREPORTRESPONSE']._serialized_end=2696
  _globals['_MSGREJECTPLAGIARISMREPORT']._serialized_start=2698
  _globals['_MSGREJECTPLAGIARISMREPORT']._serialized_end=2791
  _globals['_MSGREJECTPLAGIARISMREPORTRESPONSE']._serialized_start=2793
  _globals['_MSGREJECTPLAGIARISMREPORTRESPONSE']._serialized_end=2891
  _globals['_MSGDISPUTESUBMISSIONSCORE']._serialized_start=2893
  _globals['_MSGDISPUTESUBMISSIONSCORE']._serialized_end=2989
  _globals['_MSGDISPUTESUBMISSIONSCORERESPONSE']._serialized_start=2991
  _globals['_MSGDISPUTESUBMISSIONSCORERESPONSE']._serialized_end=3101
  _globals['_MSGSTARTTASK']._serialized_start=3103
  _globals['_MSGSTARTTASK']._serialized_end=3165
  _globals['_MSGSTARTTASKRESPONSE']._serialized_start=3167
  _globals['_MSGSTARTTASKRESPONSE']._serialized_end=3189
  _globals['_MSGABORTTASK']._serialized_start=3191
  _globals['_MSGABORTTASK']._serialized_end=3253
  _globals['_MSGABORTTASKRESPONSE']._serialized_start=3255
  _globals['_MSGABORTTASKRESPONSE']._serialized_end=3277
  _globals['_MSGTRIGGERTASKTOFINALSUBMISSION']._serialized_start=3279
  _globals['_MSGTRIGGERTASKTOFINALSUBMISSION']._serialized_end=3360
  _globals['_MSGTRIGGERTASKTOFINALSUBMISSIONRESPONSE']._serialized_start=3362
  _globals['_MSGTRIGGERTASKTOFINALSUBMISSIONRESPONSE']._serialized_end=3403
  _globals['_MSGTRIGGERTASKTOFINALTESTING']._serialized_start=3405
  _globals['_MSGTRIGGERTASKTOFINALTESTING']._serialized_end=3501
  _globals['_MSGTRIGGERTASKTOFINALTESTINGRESPONSE']._serialized_start=3503
  _globals['_MSGTRIGGERTASKTOFINALTESTINGRESPONSE']._serialized_end=3541
  _globals['_MSGTERMINATETASK']._serialized_start=3543
  _globals['_MSGTERMINATETASK']._serialized_end=3609
  _globals['_MSGTERMINATETASKRESPONSE']._serialized_start=3611
  _globals['_MSGTERMINATETASKRESPONSE']._serialized_end=3637
  _globals['_MSGCLAIMTASKREWARD']._serialized_start=3639
  _globals['_MSGCLAIMTASKREWARD']._serialized_end=3707
  _globals['_MSGCLAIMTASKREWARDRESPONSE']._serialized_start=3709
  _globals['_MSGCLAIMTASKREWARDRESPONSE']._serialized_end=3737
  _globals['_MSGUNSTAKEFROMTASK']._serialized_start=3739
  _globals['_MSGUNSTAKEFROMTASK']._serialized_end=3807
  _globals['_MSGUNSTAKEFROMTASKRESPONSE']._serialized_start=3809
  _globals['_MSGUNSTAKEFROMTASKRESPONSE']._serialized_end=3837
  _globals['_MSGDISCLAIMCREATORSTATUS']._serialized_start=3839
  _globals['_MSGDISCLAIMCREATORSTATUS']._serialized_end=3912
  _globals['_MSGDISCLAIMCREATORSTATUSRESPONSE']._serialized_start=3914
  _globals['_MSGDISCLAIMCREATORSTATUSRESPONSE']._serialized_end=3948
  _globals['_MSG']._serialized_start=3951
  _globals['_MSG']._serialized_end=6548
# @@protoc_insertion_point(module_scope)
