# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/abci/v2/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/abci/v2/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.crypto.v1 import proof_pb2 as cometbft_dot_crypto_dot_v1_dot_proof__pb2
from cometbft.types.v2 import params_pb2 as cometbft_dot_types_dot_v2_dot_params__pb2
from cometbft.types.v2 import validator_pb2 as cometbft_dot_types_dot_v2_dot_validator__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63ometbft/abci/v2/types.proto\x12\x10\x63ometbft.abci.v2\x1a\x1e\x63ometbft/crypto/v1/proof.proto\x1a\x1e\x63ometbft/types/v2/params.proto\x1a!cometbft/types/v2/validator.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\x82\x08\n\x07Request\x12-\n\x04\x65\x63ho\x18\x01 \x01(\x0b\x32\x1d.cometbft.abci.v2.EchoRequestH\x00\x12/\n\x05\x66lush\x18\x02 \x01(\x0b\x32\x1e.cometbft.abci.v2.FlushRequestH\x00\x12-\n\x04info\x18\x03 \x01(\x0b\x32\x1d.cometbft.abci.v2.InfoRequestH\x00\x12\x38\n\ninit_chain\x18\x05 \x01(\x0b\x32\".cometbft.abci.v2.InitChainRequestH\x00\x12/\n\x05query\x18\x06 \x01(\x0b\x32\x1e.cometbft.abci.v2.QueryRequestH\x00\x12\x34\n\x08\x63heck_tx\x18\x08 \x01(\x0b\x32 .cometbft.abci.v2.CheckTxRequestH\x00\x12\x31\n\x06\x63ommit\x18\x0b \x01(\x0b\x32\x1f.cometbft.abci.v2.CommitRequestH\x00\x12@\n\x0elist_snapshots\x18\x0c \x01(\x0b\x32&.cometbft.abci.v2.ListSnapshotsRequestH\x00\x12@\n\x0eoffer_snapshot\x18\r \x01(\x0b\x32&.cometbft.abci.v2.OfferSnapshotRequestH\x00\x12I\n\x13load_snapshot_chunk\x18\x0e \x01(\x0b\x32*.cometbft.abci.v2.LoadSnapshotChunkRequestH\x00\x12K\n\x14\x61pply_snapshot_chunk\x18\x0f \x01(\x0b\x32+.cometbft.abci.v2.ApplySnapshotChunkRequestH\x00\x12\x44\n\x10prepare_proposal\x18\x10 \x01(\x0b\x32(.cometbft.abci.v2.PrepareProposalRequestH\x00\x12\x44\n\x10process_proposal\x18\x11 \x01(\x0b\x32(.cometbft.abci.v2.ProcessProposalRequestH\x00\x12:\n\x0b\x65xtend_vote\x18\x12 \x01(\x0b\x32#.cometbft.abci.v2.ExtendVoteRequestH\x00\x12M\n\x15verify_vote_extension\x18\x13 \x01(\x0b\x32,.cometbft.abci.v2.VerifyVoteExtensionRequestH\x00\x12@\n\x0e\x66inalize_block\x18\x14 \x01(\x0b\x32&.cometbft.abci.v2.FinalizeBlockRequestH\x00\x42\x07\n\x05valueJ\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"\x1e\n\x0b\x45\x63hoRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x0e\n\x0c\x46lushRequest\"`\n\x0bInfoRequest\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rblock_version\x18\x02 \x01(\x04\x12\x13\n\x0bp2p_version\x18\x03 \x01(\x04\x12\x14\n\x0c\x61\x62\x63i_version\x18\x04 \x01(\t\"\x84\x02\n\x10InitChainRequest\x12\x32\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\x12<\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32\".cometbft.types.v2.ConsensusParams\x12;\n\nvalidators\x18\x04 \x03(\x0b\x32!.cometbft.abci.v2.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x17\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0c\x12\x16\n\x0einitial_height\x18\x06 \x01(\x03\"I\n\x0cQueryRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\r\n\x05prove\x18\x04 \x01(\x08\"O\n\x0e\x43heckTxRequest\x12\n\n\x02tx\x18\x01 \x01(\x0c\x12+\n\x04type\x18\x03 \x01(\x0e\x32\x1d.cometbft.abci.v2.CheckTxTypeJ\x04\x08\x02\x10\x03\"\x0f\n\rCommitRequest\"\x16\n\x14ListSnapshotsRequest\"V\n\x14OfferSnapshotRequest\x12,\n\x08snapshot\x18\x01 \x01(\x0b\x32\x1a.cometbft.abci.v2.Snapshot\x12\x10\n\x08\x61pp_hash\x18\x02 \x01(\x0c\"I\n\x18LoadSnapshotChunkRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\r\n\x05\x63hunk\x18\x03 \x01(\r\"I\n\x19\x41pplySnapshotChunkRequest\x12\r\n\x05index\x18\x01 \x01(\r\x12\r\n\x05\x63hunk\x18\x02 \x01(\x0c\x12\x0e\n\x06sender\x18\x03 \x01(\t\"\xb8\x02\n\x16PrepareProposalRequest\x12\x14\n\x0cmax_tx_bytes\x18\x01 \x01(\x03\x12\x0b\n\x03txs\x18\x02 \x03(\x0c\x12\x45\n\x11local_last_commit\x18\x03 \x01(\x0b\x32$.cometbft.abci.v2.ExtendedCommitInfoB\x04\xc8\xde\x1f\x00\x12\x38\n\x0bmisbehavior\x18\x04 \x03(\x0b\x32\x1d.cometbft.abci.v2.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x05 \x01(\x03\x12\x32\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"\xab\x02\n\x16ProcessProposalRequest\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\x12@\n\x14proposed_last_commit\x18\x02 \x01(\x0b\x32\x1c.cometbft.abci.v2.CommitInfoB\x04\xc8\xde\x1f\x00\x12\x38\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\x1d.cometbft.abci.v2.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x0e\n\x06height\x18\x05 \x01(\x03\x12\x32\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"\xa6\x02\n\x11\x45xtendVoteRequest\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x32\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x0b\n\x03txs\x18\x04 \x03(\x0c\x12@\n\x14proposed_last_commit\x18\x05 \x01(\x0b\x32\x1c.cometbft.abci.v2.CommitInfoB\x04\xc8\xde\x1f\x00\x12\x38\n\x0bmisbehavior\x18\x06 \x03(\x0b\x32\x1d.cometbft.abci.v2.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"\x8c\x01\n\x1aVerifyVoteExtensionRequest\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x19\n\x11validator_address\x18\x02 \x01(\x0c\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x16\n\x0evote_extension\x18\x04 \x01(\x0c\x12\x1d\n\x15non_rp_vote_extension\x18\x05 \x01(\x0c\"\xc3\x02\n\x14\x46inalizeBlockRequest\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\x12?\n\x13\x64\x65\x63ided_last_commit\x18\x02 \x01(\x0b\x32\x1c.cometbft.abci.v2.CommitInfoB\x04\xc8\xde\x1f\x00\x12\x38\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\x1d.cometbft.abci.v2.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x0e\n\x06height\x18\x05 \x01(\x03\x12\x32\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\x12\x19\n\x11syncing_to_height\x18\t \x01(\x03\"\xcd\x08\n\x08Response\x12\x38\n\texception\x18\x01 \x01(\x0b\x32#.cometbft.abci.v2.ExceptionResponseH\x00\x12.\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x1e.cometbft.abci.v2.EchoResponseH\x00\x12\x30\n\x05\x66lush\x18\x03 \x01(\x0b\x32\x1f.cometbft.abci.v2.FlushResponseH\x00\x12.\n\x04info\x18\x04 \x01(\x0b\x32\x1e.cometbft.abci.v2.InfoResponseH\x00\x12\x39\n\ninit_chain\x18\x06 \x01(\x0b\x32#.cometbft.abci.v2.InitChainResponseH\x00\x12\x30\n\x05query\x18\x07 \x01(\x0b\x32\x1f.cometbft.abci.v2.QueryResponseH\x00\x12\x35\n\x08\x63heck_tx\x18\t \x01(\x0b\x32!.cometbft.abci.v2.CheckTxResponseH\x00\x12\x32\n\x06\x63ommit\x18\x0c \x01(\x0b\x32 .cometbft.abci.v2.CommitResponseH\x00\x12\x41\n\x0elist_snapshots\x18\r \x01(\x0b\x32\'.cometbft.abci.v2.ListSnapshotsResponseH\x00\x12\x41\n\x0eoffer_snapshot\x18\x0e \x01(\x0b\x32\'.cometbft.abci.v2.OfferSnapshotResponseH\x00\x12J\n\x13load_snapshot_chunk\x18\x0f \x01(\x0b\x32+.cometbft.abci.v2.LoadSnapshotChunkResponseH\x00\x12L\n\x14\x61pply_snapshot_chunk\x18\x10 \x01(\x0b\x32,.cometbft.abci.v2.ApplySnapshotChunkResponseH\x00\x12\x45\n\x10prepare_proposal\x18\x11 \x01(\x0b\x32).cometbft.abci.v2.PrepareProposalResponseH\x00\x12\x45\n\x10process_proposal\x18\x12 \x01(\x0b\x32).cometbft.abci.v2.ProcessProposalResponseH\x00\x12;\n\x0b\x65xtend_vote\x18\x13 \x01(\x0b\x32$.cometbft.abci.v2.ExtendVoteResponseH\x00\x12N\n\x15verify_vote_extension\x18\x14 \x01(\x0b\x32-.cometbft.abci.v2.VerifyVoteExtensionResponseH\x00\x12\x41\n\x0e\x66inalize_block\x18\x15 \x01(\x0b\x32\'.cometbft.abci.v2.FinalizeBlockResponseH\x00\x42\x07\n\x05valueJ\x04\x08\x05\x10\x06J\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0c\"\"\n\x11\x45xceptionResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\x1f\n\x0c\x45\x63hoResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x0f\n\rFlushResponse\"\x94\x02\n\x0cInfoResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x03 \x01(\x04\x12\x19\n\x11last_block_height\x18\x04 \x01(\x03\x12\x1b\n\x13last_block_app_hash\x18\x05 \x01(\x0c\x12K\n\x0flane_priorities\x18\x06 \x03(\x0b\x32\x32.cometbft.abci.v2.InfoResponse.LanePrioritiesEntry\x12\x14\n\x0c\x64\x65\x66\x61ult_lane\x18\x07 \x01(\t\x1a\x35\n\x13LanePrioritiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"\xa0\x01\n\x11InitChainResponse\x12<\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\".cometbft.types.v2.ConsensusParams\x12;\n\nvalidators\x18\x02 \x03(\x0b\x32!.cometbft.abci.v2.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x10\n\x08\x61pp_hash\x18\x03 \x01(\x0c\"\xb7\x01\n\rQueryResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x03\x12\x0b\n\x03key\x18\x06 \x01(\x0c\x12\r\n\x05value\x18\x07 \x01(\x0c\x12/\n\tproof_ops\x18\x08 \x01(\x0b\x32\x1c.cometbft.crypto.v1.ProofOps\x12\x0e\n\x06height\x18\t \x01(\x03\x12\x11\n\tcodespace\x18\n \x01(\t\"\x92\x02\n\x0f\x43heckTxResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12\x41\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x17.cometbft.abci.v2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t\x12\x0f\n\x07lane_id\x18\x0c \x01(\tJ\x04\x08\t\x10\x0cR\x06senderR\x08priorityR\rmempool_error\"3\n\x0e\x43ommitResponse\x12\x15\n\rretain_height\x18\x03 \x01(\x03J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"F\n\x15ListSnapshotsResponse\x12-\n\tsnapshots\x18\x01 \x03(\x0b\x32\x1a.cometbft.abci.v2.Snapshot\"N\n\x15OfferSnapshotResponse\x12\x35\n\x06result\x18\x01 \x01(\x0e\x32%.cometbft.abci.v2.OfferSnapshotResult\"*\n\x19LoadSnapshotChunkResponse\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\"\x88\x01\n\x1a\x41pplySnapshotChunkResponse\x12:\n\x06result\x18\x01 \x01(\x0e\x32*.cometbft.abci.v2.ApplySnapshotChunkResult\x12\x16\n\x0erefetch_chunks\x18\x02 \x03(\r\x12\x16\n\x0ereject_senders\x18\x03 \x03(\t\"&\n\x17PrepareProposalResponse\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\"R\n\x17ProcessProposalResponse\x12\x37\n\x06status\x18\x01 \x01(\x0e\x32\'.cometbft.abci.v2.ProcessProposalStatus\"F\n\x12\x45xtendVoteResponse\x12\x16\n\x0evote_extension\x18\x01 \x01(\x0c\x12\x18\n\x10non_rp_extension\x18\x02 \x01(\x0c\"Z\n\x1bVerifyVoteExtensionResponse\x12;\n\x06status\x18\x01 \x01(\x0e\x32+.cometbft.abci.v2.VerifyVoteExtensionStatus\"\xe8\x02\n\x15\x46inalizeBlockResponse\x12\x41\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x17.cometbft.abci.v2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x32\n\ntx_results\x18\x02 \x03(\x0b\x32\x1e.cometbft.abci.v2.ExecTxResult\x12\x42\n\x11validator_updates\x18\x03 \x03(\x0b\x32!.cometbft.abci.v2.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x43\n\x17\x63onsensus_param_updates\x18\x04 \x01(\x0b\x32\".cometbft.types.v2.ConsensusParams\x12\x10\n\x08\x61pp_hash\x18\x05 \x01(\x0c\x12=\n\x10next_block_delay\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\"L\n\nCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12/\n\x05votes\x18\x02 \x03(\x0b\x32\x1a.cometbft.abci.v2.VoteInfoB\x04\xc8\xde\x1f\x00\"\\\n\x12\x45xtendedCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12\x37\n\x05votes\x18\x02 \x03(\x0b\x32\".cometbft.abci.v2.ExtendedVoteInfoB\x04\xc8\xde\x1f\x00\"i\n\x05\x45vent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12R\n\nattributes\x18\x02 \x03(\x0b\x32 .cometbft.abci.v2.EventAttributeB\x1c\xc8\xde\x1f\x00\xea\xde\x1f\x14\x61ttributes,omitempty\";\n\x0e\x45ventAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x08\"\xd7\x01\n\x0c\x45xecTxResult\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12\x41\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x17.cometbft.abci.v2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t\"k\n\x08TxResult\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05index\x18\x02 \x01(\r\x12\n\n\x02tx\x18\x03 \x01(\x0c\x12\x34\n\x06result\x18\x04 \x01(\x0b\x32\x1e.cometbft.abci.v2.ExecTxResultB\x04\xc8\xde\x1f\x00\"+\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\r\n\x05power\x18\x03 \x01(\x03\"S\n\x0fValidatorUpdate\x12\r\n\x05power\x18\x02 \x01(\x03\x12\x15\n\rpub_key_bytes\x18\x03 \x01(\x0c\x12\x14\n\x0cpub_key_type\x18\x04 \x01(\tJ\x04\x08\x01\x10\x02\"}\n\x08VoteInfo\x12\x34\n\tvalidator\x18\x01 \x01(\x0b\x32\x1b.cometbft.abci.v2.ValidatorB\x04\xc8\xde\x1f\x00\x12\x35\n\rblock_id_flag\x18\x03 \x01(\x0e\x32\x1e.cometbft.types.v2.BlockIDFlagJ\x04\x08\x02\x10\x03\"\xfd\x01\n\x10\x45xtendedVoteInfo\x12\x34\n\tvalidator\x18\x01 \x01(\x0b\x32\x1b.cometbft.abci.v2.ValidatorB\x04\xc8\xde\x1f\x00\x12\x16\n\x0evote_extension\x18\x03 \x01(\x0c\x12\x1b\n\x13\x65xtension_signature\x18\x04 \x01(\x0c\x12\x35\n\rblock_id_flag\x18\x05 \x01(\x0e\x32\x1e.cometbft.types.v2.BlockIDFlag\x12\x1d\n\x15non_rp_vote_extension\x18\x06 \x01(\x0c\x12\"\n\x1anon_rp_extension_signature\x18\x07 \x01(\x0cJ\x04\x08\x02\x10\x03\"\xd4\x01\n\x0bMisbehavior\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.cometbft.abci.v2.MisbehaviorType\x12\x34\n\tvalidator\x18\x02 \x01(\x0b\x32\x1b.cometbft.abci.v2.ValidatorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x32\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1a\n\x12total_voting_power\x18\x05 \x01(\x03\"Z\n\x08Snapshot\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\x0e\n\x06\x63hunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x10\n\x08metadata\x18\x05 \x01(\x0c*b\n\x0b\x43heckTxType\x12\x19\n\x15\x43HECK_TX_TYPE_UNKNOWN\x10\x00\x12\x19\n\x15\x43HECK_TX_TYPE_RECHECK\x10\x01\x12\x17\n\x13\x43HECK_TX_TYPE_CHECK\x10\x02\x1a\x04\x88\xa3\x1e\x00*\xf5\x01\n\x13OfferSnapshotResult\x12!\n\x1dOFFER_SNAPSHOT_RESULT_UNKNOWN\x10\x00\x12 \n\x1cOFFER_SNAPSHOT_RESULT_ACCEPT\x10\x01\x12\x1f\n\x1bOFFER_SNAPSHOT_RESULT_ABORT\x10\x02\x12 \n\x1cOFFER_SNAPSHOT_RESULT_REJECT\x10\x03\x12\'\n#OFFER_SNAPSHOT_RESULT_REJECT_FORMAT\x10\x04\x12\'\n#OFFER_SNAPSHOT_RESULT_REJECT_SENDER\x10\x05\x1a\x04\x88\xa3\x1e\x00*\xa0\x02\n\x18\x41pplySnapshotChunkResult\x12\'\n#APPLY_SNAPSHOT_CHUNK_RESULT_UNKNOWN\x10\x00\x12&\n\"APPLY_SNAPSHOT_CHUNK_RESULT_ACCEPT\x10\x01\x12%\n!APPLY_SNAPSHOT_CHUNK_RESULT_ABORT\x10\x02\x12%\n!APPLY_SNAPSHOT_CHUNK_RESULT_RETRY\x10\x03\x12.\n*APPLY_SNAPSHOT_CHUNK_RESULT_RETRY_SNAPSHOT\x10\x04\x12/\n+APPLY_SNAPSHOT_CHUNK_RESULT_REJECT_SNAPSHOT\x10\x05\x1a\x04\x88\xa3\x1e\x00*\x8a\x01\n\x15ProcessProposalStatus\x12#\n\x1fPROCESS_PROPOSAL_STATUS_UNKNOWN\x10\x00\x12\"\n\x1ePROCESS_PROPOSAL_STATUS_ACCEPT\x10\x01\x12\"\n\x1ePROCESS_PROPOSAL_STATUS_REJECT\x10\x02\x1a\x04\x88\xa3\x1e\x00*\x9d\x01\n\x19VerifyVoteExtensionStatus\x12(\n$VERIFY_VOTE_EXTENSION_STATUS_UNKNOWN\x10\x00\x12\'\n#VERIFY_VOTE_EXTENSION_STATUS_ACCEPT\x10\x01\x12\'\n#VERIFY_VOTE_EXTENSION_STATUS_REJECT\x10\x02\x1a\x04\x88\xa3\x1e\x00*\x84\x01\n\x0fMisbehaviorType\x12\x1c\n\x18MISBEHAVIOR_TYPE_UNKNOWN\x10\x00\x12#\n\x1fMISBEHAVIOR_TYPE_DUPLICATE_VOTE\x10\x01\x12(\n$MISBEHAVIOR_TYPE_LIGHT_CLIENT_ATTACK\x10\x02\x1a\x04\x88\xa3\x1e\x00\x42\x33Z1github.com/cometbft/cometbft/api/cometbft/abci/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.abci.v2.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cometbft/cometbft/api/cometbft/abci/v2'
  _globals['_CHECKTXTYPE']._loaded_options = None
  _globals['_CHECKTXTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_OFFERSNAPSHOTRESULT']._loaded_options = None
  _globals['_OFFERSNAPSHOTRESULT']._serialized_options = b'\210\243\036\000'
  _globals['_APPLYSNAPSHOTCHUNKRESULT']._loaded_options = None
  _globals['_APPLYSNAPSHOTCHUNKRESULT']._serialized_options = b'\210\243\036\000'
  _globals['_PROCESSPROPOSALSTATUS']._loaded_options = None
  _globals['_PROCESSPROPOSALSTATUS']._serialized_options = b'\210\243\036\000'
  _globals['_VERIFYVOTEEXTENSIONSTATUS']._loaded_options = None
  _globals['_VERIFYVOTEEXTENSIONSTATUS']._serialized_options = b'\210\243\036\000'
  _globals['_MISBEHAVIORTYPE']._loaded_options = None
  _globals['_MISBEHAVIORTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_INITCHAINREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_INITCHAINREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_INITCHAINREQUEST'].fields_by_name['validators']._loaded_options = None
  _globals['_INITCHAINREQUEST'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['local_last_commit']._loaded_options = None
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['local_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['decided_last_commit']._loaded_options = None
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['decided_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_INFORESPONSE_LANEPRIORITIESENTRY']._loaded_options = None
  _globals['_INFORESPONSE_LANEPRIORITIESENTRY']._serialized_options = b'8\001'
  _globals['_INITCHAINRESPONSE'].fields_by_name['validators']._loaded_options = None
  _globals['_INITCHAINRESPONSE'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_CHECKTXRESPONSE'].fields_by_name['events']._loaded_options = None
  _globals['_CHECKTXRESPONSE'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['events']._loaded_options = None
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['next_block_delay']._loaded_options = None
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['next_block_delay']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_COMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_COMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EVENT'].fields_by_name['attributes']._loaded_options = None
  _globals['_EVENT'].fields_by_name['attributes']._serialized_options = b'\310\336\037\000\352\336\037\024attributes,omitempty'
  _globals['_EXECTXRESULT'].fields_by_name['events']._loaded_options = None
  _globals['_EXECTXRESULT'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_TXRESULT'].fields_by_name['result']._loaded_options = None
  _globals['_TXRESULT'].fields_by_name['result']._serialized_options = b'\310\336\037\000'
  _globals['_VOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_VOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_MISBEHAVIOR'].fields_by_name['validator']._loaded_options = None
  _globals['_MISBEHAVIOR'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_MISBEHAVIOR'].fields_by_name['time']._loaded_options = None
  _globals['_MISBEHAVIOR'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_CHECKTXTYPE']._serialized_start=8113
  _globals['_CHECKTXTYPE']._serialized_end=8211
  _globals['_OFFERSNAPSHOTRESULT']._serialized_start=8214
  _globals['_OFFERSNAPSHOTRESULT']._serialized_end=8459
  _globals['_APPLYSNAPSHOTCHUNKRESULT']._serialized_start=8462
  _globals['_APPLYSNAPSHOTCHUNKRESULT']._serialized_end=8750
  _globals['_PROCESSPROPOSALSTATUS']._serialized_start=8753
  _globals['_PROCESSPROPOSALSTATUS']._serialized_end=8891
  _globals['_VERIFYVOTEEXTENSIONSTATUS']._serialized_start=8894
  _globals['_VERIFYVOTEEXTENSIONSTATUS']._serialized_end=9051
  _globals['_MISBEHAVIORTYPE']._serialized_start=9054
  _globals['_MISBEHAVIORTYPE']._serialized_end=9186
  _globals['_REQUEST']._serialized_start=237
  _globals['_REQUEST']._serialized_end=1263
  _globals['_ECHOREQUEST']._serialized_start=1265
  _globals['_ECHOREQUEST']._serialized_end=1295
  _globals['_FLUSHREQUEST']._serialized_start=1297
  _globals['_FLUSHREQUEST']._serialized_end=1311
  _globals['_INFOREQUEST']._serialized_start=1313
  _globals['_INFOREQUEST']._serialized_end=1409
  _globals['_INITCHAINREQUEST']._serialized_start=1412
  _globals['_INITCHAINREQUEST']._serialized_end=1672
  _globals['_QUERYREQUEST']._serialized_start=1674
  _globals['_QUERYREQUEST']._serialized_end=1747
  _globals['_CHECKTXREQUEST']._serialized_start=1749
  _globals['_CHECKTXREQUEST']._serialized_end=1828
  _globals['_COMMITREQUEST']._serialized_start=1830
  _globals['_COMMITREQUEST']._serialized_end=1845
  _globals['_LISTSNAPSHOTSREQUEST']._serialized_start=1847
  _globals['_LISTSNAPSHOTSREQUEST']._serialized_end=1869
  _globals['_OFFERSNAPSHOTREQUEST']._serialized_start=1871
  _globals['_OFFERSNAPSHOTREQUEST']._serialized_end=1957
  _globals['_LOADSNAPSHOTCHUNKREQUEST']._serialized_start=1959
  _globals['_LOADSNAPSHOTCHUNKREQUEST']._serialized_end=2032
  _globals['_APPLYSNAPSHOTCHUNKREQUEST']._serialized_start=2034
  _globals['_APPLYSNAPSHOTCHUNKREQUEST']._serialized_end=2107
  _globals['_PREPAREPROPOSALREQUEST']._serialized_start=2110
  _globals['_PREPAREPROPOSALREQUEST']._serialized_end=2422
  _globals['_PROCESSPROPOSALREQUEST']._serialized_start=2425
  _globals['_PROCESSPROPOSALREQUEST']._serialized_end=2724
  _globals['_EXTENDVOTEREQUEST']._serialized_start=2727
  _globals['_EXTENDVOTEREQUEST']._serialized_end=3021
  _globals['_VERIFYVOTEEXTENSIONREQUEST']._serialized_start=3024
  _globals['_VERIFYVOTEEXTENSIONREQUEST']._serialized_end=3164
  _globals['_FINALIZEBLOCKREQUEST']._serialized_start=3167
  _globals['_FINALIZEBLOCKREQUEST']._serialized_end=3490
  _globals['_RESPONSE']._serialized_start=3493
  _globals['_RESPONSE']._serialized_end=4594
  _globals['_EXCEPTIONRESPONSE']._serialized_start=4596
  _globals['_EXCEPTIONRESPONSE']._serialized_end=4630
  _globals['_ECHORESPONSE']._serialized_start=4632
  _globals['_ECHORESPONSE']._serialized_end=4663
  _globals['_FLUSHRESPONSE']._serialized_start=4665
  _globals['_FLUSHRESPONSE']._serialized_end=4680
  _globals['_INFORESPONSE']._serialized_start=4683
  _globals['_INFORESPONSE']._serialized_end=4959
  _globals['_INFORESPONSE_LANEPRIORITIESENTRY']._serialized_start=4906
  _globals['_INFORESPONSE_LANEPRIORITIESENTRY']._serialized_end=4959
  _globals['_INITCHAINRESPONSE']._serialized_start=4962
  _globals['_INITCHAINRESPONSE']._serialized_end=5122
  _globals['_QUERYRESPONSE']._serialized_start=5125
  _globals['_QUERYRESPONSE']._serialized_end=5308
  _globals['_CHECKTXRESPONSE']._serialized_start=5311
  _globals['_CHECKTXRESPONSE']._serialized_end=5585
  _globals['_COMMITRESPONSE']._serialized_start=5587
  _globals['_COMMITRESPONSE']._serialized_end=5638
  _globals['_LISTSNAPSHOTSRESPONSE']._serialized_start=5640
  _globals['_LISTSNAPSHOTSRESPONSE']._serialized_end=5710
  _globals['_OFFERSNAPSHOTRESPONSE']._serialized_start=5712
  _globals['_OFFERSNAPSHOTRESPONSE']._serialized_end=5790
  _globals['_LOADSNAPSHOTCHUNKRESPONSE']._serialized_start=5792
  _globals['_LOADSNAPSHOTCHUNKRESPONSE']._serialized_end=5834
  _globals['_APPLYSNAPSHOTCHUNKRESPONSE']._serialized_start=5837
  _globals['_APPLYSNAPSHOTCHUNKRESPONSE']._serialized_end=5973
  _globals['_PREPAREPROPOSALRESPONSE']._serialized_start=5975
  _globals['_PREPAREPROPOSALRESPONSE']._serialized_end=6013
  _globals['_PROCESSPROPOSALRESPONSE']._serialized_start=6015
  _globals['_PROCESSPROPOSALRESPONSE']._serialized_end=6097
  _globals['_EXTENDVOTERESPONSE']._serialized_start=6099
  _globals['_EXTENDVOTERESPONSE']._serialized_end=6169
  _globals['_VERIFYVOTEEXTENSIONRESPONSE']._serialized_start=6171
  _globals['_VERIFYVOTEEXTENSIONRESPONSE']._serialized_end=6261
  _globals['_FINALIZEBLOCKRESPONSE']._serialized_start=6264
  _globals['_FINALIZEBLOCKRESPONSE']._serialized_end=6624
  _globals['_COMMITINFO']._serialized_start=6626
  _globals['_COMMITINFO']._serialized_end=6702
  _globals['_EXTENDEDCOMMITINFO']._serialized_start=6704
  _globals['_EXTENDEDCOMMITINFO']._serialized_end=6796
  _globals['_EVENT']._serialized_start=6798
  _globals['_EVENT']._serialized_end=6903
  _globals['_EVENTATTRIBUTE']._serialized_start=6905
  _globals['_EVENTATTRIBUTE']._serialized_end=6964
  _globals['_EXECTXRESULT']._serialized_start=6967
  _globals['_EXECTXRESULT']._serialized_end=7182
  _globals['_TXRESULT']._serialized_start=7184
  _globals['_TXRESULT']._serialized_end=7291
  _globals['_VALIDATOR']._serialized_start=7293
  _globals['_VALIDATOR']._serialized_end=7336
  _globals['_VALIDATORUPDATE']._serialized_start=7338
  _globals['_VALIDATORUPDATE']._serialized_end=7421
  _globals['_VOTEINFO']._serialized_start=7423
  _globals['_VOTEINFO']._serialized_end=7548
  _globals['_EXTENDEDVOTEINFO']._serialized_start=7551
  _globals['_EXTENDEDVOTEINFO']._serialized_end=7804
  _globals['_MISBEHAVIOR']._serialized_start=7807
  _globals['_MISBEHAVIOR']._serialized_end=8019
  _globals['_SNAPSHOT']._serialized_start=8021
  _globals['_SNAPSHOT']._serialized_end=8111
# @@protoc_insertion_point(module_scope)
