# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/state/v1/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/state/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.abci.v1 import types_pb2 as cometbft_dot_abci_dot_v1_dot_types__pb2
from cometbft.types.v1 import params_pb2 as cometbft_dot_types_dot_v1_dot_params__pb2
from cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from cometbft.types.v1 import validator_pb2 as cometbft_dot_types_dot_v1_dot_validator__pb2
from cometbft.version.v1 import types_pb2 as cometbft_dot_version_dot_v1_dot_types__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ometbft/state/v1/types.proto\x12\x11\x63ometbft.state.v1\x1a\x1c\x63ometbft/abci/v1/types.proto\x1a\x1e\x63ometbft/types/v1/params.proto\x1a\x1d\x63ometbft/types/v1/types.proto\x1a!cometbft/types/v1/validator.proto\x1a\x1f\x63ometbft/version/v1/types.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xbe\x01\n\x13LegacyABCIResponses\x12\x33\n\x0b\x64\x65liver_txs\x18\x01 \x03(\x0b\x32\x1e.cometbft.abci.v1.ExecTxResult\x12\x36\n\tend_block\x18\x02 \x01(\x0b\x32#.cometbft.state.v1.ResponseEndBlock\x12:\n\x0b\x62\x65gin_block\x18\x03 \x01(\x0b\x32%.cometbft.state.v1.ResponseBeginBlock\"W\n\x12ResponseBeginBlock\x12\x41\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x17.cometbft.abci.v1.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\"\xde\x01\n\x10ResponseEndBlock\x12\x42\n\x11validator_updates\x18\x01 \x03(\x0b\x32!.cometbft.abci.v1.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x43\n\x17\x63onsensus_param_updates\x18\x02 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParams\x12\x41\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x17.cometbft.abci.v1.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\"e\n\x0eValidatorsInfo\x12\x36\n\rvalidator_set\x18\x01 \x01(\x0b\x32\x1f.cometbft.types.v1.ValidatorSet\x12\x1b\n\x13last_height_changed\x18\x02 \x01(\x03\"v\n\x13\x43onsensusParamsInfo\x12\x42\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsB\x04\xc8\xde\x1f\x00\x12\x1b\n\x13last_height_changed\x18\x02 \x01(\x03\"\xab\x01\n\x11\x41\x42\x43IResponsesInfo\x12\x45\n\x15legacy_abci_responses\x18\x01 \x01(\x0b\x32&.cometbft.state.v1.LegacyABCIResponses\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12?\n\x0e\x66inalize_block\x18\x03 \x01(\x0b\x32\'.cometbft.abci.v1.FinalizeBlockResponse\"T\n\x07Version\x12\x37\n\tconsensus\x18\x01 \x01(\x0b\x32\x1e.cometbft.version.v1.ConsensusB\x04\xc8\xde\x1f\x00\x12\x10\n\x08software\x18\x02 \x01(\t\"\xc2\x05\n\x05State\x12\x31\n\x07version\x18\x01 \x01(\x0b\x32\x1a.cometbft.state.v1.VersionB\x04\xc8\xde\x1f\x00\x12\x1d\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\x12\x16\n\x0einitial_height\x18\x0e \x01(\x03\x12\x19\n\x11last_block_height\x18\x03 \x01(\x03\x12\x46\n\rlast_block_id\x18\x04 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDB\x13\xc8\xde\x1f\x00\xe2\xde\x1f\x0bLastBlockID\x12=\n\x0flast_block_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x38\n\x0fnext_validators\x18\x06 \x01(\x0b\x32\x1f.cometbft.types.v1.ValidatorSet\x12\x33\n\nvalidators\x18\x07 \x01(\x0b\x32\x1f.cometbft.types.v1.ValidatorSet\x12\x38\n\x0flast_validators\x18\x08 \x01(\x0b\x32\x1f.cometbft.types.v1.ValidatorSet\x12&\n\x1elast_height_validators_changed\x18\t \x01(\x03\x12\x42\n\x10\x63onsensus_params\x18\n \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsB\x04\xc8\xde\x1f\x00\x12,\n$last_height_consensus_params_changed\x18\x0b \x01(\x03\x12\x19\n\x11last_results_hash\x18\x0c \x01(\x0c\x12\x10\n\x08\x61pp_hash\x18\r \x01(\x0c\x12=\n\x10next_block_delay\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x42\x34Z2github.com/cometbft/cometbft/api/cometbft/state/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.state.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2github.com/cometbft/cometbft/api/cometbft/state/v1'
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_CONSENSUSPARAMSINFO'].fields_by_name['consensus_params']._loaded_options = None
  _globals['_CONSENSUSPARAMSINFO'].fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _globals['_VERSION'].fields_by_name['consensus']._loaded_options = None
  _globals['_VERSION'].fields_by_name['consensus']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['version']._loaded_options = None
  _globals['_STATE'].fields_by_name['version']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['chain_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_STATE'].fields_by_name['last_block_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['last_block_id']._serialized_options = b'\310\336\037\000\342\336\037\013LastBlockID'
  _globals['_STATE'].fields_by_name['last_block_time']._loaded_options = None
  _globals['_STATE'].fields_by_name['last_block_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_STATE'].fields_by_name['consensus_params']._loaded_options = None
  _globals['_STATE'].fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['next_block_delay']._loaded_options = None
  _globals['_STATE'].fields_by_name['next_block_delay']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_LEGACYABCIRESPONSES']._serialized_start=301
  _globals['_LEGACYABCIRESPONSES']._serialized_end=491
  _globals['_RESPONSEBEGINBLOCK']._serialized_start=493
  _globals['_RESPONSEBEGINBLOCK']._serialized_end=580
  _globals['_RESPONSEENDBLOCK']._serialized_start=583
  _globals['_RESPONSEENDBLOCK']._serialized_end=805
  _globals['_VALIDATORSINFO']._serialized_start=807
  _globals['_VALIDATORSINFO']._serialized_end=908
  _globals['_CONSENSUSPARAMSINFO']._serialized_start=910
  _globals['_CONSENSUSPARAMSINFO']._serialized_end=1028
  _globals['_ABCIRESPONSESINFO']._serialized_start=1031
  _globals['_ABCIRESPONSESINFO']._serialized_end=1202
  _globals['_VERSION']._serialized_start=1204
  _globals['_VERSION']._serialized_end=1288
  _globals['_STATE']._serialized_start=1291
  _globals['_STATE']._serialized_end=1997
# @@protoc_insertion_point(module_scope)
