# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/types/v2/evidence.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/types/v2/evidence.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.types.v2 import types_pb2 as cometbft_dot_types_dot_v2_dot_types__pb2
from cometbft.types.v2 import validator_pb2 as cometbft_dot_types_dot_v2_dot_validator__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cometbft/types/v2/evidence.proto\x12\x11\x63ometbft.types.v2\x1a\x1d\x63ometbft/types/v2/types.proto\x1a!cometbft/types/v2/validator.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb4\x01\n\x08\x45vidence\x12K\n\x17\x64uplicate_vote_evidence\x18\x01 \x01(\x0b\x32(.cometbft.types.v2.DuplicateVoteEvidenceH\x00\x12T\n\x1clight_client_attack_evidence\x18\x02 \x01(\x0b\x32,.cometbft.types.v2.LightClientAttackEvidenceH\x00\x42\x05\n\x03sum\"\xd7\x01\n\x15\x44uplicateVoteEvidence\x12\'\n\x06vote_a\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v2.Vote\x12\'\n\x06vote_b\x18\x02 \x01(\x0b\x32\x17.cometbft.types.v2.Vote\x12\x1a\n\x12total_voting_power\x18\x03 \x01(\x03\x12\x17\n\x0fvalidator_power\x18\x04 \x01(\x03\x12\x37\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"\xfd\x01\n\x19LightClientAttackEvidence\x12\x38\n\x11\x63onflicting_block\x18\x01 \x01(\x0b\x32\x1d.cometbft.types.v2.LightBlock\x12\x15\n\rcommon_height\x18\x02 \x01(\x03\x12:\n\x14\x62yzantine_validators\x18\x03 \x03(\x0b\x32\x1c.cometbft.types.v2.Validator\x12\x1a\n\x12total_voting_power\x18\x04 \x01(\x03\x12\x37\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"C\n\x0c\x45videnceList\x12\x33\n\x08\x65vidence\x18\x01 \x03(\x0b\x32\x1b.cometbft.types.v2.EvidenceB\x04\xc8\xde\x1f\x00\x42\x34Z2github.com/cometbft/cometbft/api/cometbft/types/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v2.evidence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2github.com/cometbft/cometbft/api/cometbft/types/v2'
  _globals['_DUPLICATEVOTEEVIDENCE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_DUPLICATEVOTEEVIDENCE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_LIGHTCLIENTATTACKEVIDENCE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_LIGHTCLIENTATTACKEVIDENCE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EVIDENCELIST'].fields_by_name['evidence']._loaded_options = None
  _globals['_EVIDENCELIST'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000'
  _globals['_EVIDENCE']._serialized_start=177
  _globals['_EVIDENCE']._serialized_end=357
  _globals['_DUPLICATEVOTEEVIDENCE']._serialized_start=360
  _globals['_DUPLICATEVOTEEVIDENCE']._serialized_end=575
  _globals['_LIGHTCLIENTATTACKEVIDENCE']._serialized_start=578
  _globals['_LIGHTCLIENTATTACKEVIDENCE']._serialized_end=831
  _globals['_EVIDENCELIST']._serialized_start=833
  _globals['_EVIDENCELIST']._serialized_end=900
# @@protoc_insertion_point(module_scope)
