from cometbft.services.pruning.v1 import pruning_pb2 as _pruning_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
