# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/sanctum/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/sanctum/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from neurion.sanctum import params_pb2 as neurion_dot_sanctum_dot_params__pb2
from neurion.sanctum import dataset_application_pb2 as neurion_dot_sanctum_dot_dataset__application__pb2
from neurion.sanctum import dataset_usage_request_pb2 as neurion_dot_sanctum_dot_dataset__usage__request__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18neurion/sanctum/tx.proto\x12\x0fneurion.sanctum\x1a\x11\x61mino/amino.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cneurion/sanctum/params.proto\x1a)neurion/sanctum/dataset_application.proto\x1a+neurion/sanctum/dataset_usage_request.proto\"\xa8\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x32\n\x06params\x18\x02 \x01(\x0b\x32\x17.neurion.sanctum.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:4\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*!neurion/x/sanctum/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xcd\x01\n\x1bMsgSubmitDatasetApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x1b\n\x13\x65ncrypted_data_link\x18\x02 \x01(\t\x12\x18\n\x10\x65xplanation_link\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontact\x18\x04 \x01(\t\x12\r\n\x05stake\x18\x05 \x01(\x04\x12\x1d\n\x15proof_of_authenticity\x18\x06 \x01(\t\x12\x19\n\x11\x64\x61taset_usage_fee\x18\x07 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"r\n#MsgSubmitDatasetApplicationResponse\x12K\n\x13\x64\x61taset_application\x18\x01 \x01(\x0b\x32#.neurion.sanctum.DatasetApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"^\n\x15MsgApproveApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgApproveApplicationResponse\"]\n\x14MsgRejectApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1e\n\x1cMsgRejectApplicationResponse\"[\n\x12MsgDisclaimDataset\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgDisclaimDatasetResponse\"\x89\x01\n\x16MsgRequestToUseDataset\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\ndataset_id\x18\x02 \x01(\x04\x12\x0e\n\x06intent\x18\x03 \x01(\t\x12\x1b\n\x13training_repository\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontact\x18\x05 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"b\n\x1eMsgRequestToUseDatasetResponse\x12@\n\x07request\x18\x01 \x01(\x0b\x32$.neurion.sanctum.DatasetUsageRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"a\n\x1cMsgCancelDatasetUsageRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"&\n$MsgCancelDatasetUsageRequestResponse\"a\n\x1cMsgRejectDatasetUsageRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"&\n$MsgRejectDatasetUsageRequestResponse\"b\n\x1dMsgApproveDatasetUsageRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\'\n%MsgApproveDatasetUsageRequestResponse\"C\n\x0fMsgAddProcessor\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgAddProcessorResponse\"F\n\x12MsgRemoveProcessor\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgRemoveProcessorResponse\"R\n\x1dMsgProcessDatasetUsageRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\'\n%MsgProcessDatasetUsageRequestResponse\"c\n\x1cMsgFinishDatasetUsageRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\x10\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"&\n$MsgFinishDatasetUsageRequestResponse\"q\n\x1dMsgDisputeDatasetUsageRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\r\n\x05model\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\'\n%MsgDisputeDatasetUsageRequestResponse\"V\n\x11MsgApproveDispute\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1b\n\x19MsgApproveDisputeResponse\"U\n\x10MsgRejectDispute\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgRejectDisputeResponse\"B\n\x11MsgStakeToSanctum\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1b\n\x19MsgStakeToSanctumResponse\"F\n\x15MsgUnstakeFromSanctum\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgUnstakeFromSanctumResponse\"/\n\x0eMsgClaimReward\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x18\n\x16MsgClaimRewardResponse2\xe3\x10\n\x03Msg\x12Z\n\x0cUpdateParams\x12 .neurion.sanctum.MsgUpdateParams\x1a(.neurion.sanctum.MsgUpdateParamsResponse\x12~\n\x18SubmitDatasetApplication\x12,.neurion.sanctum.MsgSubmitDatasetApplication\x1a\x34.neurion.sanctum.MsgSubmitDatasetApplicationResponse\x12l\n\x12\x41pproveApplication\x12&.neurion.sanctum.MsgApproveApplication\x1a..neurion.sanctum.MsgApproveApplicationResponse\x12i\n\x11RejectApplication\x12%.neurion.sanctum.MsgRejectApplication\x1a-.neurion.sanctum.MsgRejectApplicationResponse\x12\x63\n\x0f\x44isclaimDataset\x12#.neurion.sanctum.MsgDisclaimDataset\x1a+.neurion.sanctum.MsgDisclaimDatasetResponse\x12o\n\x13RequestToUseDataset\x12\'.neurion.sanctum.MsgRequestToUseDataset\x1a/.neurion.sanctum.MsgRequestToUseDatasetResponse\x12\x81\x01\n\x19\x43\x61ncelDatasetUsageRequest\x12-.neurion.sanctum.MsgCancelDatasetUsageRequest\x1a\x35.neurion.sanctum.MsgCancelDatasetUsageRequestResponse\x12\x81\x01\n\x19RejectDatasetUsageRequest\x12-.neurion.sanctum.MsgRejectDatasetUsageRequest\x1a\x35.neurion.sanctum.MsgRejectDatasetUsageRequestResponse\x12\x84\x01\n\x1a\x41pproveDatasetUsageRequest\x12..neurion.sanctum.MsgApproveDatasetUsageRequest\x1a\x36.neurion.sanctum.MsgApproveDatasetUsageRequestResponse\x12Z\n\x0c\x41\x64\x64Processor\x12 .neurion.sanctum.MsgAddProcessor\x1a(.neurion.sanctum.MsgAddProcessorResponse\x12\x63\n\x0fRemoveProcessor\x12#.neurion.sanctum.MsgRemoveProcessor\x1a+.neurion.sanctum.MsgRemoveProcessorResponse\x12\x84\x01\n\x1aProcessDatasetUsageRequest\x12..neurion.sanctum.MsgProcessDatasetUsageRequest\x1a\x36.neurion.sanctum.MsgProcessDatasetUsageRequestResponse\x12\x81\x01\n\x19\x46inishDatasetUsageRequest\x12-.neurion.sanctum.MsgFinishDatasetUsageRequest\x1a\x35.neurion.sanctum.MsgFinishDatasetUsageRequestResponse\x12\x84\x01\n\x1a\x44isputeDatasetUsageRequest\x12..neurion.sanctum.MsgDisputeDatasetUsageRequest\x1a\x36.neurion.sanctum.MsgDisputeDatasetUsageRequestResponse\x12`\n\x0e\x41pproveDispute\x12\".neurion.sanctum.MsgApproveDispute\x1a*.neurion.sanctum.MsgApproveDisputeResponse\x12]\n\rRejectDispute\x12!.neurion.sanctum.MsgRejectDispute\x1a).neurion.sanctum.MsgRejectDisputeResponse\x12`\n\x0eStakeToSanctum\x12\".neurion.sanctum.MsgStakeToSanctum\x1a*.neurion.sanctum.MsgStakeToSanctumResponse\x12l\n\x12UnstakeFromSanctum\x12&.neurion.sanctum.MsgUnstakeFromSanctum\x1a..neurion.sanctum.MsgUnstakeFromSanctumResponse\x12W\n\x0b\x43laimReward\x12\x1f.neurion.sanctum.MsgClaimReward\x1a\'.neurion.sanctum.MsgClaimRewardResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x19Z\x17neurion/x/sanctum/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.sanctum.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\027neurion/x/sanctum/types'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*!neurion/x/sanctum/MsgUpdateParams'
  _globals['_MSGSUBMITDATASETAPPLICATION']._loaded_options = None
  _globals['_MSGSUBMITDATASETAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSUBMITDATASETAPPLICATIONRESPONSE'].fields_by_name['dataset_application']._loaded_options = None
  _globals['_MSGSUBMITDATASETAPPLICATIONRESPONSE'].fields_by_name['dataset_application']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGAPPROVEAPPLICATION']._loaded_options = None
  _globals['_MSGAPPROVEAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREJECTAPPLICATION']._loaded_options = None
  _globals['_MSGREJECTAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGDISCLAIMDATASET']._loaded_options = None
  _globals['_MSGDISCLAIMDATASET']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREQUESTTOUSEDATASET']._loaded_options = None
  _globals['_MSGREQUESTTOUSEDATASET']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREQUESTTOUSEDATASETRESPONSE'].fields_by_name['request']._loaded_options = None
  _globals['_MSGREQUESTTOUSEDATASETRESPONSE'].fields_by_name['request']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGCANCELDATASETUSAGEREQUEST']._loaded_options = None
  _globals['_MSGCANCELDATASETUSAGEREQUEST']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREJECTDATASETUSAGEREQUEST']._loaded_options = None
  _globals['_MSGREJECTDATASETUSAGEREQUEST']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGAPPROVEDATASETUSAGEREQUEST']._loaded_options = None
  _globals['_MSGAPPROVEDATASETUSAGEREQUEST']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGADDPROCESSOR']._loaded_options = None
  _globals['_MSGADDPROCESSOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREMOVEPROCESSOR']._loaded_options = None
  _globals['_MSGREMOVEPROCESSOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGPROCESSDATASETUSAGEREQUEST']._loaded_options = None
  _globals['_MSGPROCESSDATASETUSAGEREQUEST']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGFINISHDATASETUSAGEREQUEST']._loaded_options = None
  _globals['_MSGFINISHDATASETUSAGEREQUEST']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGDISPUTEDATASETUSAGEREQUEST']._loaded_options = None
  _globals['_MSGDISPUTEDATASETUSAGEREQUEST']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGAPPROVEDISPUTE']._loaded_options = None
  _globals['_MSGAPPROVEDISPUTE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREJECTDISPUTE']._loaded_options = None
  _globals['_MSGREJECTDISPUTE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTAKETOSANCTUM']._loaded_options = None
  _globals['_MSGSTAKETOSANCTUM']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGUNSTAKEFROMSANCTUM']._loaded_options = None
  _globals['_MSGUNSTAKEFROMSANCTUM']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCLAIMREWARD']._loaded_options = None
  _globals['_MSGCLAIMREWARD']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=257
  _globals['_MSGUPDATEPARAMS']._serialized_end=425
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=427
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=452
  _globals['_MSGSUBMITDATASETAPPLICATION']._serialized_start=455
  _globals['_MSGSUBMITDATASETAPPLICATION']._serialized_end=660
  _globals['_MSGSUBMITDATASETAPPLICATIONRESPONSE']._serialized_start=662
  _globals['_MSGSUBMITDATASETAPPLICATIONRESPONSE']._serialized_end=776
  _globals['_MSGAPPROVEAPPLICATION']._serialized_start=778
  _globals['_MSGAPPROVEAPPLICATION']._serialized_end=872
  _globals['_MSGAPPROVEAPPLICATIONRESPONSE']._serialized_start=874
  _globals['_MSGAPPROVEAPPLICATIONRESPONSE']._serialized_end=905
  _globals['_MSGREJECTAPPLICATION']._serialized_start=907
  _globals['_MSGREJECTAPPLICATION']._serialized_end=1000
  _globals['_MSGREJECTAPPLICATIONRESPONSE']._serialized_start=1002
  _globals['_MSGREJECTAPPLICATIONRESPONSE']._serialized_end=1032
  _globals['_MSGDISCLAIMDATASET']._serialized_start=1034
  _globals['_MSGDISCLAIMDATASET']._serialized_end=1125
  _globals['_MSGDISCLAIMDATASETRESPONSE']._serialized_start=1127
  _globals['_MSGDISCLAIMDATASETRESPONSE']._serialized_end=1155
  _globals['_MSGREQUESTTOUSEDATASET']._serialized_start=1158
  _globals['_MSGREQUESTTOUSEDATASET']._serialized_end=1295
  _globals['_MSGREQUESTTOUSEDATASETRESPONSE']._serialized_start=1297
  _globals['_MSGREQUESTTOUSEDATASETRESPONSE']._serialized_end=1395
  _globals['_MSGCANCELDATASETUSAGEREQUEST']._serialized_start=1397
  _globals['_MSGCANCELDATASETUSAGEREQUEST']._serialized_end=1494
  _globals['_MSGCANCELDATASETUSAGEREQUESTRESPONSE']._serialized_start=1496
  _globals['_MSGCANCELDATASETUSAGEREQUESTRESPONSE']._serialized_end=1534
  _globals['_MSGREJECTDATASETUSAGEREQUEST']._serialized_start=1536
  _globals['_MSGREJECTDATASETUSAGEREQUEST']._serialized_end=1633
  _globals['_MSGREJECTDATASETUSAGEREQUESTRESPONSE']._serialized_start=1635
  _globals['_MSGREJECTDATASETUSAGEREQUESTRESPONSE']._serialized_end=1673
  _globals['_MSGAPPROVEDATASETUSAGEREQUEST']._serialized_start=1675
  _globals['_MSGAPPROVEDATASETUSAGEREQUEST']._serialized_end=1773
  _globals['_MSGAPPROVEDATASETUSAGEREQUESTRESPONSE']._serialized_start=1775
  _globals['_MSGAPPROVEDATASETUSAGEREQUESTRESPONSE']._serialized_end=1814
  _globals['_MSGADDPROCESSOR']._serialized_start=1816
  _globals['_MSGADDPROCESSOR']._serialized_end=1883
  _globals['_MSGADDPROCESSORRESPONSE']._serialized_start=1885
  _globals['_MSGADDPROCESSORRESPONSE']._serialized_end=1910
  _globals['_MSGREMOVEPROCESSOR']._serialized_start=1912
  _globals['_MSGREMOVEPROCESSOR']._serialized_end=1982
  _globals['_MSGREMOVEPROCESSORRESPONSE']._serialized_start=1984
  _globals['_MSGREMOVEPROCESSORRESPONSE']._serialized_end=2012
  _globals['_MSGPROCESSDATASETUSAGEREQUEST']._serialized_start=2014
  _globals['_MSGPROCESSDATASETUSAGEREQUEST']._serialized_end=2096
  _globals['_MSGPROCESSDATASETUSAGEREQUESTRESPONSE']._serialized_start=2098
  _globals['_MSGPROCESSDATASETUSAGEREQUESTRESPONSE']._serialized_end=2137
  _globals['_MSGFINISHDATASETUSAGEREQUEST']._serialized_start=2139
  _globals['_MSGFINISHDATASETUSAGEREQUEST']._serialized_end=2238
  _globals['_MSGFINISHDATASETUSAGEREQUESTRESPONSE']._serialized_start=2240
  _globals['_MSGFINISHDATASETUSAGEREQUESTRESPONSE']._serialized_end=2278
  _globals['_MSGDISPUTEDATASETUSAGEREQUEST']._serialized_start=2280
  _globals['_MSGDISPUTEDATASETUSAGEREQUEST']._serialized_end=2393
  _globals['_MSGDISPUTEDATASETUSAGEREQUESTRESPONSE']._serialized_start=2395
  _globals['_MSGDISPUTEDATASETUSAGEREQUESTRESPONSE']._serialized_end=2434
  _globals['_MSGAPPROVEDISPUTE']._serialized_start=2436
  _globals['_MSGAPPROVEDISPUTE']._serialized_end=2522
  _globals['_MSGAPPROVEDISPUTERESPONSE']._serialized_start=2524
  _globals['_MSGAPPROVEDISPUTERESPONSE']._serialized_end=2551
  _globals['_MSGREJECTDISPUTE']._serialized_start=2553
  _globals['_MSGREJECTDISPUTE']._serialized_end=2638
  _globals['_MSGREJECTDISPUTERESPONSE']._serialized_start=2640
  _globals['_MSGREJECTDISPUTERESPONSE']._serialized_end=2666
  _globals['_MSGSTAKETOSANCTUM']._serialized_start=2668
  _globals['_MSGSTAKETOSANCTUM']._serialized_end=2734
  _globals['_MSGSTAKETOSANCTUMRESPONSE']._serialized_start=2736
  _globals['_MSGSTAKETOSANCTUMRESPONSE']._serialized_end=2763
  _globals['_MSGUNSTAKEFROMSANCTUM']._serialized_start=2765
  _globals['_MSGUNSTAKEFROMSANCTUM']._serialized_end=2835
  _globals['_MSGUNSTAKEFROMSANCTUMRESPONSE']._serialized_start=2837
  _globals['_MSGUNSTAKEFROMSANCTUMRESPONSE']._serialized_end=2868
  _globals['_MSGCLAIMREWARD']._serialized_start=2870
  _globals['_MSGCLAIMREWARD']._serialized_end=2917
  _globals['_MSGCLAIMREWARDRESPONSE']._serialized_start=2919
  _globals['_MSGCLAIMREWARDRESPONSE']._serialized_end=2943
  _globals['_MSG']._serialized_start=2946
  _globals['_MSG']._serialized_end=5093
# @@protoc_insertion_point(module_scope)
