# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/params.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dneurion/crucible/params.proto\x12\x10neurion.crucible\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\"\xbc\x06\n\x06Params\x12\x15\n\radmin_address\x18\x01 \x01(\t\x12!\n\x19min_task_duration_in_days\x18\x02 \x01(\x04\x12\x17\n\x0fmin_task_reward\x18\x03 \x01(\x04\x12\x1e\n\x16min_task_trainer_stake\x18\x04 \x01(\x04\x12\x1d\n\x15min_task_scorer_stake\x18\x05 \x01(\x04\x12\x30\n(submission_cooling_off_period_in_seconds\x18\x06 \x01(\x04\x12%\n\x1dmin_report_plagiarism_deposit\x18\x07 \x01(\x04\x12!\n\x19min_dispute_score_deposit\x18\x08 \x01(\x04\x12\x19\n\x11min_creator_stake\x18\t \x01(\x04\x12\x1f\n\x17\x63reator_application_fee\x18\n \x01(\x04\x12\x1c\n\x14\x64ispute_score_reward\x18\x0b \x01(\x04\x12!\n\x19min_task_training_in_days\x18\x0c \x01(\x04\x12)\n!min_task_final_submission_in_days\x18\r \x01(\x04\x12&\n\x1emin_task_final_dispute_in_days\x18\x0e \x01(\x04\x12\"\n\x1atrainers_reward_percentage\x18\x0f \x01(\x04\x12 \n\x18scorer_reward_percentage\x18\x10 \x01(\x04\x12!\n\x19stakers_reward_percentage\x18\x11 \x01(\x04\x12-\n%trainer_first_place_reward_percentage\x18\x12 \x01(\x04\x12.\n&trainer_second_place_reward_percentage\x18\x13 \x01(\x04\x12-\n%trainer_third_place_reward_percentage\x18\x14 \x01(\x04\x12\x39\n1trainers_number_to_be_rewarded_except_first_three\x18\x15 \x01(\x04:\"\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x19neurion/x/crucible/ParamsB\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\031neurion/x/crucible/Params'
  _globals['_PARAMS']._serialized_start=93
  _globals['_PARAMS']._serialized_end=921
# @@protoc_insertion_point(module_scope)
