# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/consensus/v1beta1/wal.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/consensus/v1beta1/wal.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cometbft.consensus.v1beta1 import types_pb2 as cometbft_dot_consensus_dot_v1beta1_dot_types__pb2
from cometbft.types.v1beta1 import events_pb2 as cometbft_dot_types_dot_v1beta1_dot_events__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cometbft/consensus/v1beta1/wal.proto\x12\x1a\x63ometbft.consensus.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cometbft/consensus/v1beta1/types.proto\x1a#cometbft/types/v1beta1/events.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"^\n\x07MsgInfo\x12\x36\n\x03msg\x18\x01 \x01(\x0b\x32#.cometbft.consensus.v1beta1.MessageB\x04\xc8\xde\x1f\x00\x12\x1b\n\x07peer_id\x18\x02 \x01(\tB\n\xe2\xde\x1f\x06PeerID\"q\n\x0bTimeoutInfo\x12\x35\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x05\x12\x0c\n\x04step\x18\x04 \x01(\r\"\x1b\n\tEndHeight\x12\x0e\n\x06height\x18\x01 \x01(\x03\"\x99\x02\n\nWALMessage\x12M\n\x16\x65vent_data_round_state\x18\x01 \x01(\x0b\x32+.cometbft.types.v1beta1.EventDataRoundStateH\x00\x12\x37\n\x08msg_info\x18\x02 \x01(\x0b\x32#.cometbft.consensus.v1beta1.MsgInfoH\x00\x12?\n\x0ctimeout_info\x18\x03 \x01(\x0b\x32\'.cometbft.consensus.v1beta1.TimeoutInfoH\x00\x12;\n\nend_height\x18\x04 \x01(\x0b\x32%.cometbft.consensus.v1beta1.EndHeightH\x00\x42\x05\n\x03sum\"z\n\x0fTimedWALMessage\x12\x32\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x33\n\x03msg\x18\x02 \x01(\x0b\x32&.cometbft.consensus.v1beta1.WALMessageB=Z;github.com/cometbft/cometbft/api/cometbft/consensus/v1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.consensus.v1beta1.wal_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/cometbft/cometbft/api/cometbft/consensus/v1beta1'
  _globals['_MSGINFO'].fields_by_name['msg']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['msg']._serialized_options = b'\310\336\037\000'
  _globals['_MSGINFO'].fields_by_name['peer_id']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['peer_id']._serialized_options = b'\342\336\037\006PeerID'
  _globals['_TIMEOUTINFO'].fields_by_name['duration']._loaded_options = None
  _globals['_TIMEOUTINFO'].fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_TIMEDWALMESSAGE'].fields_by_name['time']._loaded_options = None
  _globals['_TIMEDWALMESSAGE'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_MSGINFO']._serialized_start=232
  _globals['_MSGINFO']._serialized_end=326
  _globals['_TIMEOUTINFO']._serialized_start=328
  _globals['_TIMEOUTINFO']._serialized_end=441
  _globals['_ENDHEIGHT']._serialized_start=443
  _globals['_ENDHEIGHT']._serialized_end=470
  _globals['_WALMESSAGE']._serialized_start=473
  _globals['_WALMESSAGE']._serialized_end=754
  _globals['_TIMEDWALMESSAGE']._serialized_start=756
  _globals['_TIMEDWALMESSAGE']._serialized_end=878
# @@protoc_insertion_point(module_scope)
