# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/base/store/v1beta1/snapshot.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/base/store/v1beta1/snapshot.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(cosmos/base/store/v1beta1/snapshot.proto\x12\x19\x63osmos.base.store.v1beta1\x1a\x14gogoproto/gogo.proto\"\x9c\x01\n\x0cSnapshotItem\x12=\n\x05store\x18\x01 \x01(\x0b\x32,.cosmos.base.store.v1beta1.SnapshotStoreItemH\x00\x12\x45\n\x04iavl\x18\x02 \x01(\x0b\x32+.cosmos.base.store.v1beta1.SnapshotIAVLItemB\x08\xe2\xde\x1f\x04IAVLH\x00\x42\x06\n\x04item\"!\n\x11SnapshotStoreItem\x12\x0c\n\x04name\x18\x01 \x01(\t\"O\n\x10SnapshotIAVLItem\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x0f\n\x07version\x18\x03 \x01(\x03\x12\x0e\n\x06height\x18\x04 \x01(\x05\x42*Z(github.com/cosmos/cosmos-sdk/store/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.store.v1beta1.snapshot_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/store/types'
  _globals['_SNAPSHOTITEM'].fields_by_name['iavl']._loaded_options = None
  _globals['_SNAPSHOTITEM'].fields_by_name['iavl']._serialized_options = b'\342\336\037\004IAVL'
  _globals['_SNAPSHOTITEM']._serialized_start=94
  _globals['_SNAPSHOTITEM']._serialized_end=250
  _globals['_SNAPSHOTSTOREITEM']._serialized_start=252
  _globals['_SNAPSHOTSTOREITEM']._serialized_end=285
  _globals['_SNAPSHOTIAVLITEM']._serialized_start=287
  _globals['_SNAPSHOTIAVLITEM']._serialized_end=366
# @@protoc_insertion_point(module_scope)
