# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/params.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bneurion/fusion/params.proto\x12\x0eneurion.fusion\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\"\xba\x04\n\x06Params\x12\x15\n\radmin_address\x18\x01 \x01(\t\x12\x17\n\x0fmin_task_reward\x18\x02 \x01(\x04\x12\x1f\n\x17min_task_proposer_stake\x18\x04 \x01(\x04\x12 \n\x18min_task_validator_stake\x18\x05 \x01(\x04\x12(\n min_proposal_duration_in_seconds\x18\x06 \x01(\x04\x12\'\n\x1fmin_dispute_duration_in_seconds\x18\x07 \x01(\x04\x12\x19\n\x11min_creator_stake\x18\x08 \x01(\x04\x12\x1f\n\x17\x63reator_application_fee\x18\t \x01(\x04\x12 \n\x18\x64ispute_validator_reward\x18\n \x01(\x04\x12!\n\x19min_dispute_score_deposit\x18\x0b \x01(\x04\x12\x1d\n\x15\x66irst_proposer_weight\x18\x0c \x01(\x04\x12\x1e\n\x16second_proposer_weight\x18\r \x01(\x04\x12\x1d\n\x15third_proposer_weight\x18\x0e \x01(\x04\x12\"\n\x1aproposer_reward_percentage\x18\x0f \x01(\x04\x12#\n\x1bvalidator_reward_percentage\x18\x10 \x01(\x04\x12 \n\x18staker_reward_percentage\x18\x11 \x01(\x04: \xe8\xa0\x1f\x01\x8a\xe7\xb0*\x17neurion/x/fusion/ParamsB\x18Z\x16neurion/x/fusion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\026neurion/x/fusion/types'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\027neurion/x/fusion/Params'
  _globals['_PARAMS']._serialized_start=89
  _globals['_PARAMS']._serialized_end=659
# @@protoc_insertion_point(module_scope)
