# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/staking/v1beta1/genesis.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/staking/v1beta1/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/staking/v1beta1/genesis.proto\x12\x16\x63osmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a$cosmos/staking/v1beta1/staking.proto\"\xdd\x04\n\x0cGenesisState\x12\x34\n\x06params\x18\x01 \x01(\x0b\x32\x1e.cosmos.staking.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\x63\n\x10last_total_power\x18\x02 \x01(\x0c\x42I\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"last_total_power\"\x12o\n\x15last_validator_powers\x18\x03 \x03(\x0b\x32*.cosmos.staking.v1beta1.LastValidatorPowerB$\xc8\xde\x1f\x00\xf2\xde\x1f\x1cyaml:\"last_validator_powers\"\x12;\n\nvalidators\x18\x04 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12=\n\x0b\x64\x65legations\x18\x05 \x03(\x0b\x32\".cosmos.staking.v1beta1.DelegationB\x04\xc8\xde\x1f\x00\x12p\n\x15unbonding_delegations\x18\x06 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB$\xc8\xde\x1f\x00\xf2\xde\x1f\x1cyaml:\"unbonding_delegations\"\x12\x41\n\rredelegations\x18\x07 \x03(\x0b\x32$.cosmos.staking.v1beta1.RedelegationB\x04\xc8\xde\x1f\x00\x12\x10\n\x08\x65xported\x18\x08 \x01(\x08\">\n\x12LastValidatorPower\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05power\x18\x02 \x01(\x03:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x42.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['last_total_power']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['last_total_power']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"last_total_power\"'
  _globals['_GENESISSTATE'].fields_by_name['last_validator_powers']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['last_validator_powers']._serialized_options = b'\310\336\037\000\362\336\037\034yaml:\"last_validator_powers\"'
  _globals['_GENESISSTATE'].fields_by_name['validators']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['delegations']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['delegations']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['unbonding_delegations']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['unbonding_delegations']._serialized_options = b'\310\336\037\000\362\336\037\034yaml:\"unbonding_delegations\"'
  _globals['_GENESISSTATE'].fields_by_name['redelegations']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['redelegations']._serialized_options = b'\310\336\037\000'
  _globals['_LASTVALIDATORPOWER']._loaded_options = None
  _globals['_LASTVALIDATORPOWER']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_GENESISSTATE']._serialized_start=125
  _globals['_GENESISSTATE']._serialized_end=730
  _globals['_LASTVALIDATORPOWER']._serialized_start=732
  _globals['_LASTVALIDATORPOWER']._serialized_end=794
# @@protoc_insertion_point(module_scope)
