# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/services/version/v1/version.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/services/version/v1/version.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cometbft/services/version/v1/version.proto\x12\x1c\x63ometbft.services.version.v1\"\x13\n\x11GetVersionRequest\"L\n\x12GetVersionResponse\x12\x0c\n\x04node\x18\x01 \x01(\t\x12\x0c\n\x04\x61\x62\x63i\x18\x02 \x01(\t\x12\x0b\n\x03p2p\x18\x03 \x01(\x04\x12\r\n\x05\x62lock\x18\x04 \x01(\x04\x42?Z=github.com/cometbft/cometbft/api/cometbft/services/version/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.version.v1.version_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/cometbft/cometbft/api/cometbft/services/version/v1'
  _globals['_GETVERSIONREQUEST']._serialized_start=76
  _globals['_GETVERSIONREQUEST']._serialized_end=95
  _globals['_GETVERSIONRESPONSE']._serialized_start=97
  _globals['_GETVERSIONRESPONSE']._serialized_end=173
# @@protoc_insertion_point(module_scope)
