# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/sanctum/dataset_usage_request.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/sanctum/dataset_usage_request.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+neurion/sanctum/dataset_usage_request.proto\x12\x0fneurion.sanctum\"\x87\x03\n\x13\x44\x61tasetUsageRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12:\n\x06result\x18\x03 \x01(\x0e\x32*.neurion.sanctum.DatasetUsageRequestResult\x12\x12\n\ndataset_id\x18\x04 \x01(\x04\x12\x0e\n\x06intent\x18\x05 \x01(\t\x12\x1b\n\x13training_repository\x18\x06 \x01(\t\x12\x10\n\x08\x66\x65\x65_paid\x18\x07 \x01(\x04\x12\x1a\n\x12\x64\x65\x63ision_timestamp\x18\x08 \x01(\x04\x12\x16\n\x0e\x64\x65\x63ision_maker\x18\t \x01(\t\x12\x17\n\x0f\x64\x65\x63ision_reason\x18\n \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x0b \x01(\x04\x12\x15\n\rdispute_model\x18\x0c \x01(\t\x12!\n\x19\x64ispute_resolution_reason\x18\r \x01(\t\x12\x10\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x0e \x01(\t\x12\x0f\n\x07\x63ontact\x18\x0f \x01(\t*\xd0\x02\n\x19\x44\x61tasetUsageRequestResult\x12.\n*DATASET_USAGE_REQUEST_RESULT_NOT_AVAILABLE\x10\x00\x12)\n%DATASET_USAGE_REQUEST_RESULT_ACCEPTED\x10\x01\x12)\n%DATASET_USAGE_REQUEST_RESULT_REJECTED\x10\x02\x12*\n&DATASET_USAGE_REQUEST_RESULT_CANCELLED\x10\x03\x12+\n\'DATASET_USAGE_REQUEST_RESULT_PROCESSING\x10\x04\x12)\n%DATASET_USAGE_REQUEST_RESULT_FINISHED\x10\x05\x12)\n%DATASET_USAGE_REQUEST_RESULT_DISPUTED\x10\x06\x42\x19Z\x17neurion/x/sanctum/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.sanctum.dataset_usage_request_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\027neurion/x/sanctum/types'
  _globals['_DATASETUSAGEREQUESTRESULT']._serialized_start=459
  _globals['_DATASETUSAGEREQUESTRESULT']._serialized_end=795
  _globals['_DATASETUSAGEREQUEST']._serialized_start=65
  _globals['_DATASETUSAGEREQUEST']._serialized_end=456
# @@protoc_insertion_point(module_scope)
