# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/consensus/v1/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/consensus/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cometbft.libs.bits.v1 import types_pb2 as cometbft_dot_libs_dot_bits_dot_v1_dot_types__pb2
from cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cometbft/consensus/v1/types.proto\x12\x15\x63ometbft.consensus.v1\x1a\x14gogoproto/gogo.proto\x1a!cometbft/libs/bits/v1/types.proto\x1a\x1d\x63ometbft/types/v1/types.proto\"x\n\x0cNewRoundStep\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\x0c\n\x04step\x18\x03 \x01(\r\x12 \n\x18seconds_since_start_time\x18\x04 \x01(\x03\x12\x19\n\x11last_commit_round\x18\x05 \x01(\x05\"\xbe\x01\n\rNewValidBlock\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\x45\n\x15\x62lock_part_set_header\x18\x03 \x01(\x0b\x32 .cometbft.types.v1.PartSetHeaderB\x04\xc8\xde\x1f\x00\x12\x34\n\x0b\x62lock_parts\x18\x04 \x01(\x0b\x32\x1f.cometbft.libs.bits.v1.BitArray\x12\x11\n\tis_commit\x18\x05 \x01(\x08\"?\n\x08Proposal\x12\x33\n\x08proposal\x18\x01 \x01(\x0b\x32\x1b.cometbft.types.v1.ProposalB\x04\xc8\xde\x1f\x00\"v\n\x0bProposalPOL\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x1a\n\x12proposal_pol_round\x18\x02 \x01(\x05\x12;\n\x0cproposal_pol\x18\x03 \x01(\x0b\x32\x1f.cometbft.libs.bits.v1.BitArrayB\x04\xc8\xde\x1f\x00\"W\n\tBlockPart\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12+\n\x04part\x18\x03 \x01(\x0b\x32\x17.cometbft.types.v1.PartB\x04\xc8\xde\x1f\x00\"-\n\x04Vote\x12%\n\x04vote\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.Vote\"g\n\x07HasVote\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12.\n\x04type\x18\x03 \x01(\x0e\x32 .cometbft.types.v1.SignedMsgType\x12\r\n\x05index\x18\x04 \x01(\x05\"\x9c\x01\n\x0cVoteSetMaj23\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12.\n\x04type\x18\x03 \x01(\x0e\x32 .cometbft.types.v1.SignedMsgType\x12=\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\"\xd1\x01\n\x0bVoteSetBits\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12.\n\x04type\x18\x03 \x01(\x0e\x32 .cometbft.types.v1.SignedMsgType\x12=\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\x12\x34\n\x05votes\x18\x05 \x01(\x0b\x32\x1f.cometbft.libs.bits.v1.BitArrayB\x04\xc8\xde\x1f\x00\"D\n\x14HasProposalBlockPart\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\r\n\x05index\x18\x03 \x01(\x05\"\xe6\x04\n\x07Message\x12=\n\x0enew_round_step\x18\x01 \x01(\x0b\x32#.cometbft.consensus.v1.NewRoundStepH\x00\x12?\n\x0fnew_valid_block\x18\x02 \x01(\x0b\x32$.cometbft.consensus.v1.NewValidBlockH\x00\x12\x33\n\x08proposal\x18\x03 \x01(\x0b\x32\x1f.cometbft.consensus.v1.ProposalH\x00\x12:\n\x0cproposal_pol\x18\x04 \x01(\x0b\x32\".cometbft.consensus.v1.ProposalPOLH\x00\x12\x36\n\nblock_part\x18\x05 \x01(\x0b\x32 .cometbft.consensus.v1.BlockPartH\x00\x12+\n\x04vote\x18\x06 \x01(\x0b\x32\x1b.cometbft.consensus.v1.VoteH\x00\x12\x32\n\x08has_vote\x18\x07 \x01(\x0b\x32\x1e.cometbft.consensus.v1.HasVoteH\x00\x12=\n\x0evote_set_maj23\x18\x08 \x01(\x0b\x32#.cometbft.consensus.v1.VoteSetMaj23H\x00\x12;\n\rvote_set_bits\x18\t \x01(\x0b\x32\".cometbft.consensus.v1.VoteSetBitsH\x00\x12N\n\x17has_proposal_block_part\x18\n \x01(\x0b\x32+.cometbft.consensus.v1.HasProposalBlockPartH\x00\x42\x05\n\x03sumB8Z6github.com/cometbft/cometbft/api/cometbft/consensus/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.consensus.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/cometbft/cometbft/api/cometbft/consensus/v1'
  _globals['_NEWVALIDBLOCK'].fields_by_name['block_part_set_header']._loaded_options = None
  _globals['_NEWVALIDBLOCK'].fields_by_name['block_part_set_header']._serialized_options = b'\310\336\037\000'
  _globals['_PROPOSAL'].fields_by_name['proposal']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['proposal']._serialized_options = b'\310\336\037\000'
  _globals['_PROPOSALPOL'].fields_by_name['proposal_pol']._loaded_options = None
  _globals['_PROPOSALPOL'].fields_by_name['proposal_pol']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKPART'].fields_by_name['part']._loaded_options = None
  _globals['_BLOCKPART'].fields_by_name['part']._serialized_options = b'\310\336\037\000'
  _globals['_VOTESETMAJ23'].fields_by_name['block_id']._loaded_options = None
  _globals['_VOTESETMAJ23'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_VOTESETBITS'].fields_by_name['block_id']._loaded_options = None
  _globals['_VOTESETBITS'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_VOTESETBITS'].fields_by_name['votes']._loaded_options = None
  _globals['_VOTESETBITS'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_NEWROUNDSTEP']._serialized_start=148
  _globals['_NEWROUNDSTEP']._serialized_end=268
  _globals['_NEWVALIDBLOCK']._serialized_start=271
  _globals['_NEWVALIDBLOCK']._serialized_end=461
  _globals['_PROPOSAL']._serialized_start=463
  _globals['_PROPOSAL']._serialized_end=526
  _globals['_PROPOSALPOL']._serialized_start=528
  _globals['_PROPOSALPOL']._serialized_end=646
  _globals['_BLOCKPART']._serialized_start=648
  _globals['_BLOCKPART']._serialized_end=735
  _globals['_VOTE']._serialized_start=737
  _globals['_VOTE']._serialized_end=782
  _globals['_HASVOTE']._serialized_start=784
  _globals['_HASVOTE']._serialized_end=887
  _globals['_VOTESETMAJ23']._serialized_start=890
  _globals['_VOTESETMAJ23']._serialized_end=1046
  _globals['_VOTESETBITS']._serialized_start=1049
  _globals['_VOTESETBITS']._serialized_end=1258
  _globals['_HASPROPOSALBLOCKPART']._serialized_start=1260
  _globals['_HASPROPOSALBLOCKPART']._serialized_end=1328
  _globals['_MESSAGE']._serialized_start=1331
  _globals['_MESSAGE']._serialized_end=1945
# @@protoc_insertion_point(module_scope)
