# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ibc/applications/interchain_accounts/v1/metadata.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ibc/applications/interchain_accounts/v1/metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6ibc/applications/interchain_accounts/v1/metadata.proto\x12\'ibc.applications.interchain_accounts.v1\x1a\x14gogoproto/gogo.proto\"\xd1\x01\n\x08Metadata\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x45\n\x18\x63ontroller_connection_id\x18\x02 \x01(\tB#\xf2\xde\x1f\x1fyaml:\"controller_connection_id\"\x12\x39\n\x12host_connection_id\x18\x03 \x01(\tB\x1d\xf2\xde\x1f\x19yaml:\"host_connection_id\"\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\t\x12\x10\n\x08\x65ncoding\x18\x05 \x01(\t\x12\x0f\n\x07tx_type\x18\x06 \x01(\tBGZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.v1.metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/types'
  _globals['_METADATA'].fields_by_name['controller_connection_id']._loaded_options = None
  _globals['_METADATA'].fields_by_name['controller_connection_id']._serialized_options = b'\362\336\037\037yaml:\"controller_connection_id\"'
  _globals['_METADATA'].fields_by_name['host_connection_id']._loaded_options = None
  _globals['_METADATA'].fields_by_name['host_connection_id']._serialized_options = b'\362\336\037\031yaml:\"host_connection_id\"'
  _globals['_METADATA']._serialized_start=122
  _globals['_METADATA']._serialized_end=331
# @@protoc_insertion_point(module_scope)
