# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/services/block_results/v2/block_results.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/services/block_results/v2/block_results.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.abci.v2 import types_pb2 as cometbft_dot_abci_dot_v2_dot_types__pb2
from cometbft.types.v2 import params_pb2 as cometbft_dot_types_dot_v2_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6cometbft/services/block_results/v2/block_results.proto\x12\"cometbft.services.block_results.v2\x1a\x1c\x63ometbft/abci/v2/types.proto\x1a\x1e\x63ometbft/types/v2/params.proto\"(\n\x16GetBlockResultsRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"\xaa\x02\n\x17GetBlockResultsResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x32\n\ntx_results\x18\x02 \x03(\x0b\x32\x1e.cometbft.abci.v2.ExecTxResult\x12\x36\n\x15\x66inalize_block_events\x18\x03 \x03(\x0b\x32\x17.cometbft.abci.v2.Event\x12<\n\x11validator_updates\x18\x04 \x03(\x0b\x32!.cometbft.abci.v2.ValidatorUpdate\x12\x43\n\x17\x63onsensus_param_updates\x18\x05 \x01(\x0b\x32\".cometbft.types.v2.ConsensusParams\x12\x10\n\x08\x61pp_hash\x18\x06 \x01(\x0c\x42\x45ZCgithub.com/cometbft/cometbft/api/cometbft/services/block_results/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.block_results.v2.block_results_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/cometbft/cometbft/api/cometbft/services/block_results/v2'
  _globals['_GETBLOCKRESULTSREQUEST']._serialized_start=156
  _globals['_GETBLOCKRESULTSREQUEST']._serialized_end=196
  _globals['_GETBLOCKRESULTSRESPONSE']._serialized_start=199
  _globals['_GETBLOCKRESULTSRESPONSE']._serialized_end=497
# @@protoc_insertion_point(module_scope)
