# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmwasm/wasm/v1/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmwasm/wasm/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmwasm/wasm/v1/types.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"V\n\x0f\x41\x63\x63\x65ssTypeParam\x12=\n\x05value\x18\x01 \x01(\x0e\x32\x1c.cosmwasm.wasm.v1.AccessTypeB\x10\xf2\xde\x1f\x0cyaml:\"value\":\x04\x98\xa0\x1f\x01\"\x82\x01\n\x0c\x41\x63\x63\x65ssConfig\x12G\n\npermission\x18\x01 \x01(\x0e\x32\x1c.cosmwasm.wasm.v1.AccessTypeB\x15\xf2\xde\x1f\x11yaml:\"permission\"\x12#\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\":\x04\x98\xa0\x1f\x01\"\xde\x01\n\x06Params\x12]\n\x12\x63ode_upload_access\x18\x01 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB!\xc8\xde\x1f\x00\xf2\xde\x1f\x19yaml:\"code_upload_access\"\x12o\n\x1einstantiate_default_permission\x18\x02 \x01(\x0e\x32\x1c.cosmwasm.wasm.v1.AccessTypeB)\xf2\xde\x1f%yaml:\"instantiate_default_permission\":\x04\x98\xa0\x1f\x00\"|\n\x08\x43odeInfo\x12\x11\n\tcode_hash\x18\x01 \x01(\x0c\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12@\n\x12instantiate_config\x18\x05 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB\x04\xc8\xde\x1f\x00J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\xff\x01\n\x0c\x43ontractInfo\x12\x1b\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12\r\n\x05\x61\x64min\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\x12\x35\n\x07\x63reated\x18\x05 \x01(\x0b\x32$.cosmwasm.wasm.v1.AbsoluteTxPosition\x12\"\n\x0bibc_port_id\x18\x06 \x01(\tB\r\xe2\xde\x1f\tIBCPortID\x12\x42\n\textension\x18\x07 \x01(\x0b\x32\x14.google.protobuf.AnyB\x19\xca\xb4-\x15\x43ontractInfoExtension:\x04\xe8\xa0\x1f\x01\"\xda\x01\n\x18\x43ontractCodeHistoryEntry\x12\x45\n\toperation\x18\x01 \x01(\x0e\x32\x32.cosmwasm.wasm.v1.ContractCodeHistoryOperationType\x12\x1b\n\x07\x63ode_id\x18\x02 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x35\n\x07updated\x18\x03 \x01(\x0b\x32$.cosmwasm.wasm.v1.AbsoluteTxPosition\x12#\n\x03msg\x18\x04 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\"<\n\x12\x41\x62soluteTxPosition\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\x04\x12\x10\n\x08tx_index\x18\x02 \x01(\x04\"]\n\x05Model\x12\x45\n\x03key\x18\x01 \x01(\x0c\x42\x38\xfa\xde\x1f\x34github.com/tendermint/tendermint/libs/bytes.HexBytes\x12\r\n\x05value\x18\x02 \x01(\x0c*\xe9\x01\n\nAccessType\x12\x36\n\x17\x41\x43\x43\x45SS_TYPE_UNSPECIFIED\x10\x00\x1a\x19\x8a\x9d \x15\x41\x63\x63\x65ssTypeUnspecified\x12,\n\x12\x41\x43\x43\x45SS_TYPE_NOBODY\x10\x01\x1a\x14\x8a\x9d \x10\x41\x63\x63\x65ssTypeNobody\x12\x37\n\x18\x41\x43\x43\x45SS_TYPE_ONLY_ADDRESS\x10\x02\x1a\x19\x8a\x9d \x15\x41\x63\x63\x65ssTypeOnlyAddress\x12\x32\n\x15\x41\x43\x43\x45SS_TYPE_EVERYBODY\x10\x03\x1a\x17\x8a\x9d \x13\x41\x63\x63\x65ssTypeEverybody\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x00*\xa6\x03\n ContractCodeHistoryOperationType\x12\x65\n0CONTRACT_CODE_HISTORY_OPERATION_TYPE_UNSPECIFIED\x10\x00\x1a/\x8a\x9d +ContractCodeHistoryOperationTypeUnspecified\x12W\n)CONTRACT_CODE_HISTORY_OPERATION_TYPE_INIT\x10\x01\x1a(\x8a\x9d $ContractCodeHistoryOperationTypeInit\x12]\n,CONTRACT_CODE_HISTORY_OPERATION_TYPE_MIGRATE\x10\x02\x1a+\x8a\x9d \'ContractCodeHistoryOperationTypeMigrate\x12]\n,CONTRACT_CODE_HISTORY_OPERATION_TYPE_GENESIS\x10\x03\x1a+\x8a\x9d \'ContractCodeHistoryOperationTypeGenesis\x1a\x04\x88\xa3\x1e\x00\x42\x30Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000\250\342\036\001'
  _globals['_ACCESSTYPE']._loaded_options = None
  _globals['_ACCESSTYPE']._serialized_options = b'\210\243\036\000\250\244\036\000'
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_UNSPECIFIED"]._loaded_options = None
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 \025AccessTypeUnspecified'
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_NOBODY"]._loaded_options = None
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_NOBODY"]._serialized_options = b'\212\235 \020AccessTypeNobody'
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_ONLY_ADDRESS"]._loaded_options = None
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_ONLY_ADDRESS"]._serialized_options = b'\212\235 \025AccessTypeOnlyAddress'
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_EVERYBODY"]._loaded_options = None
  _globals['_ACCESSTYPE'].values_by_name["ACCESS_TYPE_EVERYBODY"]._serialized_options = b'\212\235 \023AccessTypeEverybody'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE']._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_UNSPECIFIED"]._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 +ContractCodeHistoryOperationTypeUnspecified'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_INIT"]._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_INIT"]._serialized_options = b'\212\235 $ContractCodeHistoryOperationTypeInit'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_MIGRATE"]._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_MIGRATE"]._serialized_options = b'\212\235 \'ContractCodeHistoryOperationTypeMigrate'
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_GENESIS"]._loaded_options = None
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE'].values_by_name["CONTRACT_CODE_HISTORY_OPERATION_TYPE_GENESIS"]._serialized_options = b'\212\235 \'ContractCodeHistoryOperationTypeGenesis'
  _globals['_ACCESSTYPEPARAM'].fields_by_name['value']._loaded_options = None
  _globals['_ACCESSTYPEPARAM'].fields_by_name['value']._serialized_options = b'\362\336\037\014yaml:\"value\"'
  _globals['_ACCESSTYPEPARAM']._loaded_options = None
  _globals['_ACCESSTYPEPARAM']._serialized_options = b'\230\240\037\001'
  _globals['_ACCESSCONFIG'].fields_by_name['permission']._loaded_options = None
  _globals['_ACCESSCONFIG'].fields_by_name['permission']._serialized_options = b'\362\336\037\021yaml:\"permission\"'
  _globals['_ACCESSCONFIG'].fields_by_name['address']._loaded_options = None
  _globals['_ACCESSCONFIG'].fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _globals['_ACCESSCONFIG']._loaded_options = None
  _globals['_ACCESSCONFIG']._serialized_options = b'\230\240\037\001'
  _globals['_PARAMS'].fields_by_name['code_upload_access']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['code_upload_access']._serialized_options = b'\310\336\037\000\362\336\037\031yaml:\"code_upload_access\"'
  _globals['_PARAMS'].fields_by_name['instantiate_default_permission']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['instantiate_default_permission']._serialized_options = b'\362\336\037%yaml:\"instantiate_default_permission\"'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\230\240\037\000'
  _globals['_CODEINFO'].fields_by_name['instantiate_config']._loaded_options = None
  _globals['_CODEINFO'].fields_by_name['instantiate_config']._serialized_options = b'\310\336\037\000'
  _globals['_CONTRACTINFO'].fields_by_name['code_id']._loaded_options = None
  _globals['_CONTRACTINFO'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_CONTRACTINFO'].fields_by_name['ibc_port_id']._loaded_options = None
  _globals['_CONTRACTINFO'].fields_by_name['ibc_port_id']._serialized_options = b'\342\336\037\tIBCPortID'
  _globals['_CONTRACTINFO'].fields_by_name['extension']._loaded_options = None
  _globals['_CONTRACTINFO'].fields_by_name['extension']._serialized_options = b'\312\264-\025ContractInfoExtension'
  _globals['_CONTRACTINFO']._loaded_options = None
  _globals['_CONTRACTINFO']._serialized_options = b'\350\240\037\001'
  _globals['_CONTRACTCODEHISTORYENTRY'].fields_by_name['code_id']._loaded_options = None
  _globals['_CONTRACTCODEHISTORYENTRY'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_CONTRACTCODEHISTORYENTRY'].fields_by_name['msg']._loaded_options = None
  _globals['_CONTRACTCODEHISTORYENTRY'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _globals['_MODEL'].fields_by_name['key']._loaded_options = None
  _globals['_MODEL'].fields_by_name['key']._serialized_options = b'\372\336\0374github.com/tendermint/tendermint/libs/bytes.HexBytes'
  _globals['_ACCESSTYPE']._serialized_start=1335
  _globals['_ACCESSTYPE']._serialized_end=1568
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE']._serialized_start=1571
  _globals['_CONTRACTCODEHISTORYOPERATIONTYPE']._serialized_end=1993
  _globals['_ACCESSTYPEPARAM']._serialized_start=126
  _globals['_ACCESSTYPEPARAM']._serialized_end=212
  _globals['_ACCESSCONFIG']._serialized_start=215
  _globals['_ACCESSCONFIG']._serialized_end=345
  _globals['_PARAMS']._serialized_start=348
  _globals['_PARAMS']._serialized_end=570
  _globals['_CODEINFO']._serialized_start=572
  _globals['_CODEINFO']._serialized_end=696
  _globals['_CONTRACTINFO']._serialized_start=699
  _globals['_CONTRACTINFO']._serialized_end=954
  _globals['_CONTRACTCODEHISTORYENTRY']._serialized_start=957
  _globals['_CONTRACTCODEHISTORYENTRY']._serialized_end=1175
  _globals['_ABSOLUTETXPOSITION']._serialized_start=1177
  _globals['_ABSOLUTETXPOSITION']._serialized_end=1237
  _globals['_MODEL']._serialized_start=1239
  _globals['_MODEL']._serialized_end=1332
# @@protoc_insertion_point(module_scope)
