# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/ganglion/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/ganglion/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from neurion.ganglion import params_pb2 as neurion_dot_ganglion_dot_params__pb2
from neurion.ganglion import ion_pb2 as neurion_dot_ganglion_dot_ion__pb2
from neurion.ganglion import pathway_pb2 as neurion_dot_ganglion_dot_pathway__pb2
from neurion.ganglion import pathway_user_pb2 as neurion_dot_ganglion_dot_pathway__user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cneurion/ganglion/query.proto\x12\x10neurion.ganglion\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1dneurion/ganglion/params.proto\x1a\x1aneurion/ganglion/ion.proto\x1a\x1eneurion/ganglion/pathway.proto\x1a#neurion/ganglion/pathway_user.proto\"\x14\n\x12QueryParamsRequest\"J\n\x13QueryParamsResponse\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x18.neurion.ganglion.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"2\n\x1bQueryIonByIonAddressRequest\x12\x13\n\x0bion_address\x18\x01 \x01(\t\"B\n\x1cQueryIonByIonAddressResponse\x12\"\n\x03ion\x18\x01 \x01(\x0b\x32\x15.neurion.ganglion.Ion\"+\n\x18QueryIonByCreatorRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\"?\n\x19QueryIonByCreatorResponse\x12\"\n\x03ion\x18\x01 \x01(\x0b\x32\x15.neurion.ganglion.Ion\"\x1b\n\x19QueryGetValidatorsRequest\"0\n\x1aQueryGetValidatorsResponse\x12\x12\n\nvalidators\x18\x01 \x03(\t\"k\n!QueryIonsByInputSchemaHashRequest\x12\x19\n\x11input_schema_hash\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x04\x12\r\n\x05limit\x18\x04 \x01(\x04\"\x91\x01\n\"QueryIonsByInputSchemaHashResponse\x12.\n\x04ions\x18\x01 \x03(\x0b\x32\x15.neurion.ganglion.IonB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"$\n\x16QueryGetPathwayRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"P\n\x17QueryGetPathwayResponse\x12\x35\n\x07pathway\x18\x01 \x01(\x0b\x32\x19.neurion.ganglion.PathwayB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"J\n\x18QueryListPathwaysRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\x90\x01\n\x19QueryListPathwaysResponse\x12\x36\n\x08pathways\x18\x01 \x03(\x0b\x32\x19.neurion.ganglion.PathwayB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"8\n\x1fQueryListIonsByAddressesRequest\x12\x15\n\rion_addresses\x18\x01 \x03(\t\"R\n QueryListIonsByAddressesResponse\x12.\n\x04ions\x18\x01 \x03(\x0b\x32\x15.neurion.ganglion.IonB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"8\n\x1cQueryUserPathwayStakeRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\".\n\x1dQueryUserPathwayStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\")\n\x19QueryGetUserRewardRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\",\n\x1aQueryGetUserRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"\x1c\n\x1aQueryGetProtocolFeeRequest\"*\n\x1bQueryGetProtocolFeeResponse\x12\x0b\n\x03\x66\x65\x65\x18\x01 \x01(\x04\"3\n\x1cQueryPathwaysUsingIonRequest\x12\x13\n\x0bion_address\x18\x01 \x01(\t\"W\n\x1dQueryPathwaysUsingIonResponse\x12\x36\n\x08pathways\x18\x01 \x03(\x0b\x32\x19.neurion.ganglion.PathwayB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\":\n\x19QueryIonsByReportsRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x04\"p\n\x1aQueryIonsByReportsResponse\x12\x15\n\rion_addresses\x18\x01 \x03(\t\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"<\n\x1bQueryListAllPathwaysRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x04\"\x93\x01\n\x1cQueryListAllPathwaysResponse\x12\x36\n\x08pathways\x18\x01 \x03(\x0b\x32\x19.neurion.ganglion.PathwayB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"%\n\x15QueryGetRewardRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"(\n\x16QueryGetRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"$\n\x14QueryGetStakeRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"&\n\x15QueryGetStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\" \n\x12QueryGetIonRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"D\n\x13QueryGetIonResponse\x12-\n\x03ion\x18\x01 \x01(\x0b\x32\x15.neurion.ganglion.IonB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"-\n+QueryGetPathwayUnstakeInitiatedUsersRequest\"o\n,QueryGetPathwayUnstakeInitiatedUsersResponse\x12?\n\rpathway_users\x18\x01 \x03(\x0b\x32\x1d.neurion.ganglion.PathwayUserB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x1d\n\x1bQueryGetStakerRewardRequest\".\n\x1cQueryGetStakerRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"K\n\x1cQueryGetAvailableIonsRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\x8c\x01\n\x1dQueryGetAvailableIonsResponse\x12.\n\x04ions\x18\x01 \x03(\x0b\x32\x15.neurion.ganglion.IonB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"T\n\x1cQueryValidateIonChainRequest\x12\x0c\n\x04ion1\x18\x01 \x01(\t\x12\x0c\n\x04ion2\x18\x02 \x01(\t\x12\x18\n\x10\x66ield_map_base64\x18\x03 \x01(\t\">\n\x1dQueryValidateIonChainResponse\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x1b\n\x19QueryGetAllowedIpsRequest\")\n\x1aQueryGetAllowedIpsResponse\x12\x0b\n\x03ips\x18\x01 \x03(\t2\xf2\x1c\n\x05Query\x12w\n\x06Params\x12$.neurion.ganglion.QueryParamsRequest\x1a%.neurion.ganglion.QueryParamsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/neurion/ganglion/params\x12\xac\x01\n\x0fIonByIonAddress\x12-.neurion.ganglion.QueryIonByIonAddressRequest\x1a..neurion.ganglion.QueryIonByIonAddressResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/ganglion/ion_by_ion_address/{ion_address}\x12\x9b\x01\n\x0cIonByCreator\x12*.neurion.ganglion.QueryIonByCreatorRequest\x1a+.neurion.ganglion.QueryIonByCreatorResponse\"2\x82\xd3\xe4\x93\x02,\x12*/neurion/ganglion/ion_by_creator/{creator}\x12\x94\x01\n\rGetValidators\x12+.neurion.ganglion.QueryGetValidatorsRequest\x1a,.neurion.ganglion.QueryGetValidatorsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /neurion/ganglion/get_validators\x12\xe3\x01\n\x15IonsByInputSchemaHash\x12\x33.neurion.ganglion.QueryIonsByInputSchemaHashRequest\x1a\x34.neurion.ganglion.QueryIonsByInputSchemaHashResponse\"_\x82\xd3\xe4\x93\x02Y\x12W/neurion/ganglion/ions_by_input_schema_hash/{input_schema_hash}/{user}/{offset}/{limit}\x12\x8d\x01\n\nGetPathway\x12(.neurion.ganglion.QueryGetPathwayRequest\x1a).neurion.ganglion.QueryGetPathwayResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/neurion/ganglion/get_pathway/{id}\x12\xab\x01\n\x0cListPathways\x12*.neurion.ganglion.QueryListPathwaysRequest\x1a+.neurion.ganglion.QueryListPathwaysResponse\"B\x82\xd3\xe4\x93\x02<\x12:/neurion/ganglion/list_pathways/{creator}/{offset}/{limit}\x12\xbe\x01\n\x13ListIonsByAddresses\x12\x31.neurion.ganglion.QueryListIonsByAddressesRequest\x1a\x32.neurion.ganglion.QueryListIonsByAddressesResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/neurion/ganglion/list_ions_by_addresses/{ion_addresses}\x12\xad\x01\n\x10UserPathwayStake\x12..neurion.ganglion.QueryUserPathwayStakeRequest\x1a/.neurion.ganglion.QueryUserPathwayStakeResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/neurion/ganglion/user_pathway_stake/{id}/{user}\x12\x9c\x01\n\rGetUserReward\x12+.neurion.ganglion.QueryGetUserRewardRequest\x1a,.neurion.ganglion.QueryGetUserRewardResponse\"0\x82\xd3\xe4\x93\x02*\x12(/neurion/ganglion/get_user_reward/{user}\x12\x99\x01\n\x0eGetProtocolFee\x12,.neurion.ganglion.QueryGetProtocolFeeRequest\x1a-.neurion.ganglion.QueryGetProtocolFeeResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/neurion/ganglion/get_protocol_fee\x12\xaf\x01\n\x10PathwaysUsingIon\x12..neurion.ganglion.QueryPathwaysUsingIonRequest\x1a/.neurion.ganglion.QueryPathwaysUsingIonResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/ganglion/pathways_using_ion/{ion_address}\x12\xa6\x01\n\rIonsByReports\x12+.neurion.ganglion.QueryIonsByReportsRequest\x1a,.neurion.ganglion.QueryIonsByReportsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/ganglion/ions_by_reports/{offset}/{limit}\x12\xae\x01\n\x0fListAllPathways\x12-.neurion.ganglion.QueryListAllPathwaysRequest\x1a..neurion.ganglion.QueryListAllPathwaysResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/neurion/ganglion/list_all_pathways/{offset}/{limit}\x12\x8b\x01\n\tGetReward\x12\'.neurion.ganglion.QueryGetRewardRequest\x1a(.neurion.ganglion.QueryGetRewardResponse\"+\x82\xd3\xe4\x93\x02%\x12#/neurion/ganglion/get_reward/{user}\x12\x87\x01\n\x08GetStake\x12&.neurion.ganglion.QueryGetStakeRequest\x1a\'.neurion.ganglion.QueryGetStakeResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/neurion/ganglion/get_stake/{user}\x12}\n\x06GetIon\x12$.neurion.ganglion.QueryGetIonRequest\x1a%.neurion.ganglion.QueryGetIonResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/neurion/ganglion/get_ion/{id}\x12\xdf\x01\n\x1fGetPathwayUnstakeInitiatedUsers\x12=.neurion.ganglion.QueryGetPathwayUnstakeInitiatedUsersRequest\x1a>.neurion.ganglion.QueryGetPathwayUnstakeInitiatedUsersResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/neurion/ganglion/get_pathway_unstake_initiated_users\x12\x9d\x01\n\x0fGetStakerReward\x12-.neurion.ganglion.QueryGetStakerRewardRequest\x1a..neurion.ganglion.QueryGetStakerRewardResponse\"+\x82\xd3\xe4\x93\x02%\x12#/neurion/ganglion/get_staker_reward\x12\xb9\x01\n\x10GetAvailableIons\x12..neurion.ganglion.QueryGetAvailableIonsRequest\x1a/.neurion.ganglion.QueryGetAvailableIonsResponse\"D\x82\xd3\xe4\x93\x02>\x12</neurion/ganglion/get_available_ions/{user}/{offset}/{limit}\x12\xc2\x01\n\x10ValidateIonChain\x12..neurion.ganglion.QueryValidateIonChainRequest\x1a/.neurion.ganglion.QueryValidateIonChainResponse\"M\x82\xd3\xe4\x93\x02G\x12\x45/neurion/ganglion/validate_ion_chain/{ion1}/{ion2}/{field_map_base64}\x12\x95\x01\n\rGetAllowedIps\x12+.neurion.ganglion.QueryGetAllowedIpsRequest\x1a,.neurion.ganglion.QueryGetAllowedIpsResponse\")\x82\xd3\xe4\x93\x02#\x12!/neurion/ganglion/get_allowed_ipsB\x1aZ\x18neurion/x/ganglion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.ganglion.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/ganglion/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYIONSBYINPUTSCHEMAHASHRESPONSE'].fields_by_name['ions']._loaded_options = None
  _globals['_QUERYIONSBYINPUTSCHEMAHASHRESPONSE'].fields_by_name['ions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPATHWAYRESPONSE'].fields_by_name['pathway']._loaded_options = None
  _globals['_QUERYGETPATHWAYRESPONSE'].fields_by_name['pathway']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTPATHWAYSRESPONSE'].fields_by_name['pathways']._loaded_options = None
  _globals['_QUERYLISTPATHWAYSRESPONSE'].fields_by_name['pathways']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTIONSBYADDRESSESRESPONSE'].fields_by_name['ions']._loaded_options = None
  _globals['_QUERYLISTIONSBYADDRESSESRESPONSE'].fields_by_name['ions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYPATHWAYSUSINGIONRESPONSE'].fields_by_name['pathways']._loaded_options = None
  _globals['_QUERYPATHWAYSUSINGIONRESPONSE'].fields_by_name['pathways']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTALLPATHWAYSRESPONSE'].fields_by_name['pathways']._loaded_options = None
  _globals['_QUERYLISTALLPATHWAYSRESPONSE'].fields_by_name['pathways']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETIONRESPONSE'].fields_by_name['ion']._loaded_options = None
  _globals['_QUERYGETIONRESPONSE'].fields_by_name['ion']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPATHWAYUNSTAKEINITIATEDUSERSRESPONSE'].fields_by_name['pathway_users']._loaded_options = None
  _globals['_QUERYGETPATHWAYUNSTAKEINITIATEDUSERSRESPONSE'].fields_by_name['pathway_users']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETAVAILABLEIONSRESPONSE'].fields_by_name['ions']._loaded_options = None
  _globals['_QUERYGETAVAILABLEIONSRESPONSE'].fields_by_name['ions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\032\022\030/neurion/ganglion/params'
  _globals['_QUERY'].methods_by_name['IonByIonAddress']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IonByIonAddress']._serialized_options = b'\202\323\344\223\0024\0222/neurion/ganglion/ion_by_ion_address/{ion_address}'
  _globals['_QUERY'].methods_by_name['IonByCreator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IonByCreator']._serialized_options = b'\202\323\344\223\002,\022*/neurion/ganglion/ion_by_creator/{creator}'
  _globals['_QUERY'].methods_by_name['GetValidators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetValidators']._serialized_options = b'\202\323\344\223\002\"\022 /neurion/ganglion/get_validators'
  _globals['_QUERY'].methods_by_name['IonsByInputSchemaHash']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IonsByInputSchemaHash']._serialized_options = b'\202\323\344\223\002Y\022W/neurion/ganglion/ions_by_input_schema_hash/{input_schema_hash}/{user}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['GetPathway']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPathway']._serialized_options = b'\202\323\344\223\002$\022\"/neurion/ganglion/get_pathway/{id}'
  _globals['_QUERY'].methods_by_name['ListPathways']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListPathways']._serialized_options = b'\202\323\344\223\002<\022:/neurion/ganglion/list_pathways/{creator}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['ListIonsByAddresses']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListIonsByAddresses']._serialized_options = b'\202\323\344\223\002:\0228/neurion/ganglion/list_ions_by_addresses/{ion_addresses}'
  _globals['_QUERY'].methods_by_name['UserPathwayStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UserPathwayStake']._serialized_options = b'\202\323\344\223\0022\0220/neurion/ganglion/user_pathway_stake/{id}/{user}'
  _globals['_QUERY'].methods_by_name['GetUserReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetUserReward']._serialized_options = b'\202\323\344\223\002*\022(/neurion/ganglion/get_user_reward/{user}'
  _globals['_QUERY'].methods_by_name['GetProtocolFee']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetProtocolFee']._serialized_options = b'\202\323\344\223\002$\022\"/neurion/ganglion/get_protocol_fee'
  _globals['_QUERY'].methods_by_name['PathwaysUsingIon']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PathwaysUsingIon']._serialized_options = b'\202\323\344\223\0024\0222/neurion/ganglion/pathways_using_ion/{ion_address}'
  _globals['_QUERY'].methods_by_name['IonsByReports']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IonsByReports']._serialized_options = b'\202\323\344\223\0024\0222/neurion/ganglion/ions_by_reports/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['ListAllPathways']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListAllPathways']._serialized_options = b'\202\323\344\223\0026\0224/neurion/ganglion/list_all_pathways/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['GetReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetReward']._serialized_options = b'\202\323\344\223\002%\022#/neurion/ganglion/get_reward/{user}'
  _globals['_QUERY'].methods_by_name['GetStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetStake']._serialized_options = b'\202\323\344\223\002$\022\"/neurion/ganglion/get_stake/{user}'
  _globals['_QUERY'].methods_by_name['GetIon']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetIon']._serialized_options = b'\202\323\344\223\002 \022\036/neurion/ganglion/get_ion/{id}'
  _globals['_QUERY'].methods_by_name['GetPathwayUnstakeInitiatedUsers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPathwayUnstakeInitiatedUsers']._serialized_options = b'\202\323\344\223\0027\0225/neurion/ganglion/get_pathway_unstake_initiated_users'
  _globals['_QUERY'].methods_by_name['GetStakerReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetStakerReward']._serialized_options = b'\202\323\344\223\002%\022#/neurion/ganglion/get_staker_reward'
  _globals['_QUERY'].methods_by_name['GetAvailableIons']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetAvailableIons']._serialized_options = b'\202\323\344\223\002>\022</neurion/ganglion/get_available_ions/{user}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['ValidateIonChain']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValidateIonChain']._serialized_options = b'\202\323\344\223\002G\022E/neurion/ganglion/validate_ion_chain/{ion1}/{ion2}/{field_map_base64}'
  _globals['_QUERY'].methods_by_name['GetAllowedIps']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetAllowedIps']._serialized_options = b'\202\323\344\223\002#\022!/neurion/ganglion/get_allowed_ips'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=293
  _globals['_QUERYPARAMSREQUEST']._serialized_end=313
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=315
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=389
  _globals['_QUERYIONBYIONADDRESSREQUEST']._serialized_start=391
  _globals['_QUERYIONBYIONADDRESSREQUEST']._serialized_end=441
  _globals['_QUERYIONBYIONADDRESSRESPONSE']._serialized_start=443
  _globals['_QUERYIONBYIONADDRESSRESPONSE']._serialized_end=509
  _globals['_QUERYIONBYCREATORREQUEST']._serialized_start=511
  _globals['_QUERYIONBYCREATORREQUEST']._serialized_end=554
  _globals['_QUERYIONBYCREATORRESPONSE']._serialized_start=556
  _globals['_QUERYIONBYCREATORRESPONSE']._serialized_end=619
  _globals['_QUERYGETVALIDATORSREQUEST']._serialized_start=621
  _globals['_QUERYGETVALIDATORSREQUEST']._serialized_end=648
  _globals['_QUERYGETVALIDATORSRESPONSE']._serialized_start=650
  _globals['_QUERYGETVALIDATORSRESPONSE']._serialized_end=698
  _globals['_QUERYIONSBYINPUTSCHEMAHASHREQUEST']._serialized_start=700
  _globals['_QUERYIONSBYINPUTSCHEMAHASHREQUEST']._serialized_end=807
  _globals['_QUERYIONSBYINPUTSCHEMAHASHRESPONSE']._serialized_start=810
  _globals['_QUERYIONSBYINPUTSCHEMAHASHRESPONSE']._serialized_end=955
  _globals['_QUERYGETPATHWAYREQUEST']._serialized_start=957
  _globals['_QUERYGETPATHWAYREQUEST']._serialized_end=993
  _globals['_QUERYGETPATHWAYRESPONSE']._serialized_start=995
  _globals['_QUERYGETPATHWAYRESPONSE']._serialized_end=1075
  _globals['_QUERYLISTPATHWAYSREQUEST']._serialized_start=1077
  _globals['_QUERYLISTPATHWAYSREQUEST']._serialized_end=1151
  _globals['_QUERYLISTPATHWAYSRESPONSE']._serialized_start=1154
  _globals['_QUERYLISTPATHWAYSRESPONSE']._serialized_end=1298
  _globals['_QUERYLISTIONSBYADDRESSESREQUEST']._serialized_start=1300
  _globals['_QUERYLISTIONSBYADDRESSESREQUEST']._serialized_end=1356
  _globals['_QUERYLISTIONSBYADDRESSESRESPONSE']._serialized_start=1358
  _globals['_QUERYLISTIONSBYADDRESSESRESPONSE']._serialized_end=1440
  _globals['_QUERYUSERPATHWAYSTAKEREQUEST']._serialized_start=1442
  _globals['_QUERYUSERPATHWAYSTAKEREQUEST']._serialized_end=1498
  _globals['_QUERYUSERPATHWAYSTAKERESPONSE']._serialized_start=1500
  _globals['_QUERYUSERPATHWAYSTAKERESPONSE']._serialized_end=1546
  _globals['_QUERYGETUSERREWARDREQUEST']._serialized_start=1548
  _globals['_QUERYGETUSERREWARDREQUEST']._serialized_end=1589
  _globals['_QUERYGETUSERREWARDRESPONSE']._serialized_start=1591
  _globals['_QUERYGETUSERREWARDRESPONSE']._serialized_end=1635
  _globals['_QUERYGETPROTOCOLFEEREQUEST']._serialized_start=1637
  _globals['_QUERYGETPROTOCOLFEEREQUEST']._serialized_end=1665
  _globals['_QUERYGETPROTOCOLFEERESPONSE']._serialized_start=1667
  _globals['_QUERYGETPROTOCOLFEERESPONSE']._serialized_end=1709
  _globals['_QUERYPATHWAYSUSINGIONREQUEST']._serialized_start=1711
  _globals['_QUERYPATHWAYSUSINGIONREQUEST']._serialized_end=1762
  _globals['_QUERYPATHWAYSUSINGIONRESPONSE']._serialized_start=1764
  _globals['_QUERYPATHWAYSUSINGIONRESPONSE']._serialized_end=1851
  _globals['_QUERYIONSBYREPORTSREQUEST']._serialized_start=1853
  _globals['_QUERYIONSBYREPORTSREQUEST']._serialized_end=1911
  _globals['_QUERYIONSBYREPORTSRESPONSE']._serialized_start=1913
  _globals['_QUERYIONSBYREPORTSRESPONSE']._serialized_end=2025
  _globals['_QUERYLISTALLPATHWAYSREQUEST']._serialized_start=2027
  _globals['_QUERYLISTALLPATHWAYSREQUEST']._serialized_end=2087
  _globals['_QUERYLISTALLPATHWAYSRESPONSE']._serialized_start=2090
  _globals['_QUERYLISTALLPATHWAYSRESPONSE']._serialized_end=2237
  _globals['_QUERYGETREWARDREQUEST']._serialized_start=2239
  _globals['_QUERYGETREWARDREQUEST']._serialized_end=2276
  _globals['_QUERYGETREWARDRESPONSE']._serialized_start=2278
  _globals['_QUERYGETREWARDRESPONSE']._serialized_end=2318
  _globals['_QUERYGETSTAKEREQUEST']._serialized_start=2320
  _globals['_QUERYGETSTAKEREQUEST']._serialized_end=2356
  _globals['_QUERYGETSTAKERESPONSE']._serialized_start=2358
  _globals['_QUERYGETSTAKERESPONSE']._serialized_end=2396
  _globals['_QUERYGETIONREQUEST']._serialized_start=2398
  _globals['_QUERYGETIONREQUEST']._serialized_end=2430
  _globals['_QUERYGETIONRESPONSE']._serialized_start=2432
  _globals['_QUERYGETIONRESPONSE']._serialized_end=2500
  _globals['_QUERYGETPATHWAYUNSTAKEINITIATEDUSERSREQUEST']._serialized_start=2502
  _globals['_QUERYGETPATHWAYUNSTAKEINITIATEDUSERSREQUEST']._serialized_end=2547
  _globals['_QUERYGETPATHWAYUNSTAKEINITIATEDUSERSRESPONSE']._serialized_start=2549
  _globals['_QUERYGETPATHWAYUNSTAKEINITIATEDUSERSRESPONSE']._serialized_end=2660
  _globals['_QUERYGETSTAKERREWARDREQUEST']._serialized_start=2662
  _globals['_QUERYGETSTAKERREWARDREQUEST']._serialized_end=2691
  _globals['_QUERYGETSTAKERREWARDRESPONSE']._serialized_start=2693
  _globals['_QUERYGETSTAKERREWARDRESPONSE']._serialized_end=2739
  _globals['_QUERYGETAVAILABLEIONSREQUEST']._serialized_start=2741
  _globals['_QUERYGETAVAILABLEIONSREQUEST']._serialized_end=2816
  _globals['_QUERYGETAVAILABLEIONSRESPONSE']._serialized_start=2819
  _globals['_QUERYGETAVAILABLEIONSRESPONSE']._serialized_end=2959
  _globals['_QUERYVALIDATEIONCHAINREQUEST']._serialized_start=2961
  _globals['_QUERYVALIDATEIONCHAINREQUEST']._serialized_end=3045
  _globals['_QUERYVALIDATEIONCHAINRESPONSE']._serialized_start=3047
  _globals['_QUERYVALIDATEIONCHAINRESPONSE']._serialized_end=3109
  _globals['_QUERYGETALLOWEDIPSREQUEST']._serialized_start=3111
  _globals['_QUERYGETALLOWEDIPSREQUEST']._serialized_end=3138
  _globals['_QUERYGETALLOWEDIPSRESPONSE']._serialized_start=3140
  _globals['_QUERYGETALLOWEDIPSRESPONSE']._serialized_end=3181
  _globals['_QUERY']._serialized_start=3184
  _globals['_QUERY']._serialized_end=6882
# @@protoc_insertion_point(module_scope)
