# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/task.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bneurion/crucible/task.proto\x12\x10neurion.crucible\"\xb9\x03\n\x04Task\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0e\n\x06reward\x18\x05 \x01(\x04\x12\x18\n\x10\x64uration_in_days\x18\x06 \x01(\x04\x12\x14\n\x0ctraining_kit\x18\x07 \x01(\t\x12\x16\n\x0evalidation_kit\x18\x08 \x01(\t\x12\x16\n\x0e\x66inal_test_kit\x18\t \x01(\t\x12,\n\x06status\x18\n \x01(\x0e\x32\x1c.neurion.crucible.TaskStatus\x12\x19\n\x11\x63reated_timestamp\x18\x0b \x01(\x04\x12\x19\n\x11started_timestamp\x18\x0c \x01(\x04\x12\x1c\n\x14terminated_timestamp\x18\r \x01(\x04\x12\"\n\x1a\x66inal_submission_timestamp\x18\x0e \x01(\x04\x12\x1f\n\x17\x66inal_testing_timestamp\x18\x0f \x01(\x04\x12\x1f\n\x17\x66inal_dispute_timestamp\x18\x10 \x01(\x04\x12\x19\n\x11\x61\x62orted_timestamp\x18\x11 \x01(\x04*\xd3\x01\n\nTaskStatus\x12\x17\n\x13TASK_STATUS_CREATED\x10\x00\x12\x17\n\x13TASK_STATUS_STARTED\x10\x01\x12\x17\n\x13TASK_STATUS_ABORTED\x10\x02\x12 \n\x1cTASK_STATUS_FINAL_SUBMISSION\x10\x04\x12\x1d\n\x19TASK_STATUS_FINAL_TESTING\x10\x05\x12\x1d\n\x19TASK_STATUS_FINAL_DISPUTE\x10\x06\x12\x1a\n\x16TASK_STATUS_TERMINATED\x10\x07\x42\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_TASKSTATUS']._serialized_start=494
  _globals['_TASKSTATUS']._serialized_end=705
  _globals['_TASK']._serialized_start=50
  _globals['_TASK']._serialized_end=491
# @@protoc_insertion_point(module_scope)
