# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmwasm/wasm/v1/genesis.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmwasm/wasm/v1/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from cosmwasm.wasm.v1 import tx_pb2 as cosmwasm_dot_wasm_dot_v1_dot_tx__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmwasm/wasm/v1/genesis.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x19\x63osmwasm/wasm/v1/tx.proto\"\xc1\x04\n\x0cGenesisState\x12.\n\x06params\x18\x01 \x01(\x0b\x32\x18.cosmwasm.wasm.v1.ParamsB\x04\xc8\xde\x1f\x00\x12>\n\x05\x63odes\x18\x02 \x03(\x0b\x32\x16.cosmwasm.wasm.v1.CodeB\x17\xc8\xde\x1f\x00\xea\xde\x1f\x0f\x63odes,omitempty\x12J\n\tcontracts\x18\x03 \x03(\x0b\x32\x1a.cosmwasm.wasm.v1.ContractB\x1b\xc8\xde\x1f\x00\xea\xde\x1f\x13\x63ontracts,omitempty\x12J\n\tsequences\x18\x04 \x03(\x0b\x32\x1a.cosmwasm.wasm.v1.SequenceB\x1b\xc8\xde\x1f\x00\xea\xde\x1f\x13sequences,omitempty\x12T\n\x08gen_msgs\x18\x05 \x03(\x0b\x32&.cosmwasm.wasm.v1.GenesisState.GenMsgsB\x1a\xc8\xde\x1f\x00\xea\xde\x1f\x12gen_msgs,omitempty\x1a\xd2\x01\n\x07GenMsgs\x12\x34\n\nstore_code\x18\x01 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.MsgStoreCodeH\x00\x12H\n\x14instantiate_contract\x18\x02 \x01(\x0b\x32(.cosmwasm.wasm.v1.MsgInstantiateContractH\x00\x12@\n\x10\x65xecute_contract\x18\x03 \x01(\x0b\x32$.cosmwasm.wasm.v1.MsgExecuteContractH\x00\x42\x05\n\x03sum\"|\n\x04\x43ode\x12\x1b\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x33\n\tcode_info\x18\x02 \x01(\x0b\x32\x1a.cosmwasm.wasm.v1.CodeInfoB\x04\xc8\xde\x1f\x00\x12\x12\n\ncode_bytes\x18\x03 \x01(\x0c\x12\x0e\n\x06pinned\x18\x04 \x01(\x08\"\x98\x01\n\x08\x43ontract\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12;\n\rcontract_info\x18\x02 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.ContractInfoB\x04\xc8\xde\x1f\x00\x12\x35\n\x0e\x63ontract_state\x18\x03 \x03(\x0b\x32\x17.cosmwasm.wasm.v1.ModelB\x04\xc8\xde\x1f\x00\"4\n\x08Sequence\x12\x19\n\x06id_key\x18\x01 \x01(\x0c\x42\t\xe2\xde\x1f\x05IDKey\x12\r\n\x05value\x18\x02 \x01(\x04\x42(Z&github.com/CosmWasm/wasmd/x/wasm/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['codes']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['codes']._serialized_options = b'\310\336\037\000\352\336\037\017codes,omitempty'
  _globals['_GENESISSTATE'].fields_by_name['contracts']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['contracts']._serialized_options = b'\310\336\037\000\352\336\037\023contracts,omitempty'
  _globals['_GENESISSTATE'].fields_by_name['sequences']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['sequences']._serialized_options = b'\310\336\037\000\352\336\037\023sequences,omitempty'
  _globals['_GENESISSTATE'].fields_by_name['gen_msgs']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['gen_msgs']._serialized_options = b'\310\336\037\000\352\336\037\022gen_msgs,omitempty'
  _globals['_CODE'].fields_by_name['code_id']._loaded_options = None
  _globals['_CODE'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_CODE'].fields_by_name['code_info']._loaded_options = None
  _globals['_CODE'].fields_by_name['code_info']._serialized_options = b'\310\336\037\000'
  _globals['_CONTRACT'].fields_by_name['contract_info']._loaded_options = None
  _globals['_CONTRACT'].fields_by_name['contract_info']._serialized_options = b'\310\336\037\000'
  _globals['_CONTRACT'].fields_by_name['contract_state']._loaded_options = None
  _globals['_CONTRACT'].fields_by_name['contract_state']._serialized_options = b'\310\336\037\000'
  _globals['_SEQUENCE'].fields_by_name['id_key']._loaded_options = None
  _globals['_SEQUENCE'].fields_by_name['id_key']._serialized_options = b'\342\336\037\005IDKey'
  _globals['_GENESISSTATE']._serialized_start=132
  _globals['_GENESISSTATE']._serialized_end=709
  _globals['_GENESISSTATE_GENMSGS']._serialized_start=499
  _globals['_GENESISSTATE_GENMSGS']._serialized_end=709
  _globals['_CODE']._serialized_start=711
  _globals['_CODE']._serialized_end=835
  _globals['_CONTRACT']._serialized_start=838
  _globals['_CONTRACT']._serialized_end=990
  _globals['_SEQUENCE']._serialized_start=992
  _globals['_SEQUENCE']._serialized_end=1044
# @@protoc_insertion_point(module_scope)
