# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/dispute_validation_task.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/dispute_validation_task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,neurion/fusion/dispute_validation_task.proto\x12\x0eneurion.fusion\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\x81\x03\n\x15\x44isputeValidationTask\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12\x19\n\x11proposed_model_id\x18\x03 \x01(\x04\x12N\n\x0eproposed_score\x18\x04 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12\x0f\n\x07\x64\x65posit\x18\x05 \x01(\x04\x12;\n\x06result\x18\x06 \x01(\x0e\x32+.neurion.fusion.DisputeValidationTaskResult\x12\x19\n\x11\x63reated_timestamp\x18\x07 \x01(\x04\x12\x1a\n\x12\x64\x65\x63ision_timestamp\x18\x08 \x01(\x04\x12$\n\x1c\x61\x63\x63\x65pting_dispute_validators\x18\t \x03(\t\x12$\n\x1crejecting_dispute_validators\x18\n \x03(\t\x12\x0f\n\x07task_id\x18\x0b \x01(\x04*\xa9\x01\n\x1b\x44isputeValidationTaskResult\x12\x30\n,DISPUTE_VALIDATION_TASK_RESULT_NOT_AVAILABLE\x10\x00\x12+\n\'DISPUTE_VALIDATION_TASK_RESULT_ACCEPTED\x10\x01\x12+\n\'DISPUTE_VALIDATION_TASK_RESULT_REJECTED\x10\x02\x42\x18Z\x16neurion/x/fusion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.dispute_validation_task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\026neurion/x/fusion/types'
  _globals['_DISPUTEVALIDATIONTASK'].fields_by_name['proposed_score']._loaded_options = None
  _globals['_DISPUTEVALIDATIONTASK'].fields_by_name['proposed_score']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_DISPUTEVALIDATIONTASKRESULT']._serialized_start=521
  _globals['_DISPUTEVALIDATIONTASKRESULT']._serialized_end=690
  _globals['_DISPUTEVALIDATIONTASK']._serialized_start=133
  _globals['_DISPUTEVALIDATIONTASK']._serialized_end=518
# @@protoc_insertion_point(module_scope)
