# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/ganglion/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/ganglion/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from neurion.ganglion import ion_pb2 as neurion_dot_ganglion_dot_ion__pb2
from neurion.ganglion import params_pb2 as neurion_dot_ganglion_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19neurion/ganglion/tx.proto\x12\x10neurion.ganglion\x1a\x11\x61mino/amino.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1aneurion/ganglion/ion.proto\x1a\x1dneurion/ganglion/params.proto\"\xaa\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x06params\x18\x02 \x01(\x0b\x32\x18.neurion.ganglion.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:5\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\"neurion/x/ganglion/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xf8\x01\n\x0eMsgRegisterIon\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x12\n\ncapacities\x18\x02 \x03(\t\x12\r\n\x05stake\x18\x03 \x01(\x04\x12\x11\n\tendpoints\x18\x04 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x14\n\x0cinput_schema\x18\x06 \x01(\t\x12\x15\n\routput_schema\x18\x07 \x01(\t\x12\x1e\n\x16\x66\x65\x65_per_thousand_calls\x18\x08 \x01(\x04\x12\x1e\n\x16\x61llowed_pathway_owners\x18\t \x03(\t\x12\x0f\n\x07private\x18\n \x01(\x08:\x0c\x82\xe7\xb0*\x07\x63reator\"\x18\n\x16MsgRegisterIonResponse\"M\n\x17MsgReportUnavailableIon\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x13\n\x0bion_address\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"!\n\x1fMsgReportUnavailableIonResponse\"O\n\x19MsgUnreportUnavailableIon\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x13\n\x0bion_address\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"#\n!MsgUnreportUnavailableIonResponse\"K\n\x0fMsgAddValidator\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x19\n\x11validator_address\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgAddValidatorResponse\"N\n\x12MsgRemoveValidator\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x19\n\x11validator_address\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgRemoveValidatorResponse\"`\n\x17MsgValidateAvailability\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x13\n\x0bion_address\x18\x02 \x01(\t\x12\x11\n\tavailable\x18\x03 \x01(\x08:\x0c\x82\xe7\xb0*\x07\x63reator\"2\n\x1fMsgValidateAvailabilityResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x92\x01\n\x12MsgRegisterPathway\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tis_public\x18\x04 \x01(\x08\x12\x0c\n\x04ions\x18\x05 \x03(\t\x12\x19\n\x11\x66ield_maps_base64\x18\x06 \x03(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgRegisterPathwayResponse\"L\n\x0fMsgStakePathway\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgStakePathwayResponse\"c\n\x15MsgRefundPathwayStake\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x11\n\tnum_calls\x18\x04 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgRefundPathwayStakeResponse\"B\n\x15MsgInitUnstakePathway\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgInitUnstakePathwayResponse\"4\n\x13MsgClaimProtocolFee\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1d\n\x1bMsgClaimProtocolFeeResponse\"c\n\x15MsgSettlePathwayStake\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x11\n\tnum_calls\x18\x04 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgSettlePathwayStakeResponse\"C\n\x12MsgStakeToGanglion\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgStakeToGanglionResponse\"/\n\x0eMsgClaimReward\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x18\n\x16MsgClaimRewardResponse\"G\n\x16MsgUnstakeFromGanglion\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\" \n\x1eMsgUnstakeFromGanglionResponse\"\x9c\x01\n\x10MsgUpdatePathway\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tis_public\x18\x05 \x01(\x08\x12\x0c\n\x04ions\x18\x06 \x03(\t\x12\x19\n\x11\x66ield_maps_base64\x18\x07 \x03(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgUpdatePathwayResponse\"-\n\x0cMsgRemoveIon\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x16\n\x14MsgRemoveIonResponse\"=\n\x10MsgRemovePathway\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgRemovePathwayResponse\">\n\x10MsgSetAllowedIps\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0b\n\x03ips\x18\x02 \x03(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgSetAllowedIpsResponse2\x9e\x10\n\x03Msg\x12\\\n\x0cUpdateParams\x12!.neurion.ganglion.MsgUpdateParams\x1a).neurion.ganglion.MsgUpdateParamsResponse\x12Y\n\x0bRegisterIon\x12 .neurion.ganglion.MsgRegisterIon\x1a(.neurion.ganglion.MsgRegisterIonResponse\x12t\n\x14ReportUnavailableIon\x12).neurion.ganglion.MsgReportUnavailableIon\x1a\x31.neurion.ganglion.MsgReportUnavailableIonResponse\x12z\n\x16UnreportUnavailableIon\x12+.neurion.ganglion.MsgUnreportUnavailableIon\x1a\x33.neurion.ganglion.MsgUnreportUnavailableIonResponse\x12\\\n\x0c\x41\x64\x64Validator\x12!.neurion.ganglion.MsgAddValidator\x1a).neurion.ganglion.MsgAddValidatorResponse\x12\x65\n\x0fRemoveValidator\x12$.neurion.ganglion.MsgRemoveValidator\x1a,.neurion.ganglion.MsgRemoveValidatorResponse\x12t\n\x14ValidateAvailability\x12).neurion.ganglion.MsgValidateAvailability\x1a\x31.neurion.ganglion.MsgValidateAvailabilityResponse\x12\x65\n\x0fRegisterPathway\x12$.neurion.ganglion.MsgRegisterPathway\x1a,.neurion.ganglion.MsgRegisterPathwayResponse\x12\\\n\x0cStakePathway\x12!.neurion.ganglion.MsgStakePathway\x1a).neurion.ganglion.MsgStakePathwayResponse\x12n\n\x12RefundPathwayStake\x12\'.neurion.ganglion.MsgRefundPathwayStake\x1a/.neurion.ganglion.MsgRefundPathwayStakeResponse\x12n\n\x12InitUnstakePathway\x12\'.neurion.ganglion.MsgInitUnstakePathway\x1a/.neurion.ganglion.MsgInitUnstakePathwayResponse\x12h\n\x10\x43laimProtocolFee\x12%.neurion.ganglion.MsgClaimProtocolFee\x1a-.neurion.ganglion.MsgClaimProtocolFeeResponse\x12n\n\x12SettlePathwayStake\x12\'.neurion.ganglion.MsgSettlePathwayStake\x1a/.neurion.ganglion.MsgSettlePathwayStakeResponse\x12\x65\n\x0fStakeToGanglion\x12$.neurion.ganglion.MsgStakeToGanglion\x1a,.neurion.ganglion.MsgStakeToGanglionResponse\x12Y\n\x0b\x43laimReward\x12 .neurion.ganglion.MsgClaimReward\x1a(.neurion.ganglion.MsgClaimRewardResponse\x12q\n\x13UnstakeFromGanglion\x12(.neurion.ganglion.MsgUnstakeFromGanglion\x1a\x30.neurion.ganglion.MsgUnstakeFromGanglionResponse\x12_\n\rUpdatePathway\x12\".neurion.ganglion.MsgUpdatePathway\x1a*.neurion.ganglion.MsgUpdatePathwayResponse\x12S\n\tRemoveIon\x12\x1e.neurion.ganglion.MsgRemoveIon\x1a&.neurion.ganglion.MsgRemoveIonResponse\x12_\n\rRemovePathway\x12\".neurion.ganglion.MsgRemovePathway\x1a*.neurion.ganglion.MsgRemovePathwayResponse\x12_\n\rSetAllowedIps\x12\".neurion.ganglion.MsgSetAllowedIps\x1a*.neurion.ganglion.MsgSetAllowedIpsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x1aZ\x18neurion/x/ganglion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.ganglion.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/ganglion/types'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\"neurion/x/ganglion/MsgUpdateParams'
  _globals['_MSGREGISTERION']._loaded_options = None
  _globals['_MSGREGISTERION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREPORTUNAVAILABLEION']._loaded_options = None
  _globals['_MSGREPORTUNAVAILABLEION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGUNREPORTUNAVAILABLEION']._loaded_options = None
  _globals['_MSGUNREPORTUNAVAILABLEION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGADDVALIDATOR']._loaded_options = None
  _globals['_MSGADDVALIDATOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREMOVEVALIDATOR']._loaded_options = None
  _globals['_MSGREMOVEVALIDATOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGVALIDATEAVAILABILITY']._loaded_options = None
  _globals['_MSGVALIDATEAVAILABILITY']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREGISTERPATHWAY']._loaded_options = None
  _globals['_MSGREGISTERPATHWAY']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTAKEPATHWAY']._loaded_options = None
  _globals['_MSGSTAKEPATHWAY']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREFUNDPATHWAYSTAKE']._loaded_options = None
  _globals['_MSGREFUNDPATHWAYSTAKE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGINITUNSTAKEPATHWAY']._loaded_options = None
  _globals['_MSGINITUNSTAKEPATHWAY']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCLAIMPROTOCOLFEE']._loaded_options = None
  _globals['_MSGCLAIMPROTOCOLFEE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSETTLEPATHWAYSTAKE']._loaded_options = None
  _globals['_MSGSETTLEPATHWAYSTAKE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSTAKETOGANGLION']._loaded_options = None
  _globals['_MSGSTAKETOGANGLION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCLAIMREWARD']._loaded_options = None
  _globals['_MSGCLAIMREWARD']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGUNSTAKEFROMGANGLION']._loaded_options = None
  _globals['_MSGUNSTAKEFROMGANGLION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGUPDATEPATHWAY']._loaded_options = None
  _globals['_MSGUPDATEPATHWAY']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREMOVEION']._loaded_options = None
  _globals['_MSGREMOVEION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREMOVEPATHWAY']._loaded_options = None
  _globals['_MSGREMOVEPATHWAY']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSETALLOWEDIPS']._loaded_options = None
  _globals['_MSGSETALLOWEDIPS']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=200
  _globals['_MSGUPDATEPARAMS']._serialized_end=370
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=372
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=397
  _globals['_MSGREGISTERION']._serialized_start=400
  _globals['_MSGREGISTERION']._serialized_end=648
  _globals['_MSGREGISTERIONRESPONSE']._serialized_start=650
  _globals['_MSGREGISTERIONRESPONSE']._serialized_end=674
  _globals['_MSGREPORTUNAVAILABLEION']._serialized_start=676
  _globals['_MSGREPORTUNAVAILABLEION']._serialized_end=753
  _globals['_MSGREPORTUNAVAILABLEIONRESPONSE']._serialized_start=755
  _globals['_MSGREPORTUNAVAILABLEIONRESPONSE']._serialized_end=788
  _globals['_MSGUNREPORTUNAVAILABLEION']._serialized_start=790
  _globals['_MSGUNREPORTUNAVAILABLEION']._serialized_end=869
  _globals['_MSGUNREPORTUNAVAILABLEIONRESPONSE']._serialized_start=871
  _globals['_MSGUNREPORTUNAVAILABLEIONRESPONSE']._serialized_end=906
  _globals['_MSGADDVALIDATOR']._serialized_start=908
  _globals['_MSGADDVALIDATOR']._serialized_end=983
  _globals['_MSGADDVALIDATORRESPONSE']._serialized_start=985
  _globals['_MSGADDVALIDATORRESPONSE']._serialized_end=1010
  _globals['_MSGREMOVEVALIDATOR']._serialized_start=1012
  _globals['_MSGREMOVEVALIDATOR']._serialized_end=1090
  _globals['_MSGREMOVEVALIDATORRESPONSE']._serialized_start=1092
  _globals['_MSGREMOVEVALIDATORRESPONSE']._serialized_end=1120
  _globals['_MSGVALIDATEAVAILABILITY']._serialized_start=1122
  _globals['_MSGVALIDATEAVAILABILITY']._serialized_end=1218
  _globals['_MSGVALIDATEAVAILABILITYRESPONSE']._serialized_start=1220
  _globals['_MSGVALIDATEAVAILABILITYRESPONSE']._serialized_end=1270
  _globals['_MSGREGISTERPATHWAY']._serialized_start=1273
  _globals['_MSGREGISTERPATHWAY']._serialized_end=1419
  _globals['_MSGREGISTERPATHWAYRESPONSE']._serialized_start=1421
  _globals['_MSGREGISTERPATHWAYRESPONSE']._serialized_end=1449
  _globals['_MSGSTAKEPATHWAY']._serialized_start=1451
  _globals['_MSGSTAKEPATHWAY']._serialized_end=1527
  _globals['_MSGSTAKEPATHWAYRESPONSE']._serialized_start=1529
  _globals['_MSGSTAKEPATHWAYRESPONSE']._serialized_end=1554
  _globals['_MSGREFUNDPATHWAYSTAKE']._serialized_start=1556
  _globals['_MSGREFUNDPATHWAYSTAKE']._serialized_end=1655
  _globals['_MSGREFUNDPATHWAYSTAKERESPONSE']._serialized_start=1657
  _globals['_MSGREFUNDPATHWAYSTAKERESPONSE']._serialized_end=1688
  _globals['_MSGINITUNSTAKEPATHWAY']._serialized_start=1690
  _globals['_MSGINITUNSTAKEPATHWAY']._serialized_end=1756
  _globals['_MSGINITUNSTAKEPATHWAYRESPONSE']._serialized_start=1758
  _globals['_MSGINITUNSTAKEPATHWAYRESPONSE']._serialized_end=1789
  _globals['_MSGCLAIMPROTOCOLFEE']._serialized_start=1791
  _globals['_MSGCLAIMPROTOCOLFEE']._serialized_end=1843
  _globals['_MSGCLAIMPROTOCOLFEERESPONSE']._serialized_start=1845
  _globals['_MSGCLAIMPROTOCOLFEERESPONSE']._serialized_end=1874
  _globals['_MSGSETTLEPATHWAYSTAKE']._serialized_start=1876
  _globals['_MSGSETTLEPATHWAYSTAKE']._serialized_end=1975
  _globals['_MSGSETTLEPATHWAYSTAKERESPONSE']._serialized_start=1977
  _globals['_MSGSETTLEPATHWAYSTAKERESPONSE']._serialized_end=2008
  _globals['_MSGSTAKETOGANGLION']._serialized_start=2010
  _globals['_MSGSTAKETOGANGLION']._serialized_end=2077
  _globals['_MSGSTAKETOGANGLIONRESPONSE']._serialized_start=2079
  _globals['_MSGSTAKETOGANGLIONRESPONSE']._serialized_end=2107
  _globals['_MSGCLAIMREWARD']._serialized_start=2109
  _globals['_MSGCLAIMREWARD']._serialized_end=2156
  _globals['_MSGCLAIMREWARDRESPONSE']._serialized_start=2158
  _globals['_MSGCLAIMREWARDRESPONSE']._serialized_end=2182
  _globals['_MSGUNSTAKEFROMGANGLION']._serialized_start=2184
  _globals['_MSGUNSTAKEFROMGANGLION']._serialized_end=2255
  _globals['_MSGUNSTAKEFROMGANGLIONRESPONSE']._serialized_start=2257
  _globals['_MSGUNSTAKEFROMGANGLIONRESPONSE']._serialized_end=2289
  _globals['_MSGUPDATEPATHWAY']._serialized_start=2292
  _globals['_MSGUPDATEPATHWAY']._serialized_end=2448
  _globals['_MSGUPDATEPATHWAYRESPONSE']._serialized_start=2450
  _globals['_MSGUPDATEPATHWAYRESPONSE']._serialized_end=2476
  _globals['_MSGREMOVEION']._serialized_start=2478
  _globals['_MSGREMOVEION']._serialized_end=2523
  _globals['_MSGREMOVEIONRESPONSE']._serialized_start=2525
  _globals['_MSGREMOVEIONRESPONSE']._serialized_end=2547
  _globals['_MSGREMOVEPATHWAY']._serialized_start=2549
  _globals['_MSGREMOVEPATHWAY']._serialized_end=2610
  _globals['_MSGREMOVEPATHWAYRESPONSE']._serialized_start=2612
  _globals['_MSGREMOVEPATHWAYRESPONSE']._serialized_end=2638
  _globals['_MSGSETALLOWEDIPS']._serialized_start=2640
  _globals['_MSGSETALLOWEDIPS']._serialized_end=2702
  _globals['_MSGSETALLOWEDIPSRESPONSE']._serialized_start=2704
  _globals['_MSGSETALLOWEDIPSRESPONSE']._serialized_end=2730
  _globals['_MSG']._serialized_start=2733
  _globals['_MSG']._serialized_end=4811
# @@protoc_insertion_point(module_scope)
