# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from neurion.fusion import params_pb2 as neurion_dot_fusion_dot_params__pb2
from neurion.fusion import task_pb2 as neurion_dot_fusion_dot_task__pb2
from neurion.fusion import creator_application_pb2 as neurion_dot_fusion_dot_creator__application__pb2
from neurion.fusion import proposed_model_pb2 as neurion_dot_fusion_dot_proposed__model__pb2
from neurion.fusion import validation_task_pb2 as neurion_dot_fusion_dot_validation__task__pb2
from neurion.fusion import dispute_validation_task_pb2 as neurion_dot_fusion_dot_dispute__validation__task__pb2
from neurion.fusion import error_code_pb2 as neurion_dot_fusion_dot_error__code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aneurion/fusion/query.proto\x12\x0eneurion.fusion\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bneurion/fusion/params.proto\x1a\x19neurion/fusion/task.proto\x1a(neurion/fusion/creator_application.proto\x1a#neurion/fusion/proposed_model.proto\x1a$neurion/fusion/validation_task.proto\x1a,neurion/fusion/dispute_validation_task.proto\x1a\x1fneurion/fusion/error_code.proto\"\x14\n\x12QueryParamsRequest\"H\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x16.neurion.fusion.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"&\n\x13QueryGetTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\"E\n\x14QueryGetTaskResponse\x12-\n\x04task\x18\x01 \x01(\x0b\x32\x14.neurion.fusion.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\":\n\x19QueryGetTaskRewardRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\",\n\x1aQueryGetTaskRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"5\n\"QueryGetCreatorApplicationsRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\"h\n#QueryGetCreatorApplicationsResponse\x12\x41\n\napplicants\x18\x01 \x03(\x0b\x32\".neurion.fusion.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"+\n)QueryGetPendingCreatorApplicationsRequest\"o\n*QueryGetPendingCreatorApplicationsResponse\x12\x41\n\napplicants\x18\x01 \x03(\x0b\x32\".neurion.fusion.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\">\n\x1cQueryGetModelsByRoundRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\r\n\x05round\x18\x02 \x01(\x04\"Y\n\x1dQueryGetModelsByRoundResponse\x12\x38\n\x06models\x18\x01 \x03(\x0b\x32\x1d.neurion.fusion.ProposedModelB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"9\n\x18QueryGetTaskStakeRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\"*\n\x19QueryGetTaskStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\"+\n\x1dQueryGetValidationTaskRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"d\n\x1eQueryGetValidationTaskResponse\x12\x42\n\x0fvalidation_task\x18\x01 \x01(\x0b\x32\x1e.neurion.fusion.ValidationTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"U\n%QueryCanTriggerTestingForRoundRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\r\n\x05round\x18\x03 \x01(\x04\"c\n&QueryCanTriggerTestingForRoundResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"L\n\x1cQueryCanStartNewRoundRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\r\n\x05round\x18\x03 \x01(\x04\"Z\n\x1dQueryCanStartNewRoundResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"B\n!QueryCanRegisterAsProposerRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"_\n\"QueryCanRegisterAsProposerResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"C\n\"QueryCanRegisterAsValidatorRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"`\n#QueryCanRegisterAsValidatorResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"7\n\x16QueryIsProposerRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"T\n\x17QueryIsProposerResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"8\n\x17QueryIsValidatorRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"U\n\x18QueryIsValidatorResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"K\n\x1bQueryCanProposeModelRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\r\n\x05round\x18\x03 \x01(\x04\"Y\n\x1cQueryCanProposeModelResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"T\n$QueryCanRequestValidationTaskRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\r\n\x05round\x18\x03 \x01(\x04\"b\n%QueryCanRequestValidationTaskResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"F\n%QueryGetPendingValidationTasksRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"m\n&QueryGetPendingValidationTasksResponse\x12\x43\n\x10validation_tasks\x18\x01 \x03(\x0b\x32\x1e.neurion.fusion.ValidationTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"<\n\x18QueryCanTerminateRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\"V\n\x19QueryCanTerminateResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x06reason\x18\x02 \x01(\x0e\x32\x19.neurion.fusion.ErrorCode\"3\n#QueryGetScoreDisputeFromUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"z\n$QueryGetScoreDisputeFromUserResponse\x12R\n\x18\x64ispute_validation_tasks\x18\x01 \x03(\x0b\x32%.neurion.fusion.DisputeValidationTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32\xbe\x1a\n\x05Query\x12q\n\x06Params\x12\".neurion.fusion.QueryParamsRequest\x1a#.neurion.fusion.QueryParamsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/neurion/fusion/params\x12\x80\x01\n\x07GetTask\x12#.neurion.fusion.QueryGetTaskRequest\x1a$.neurion.fusion.QueryGetTaskResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/neurion/fusion/get_task/{task_id}\x12\xa0\x01\n\rGetTaskReward\x12).neurion.fusion.QueryGetTaskRewardRequest\x1a*.neurion.fusion.QueryGetTaskRewardResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/neurion/fusion/get_task_reward/{task_id}/{user}\x12\xbd\x01\n\x16GetCreatorApplications\x12\x32.neurion.fusion.QueryGetCreatorApplicationsRequest\x1a\x33.neurion.fusion.QueryGetCreatorApplicationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/fusion/get_creator_applications/{creator}\x12\xd0\x01\n\x1dGetPendingCreatorApplications\x12\x39.neurion.fusion.QueryGetPendingCreatorApplicationsRequest\x1a:.neurion.fusion.QueryGetPendingCreatorApplicationsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/neurion/fusion/get_pending_creator_applications\x12\xae\x01\n\x10GetModelsByRound\x12,.neurion.fusion.QueryGetModelsByRoundRequest\x1a-.neurion.fusion.QueryGetModelsByRoundResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/neurion/fusion/get_models_by_round/{task_id}/{round}\x12\x9c\x01\n\x0cGetTaskStake\x12(.neurion.fusion.QueryGetTaskStakeRequest\x1a).neurion.fusion.QueryGetTaskStakeResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//neurion/fusion/get_task_stake/{task_id}/{user}\x12\xa4\x01\n\x11GetValidationTask\x12-.neurion.fusion.QueryGetValidationTaskRequest\x1a..neurion.fusion.QueryGetValidationTaskResponse\"0\x82\xd3\xe4\x93\x02*\x12(/neurion/fusion/get_validation_task/{id}\x12\xda\x01\n\x19\x43\x61nTriggerTestingForRound\x12\x35.neurion.fusion.QueryCanTriggerTestingForRoundRequest\x1a\x36.neurion.fusion.QueryCanTriggerTestingForRoundResponse\"N\x82\xd3\xe4\x93\x02H\x12\x46/neurion/fusion/can_trigger_testing_for_round/{user}/{task_id}/{round}\x12\xb5\x01\n\x10\x43\x61nStartNewRound\x12,.neurion.fusion.QueryCanStartNewRoundRequest\x1a-.neurion.fusion.QueryCanStartNewRoundResponse\"D\x82\xd3\xe4\x93\x02>\x12</neurion/fusion/can_start_new_round/{user}/{task_id}/{round}\x12\xc1\x01\n\x15\x43\x61nRegisterAsProposer\x12\x31.neurion.fusion.QueryCanRegisterAsProposerRequest\x1a\x32.neurion.fusion.QueryCanRegisterAsProposerResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/neurion/fusion/can_register_as_proposer/{user}/{task_id}\x12\xc5\x01\n\x16\x43\x61nRegisterAsValidator\x12\x32.neurion.fusion.QueryCanRegisterAsValidatorRequest\x1a\x33.neurion.fusion.QueryCanRegisterAsValidatorResponse\"B\x82\xd3\xe4\x93\x02<\x12:/neurion/fusion/can_register_as_validator/{user}/{task_id}\x12\x93\x01\n\nIsProposer\x12&.neurion.fusion.QueryIsProposerRequest\x1a\'.neurion.fusion.QueryIsProposerResponse\"4\x82\xd3\xe4\x93\x02.\x12,/neurion/fusion/is_proposer/{user}/{task_id}\x12\x97\x01\n\x0bIsValidator\x12\'.neurion.fusion.QueryIsValidatorRequest\x1a(.neurion.fusion.QueryIsValidatorResponse\"5\x82\xd3\xe4\x93\x02/\x12-/neurion/fusion/is_validator/{user}/{task_id}\x12\xb0\x01\n\x0f\x43\x61nProposeModel\x12+.neurion.fusion.QueryCanProposeModelRequest\x1a,.neurion.fusion.QueryCanProposeModelResponse\"B\x82\xd3\xe4\x93\x02<\x12:/neurion/fusion/can_propose_model/{user}/{task_id}/{round}\x12\xd5\x01\n\x18\x43\x61nRequestValidationTask\x12\x34.neurion.fusion.QueryCanRequestValidationTaskRequest\x1a\x35.neurion.fusion.QueryCanRequestValidationTaskResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/neurion/fusion/can_request_validation_task/{user}/{task_id}/{round}\x12\xd1\x01\n\x19GetPendingValidationTasks\x12\x35.neurion.fusion.QueryGetPendingValidationTasksRequest\x1a\x36.neurion.fusion.QueryGetPendingValidationTasksResponse\"E\x82\xd3\xe4\x93\x02?\x12=/neurion/fusion/get_pending_validation_tasks/{user}/{task_id}\x12\x9e\x01\n\x0c\x43\x61nTerminate\x12(.neurion.fusion.QueryCanTerminateRequest\x1a).neurion.fusion.QueryCanTerminateResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/neurion/fusion/can_terminate/{creator}/{task_id}\x12\xc0\x01\n\x17GetScoreDisputeFromUser\x12\x33.neurion.fusion.QueryGetScoreDisputeFromUserRequest\x1a\x34.neurion.fusion.QueryGetScoreDisputeFromUserResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/fusion/get_score_dispute_from_user/{user}B\x18Z\x16neurion/x/fusion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\026neurion/x/fusion/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._loaded_options = None
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._loaded_options = None
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETMODELSBYROUNDRESPONSE'].fields_by_name['models']._loaded_options = None
  _globals['_QUERYGETMODELSBYROUNDRESPONSE'].fields_by_name['models']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETVALIDATIONTASKRESPONSE'].fields_by_name['validation_task']._loaded_options = None
  _globals['_QUERYGETVALIDATIONTASKRESPONSE'].fields_by_name['validation_task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGVALIDATIONTASKSRESPONSE'].fields_by_name['validation_tasks']._loaded_options = None
  _globals['_QUERYGETPENDINGVALIDATIONTASKSRESPONSE'].fields_by_name['validation_tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE'].fields_by_name['dispute_validation_tasks']._loaded_options = None
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE'].fields_by_name['dispute_validation_tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\030\022\026/neurion/fusion/params'
  _globals['_QUERY'].methods_by_name['GetTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTask']._serialized_options = b'\202\323\344\223\002$\022\"/neurion/fusion/get_task/{task_id}'
  _globals['_QUERY'].methods_by_name['GetTaskReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskReward']._serialized_options = b'\202\323\344\223\0022\0220/neurion/fusion/get_task_reward/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetCreatorApplications']._serialized_options = b'\202\323\344\223\0024\0222/neurion/fusion/get_creator_applications/{creator}'
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._serialized_options = b'\202\323\344\223\0022\0220/neurion/fusion/get_pending_creator_applications'
  _globals['_QUERY'].methods_by_name['GetModelsByRound']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetModelsByRound']._serialized_options = b'\202\323\344\223\0027\0225/neurion/fusion/get_models_by_round/{task_id}/{round}'
  _globals['_QUERY'].methods_by_name['GetTaskStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskStake']._serialized_options = b'\202\323\344\223\0021\022//neurion/fusion/get_task_stake/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetValidationTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetValidationTask']._serialized_options = b'\202\323\344\223\002*\022(/neurion/fusion/get_validation_task/{id}'
  _globals['_QUERY'].methods_by_name['CanTriggerTestingForRound']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanTriggerTestingForRound']._serialized_options = b'\202\323\344\223\002H\022F/neurion/fusion/can_trigger_testing_for_round/{user}/{task_id}/{round}'
  _globals['_QUERY'].methods_by_name['CanStartNewRound']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanStartNewRound']._serialized_options = b'\202\323\344\223\002>\022</neurion/fusion/can_start_new_round/{user}/{task_id}/{round}'
  _globals['_QUERY'].methods_by_name['CanRegisterAsProposer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanRegisterAsProposer']._serialized_options = b'\202\323\344\223\002;\0229/neurion/fusion/can_register_as_proposer/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanRegisterAsValidator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanRegisterAsValidator']._serialized_options = b'\202\323\344\223\002<\022:/neurion/fusion/can_register_as_validator/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['IsProposer']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IsProposer']._serialized_options = b'\202\323\344\223\002.\022,/neurion/fusion/is_proposer/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['IsValidator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IsValidator']._serialized_options = b'\202\323\344\223\002/\022-/neurion/fusion/is_validator/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanProposeModel']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanProposeModel']._serialized_options = b'\202\323\344\223\002<\022:/neurion/fusion/can_propose_model/{user}/{task_id}/{round}'
  _globals['_QUERY'].methods_by_name['CanRequestValidationTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanRequestValidationTask']._serialized_options = b'\202\323\344\223\002F\022D/neurion/fusion/can_request_validation_task/{user}/{task_id}/{round}'
  _globals['_QUERY'].methods_by_name['GetPendingValidationTasks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingValidationTasks']._serialized_options = b'\202\323\344\223\002?\022=/neurion/fusion/get_pending_validation_tasks/{user}/{task_id}'
  _globals['_QUERY'].methods_by_name['CanTerminate']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CanTerminate']._serialized_options = b'\202\323\344\223\0023\0221/neurion/fusion/can_terminate/{creator}/{task_id}'
  _globals['_QUERY'].methods_by_name['GetScoreDisputeFromUser']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetScoreDisputeFromUser']._serialized_options = b'\202\323\344\223\0024\0222/neurion/fusion/get_score_dispute_from_user/{user}'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=369
  _globals['_QUERYPARAMSREQUEST']._serialized_end=389
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=391
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=463
  _globals['_QUERYGETTASKREQUEST']._serialized_start=465
  _globals['_QUERYGETTASKREQUEST']._serialized_end=503
  _globals['_QUERYGETTASKRESPONSE']._serialized_start=505
  _globals['_QUERYGETTASKRESPONSE']._serialized_end=574
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_start=576
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_end=634
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_start=636
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_end=680
  _globals['_QUERYGETCREATORAPPLICATIONSREQUEST']._serialized_start=682
  _globals['_QUERYGETCREATORAPPLICATIONSREQUEST']._serialized_end=735
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE']._serialized_start=737
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE']._serialized_end=841
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_start=843
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_end=886
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_start=888
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_end=999
  _globals['_QUERYGETMODELSBYROUNDREQUEST']._serialized_start=1001
  _globals['_QUERYGETMODELSBYROUNDREQUEST']._serialized_end=1063
  _globals['_QUERYGETMODELSBYROUNDRESPONSE']._serialized_start=1065
  _globals['_QUERYGETMODELSBYROUNDRESPONSE']._serialized_end=1154
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_start=1156
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_end=1213
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_start=1215
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_end=1257
  _globals['_QUERYGETVALIDATIONTASKREQUEST']._serialized_start=1259
  _globals['_QUERYGETVALIDATIONTASKREQUEST']._serialized_end=1302
  _globals['_QUERYGETVALIDATIONTASKRESPONSE']._serialized_start=1304
  _globals['_QUERYGETVALIDATIONTASKRESPONSE']._serialized_end=1404
  _globals['_QUERYCANTRIGGERTESTINGFORROUNDREQUEST']._serialized_start=1406
  _globals['_QUERYCANTRIGGERTESTINGFORROUNDREQUEST']._serialized_end=1491
  _globals['_QUERYCANTRIGGERTESTINGFORROUNDRESPONSE']._serialized_start=1493
  _globals['_QUERYCANTRIGGERTESTINGFORROUNDRESPONSE']._serialized_end=1592
  _globals['_QUERYCANSTARTNEWROUNDREQUEST']._serialized_start=1594
  _globals['_QUERYCANSTARTNEWROUNDREQUEST']._serialized_end=1670
  _globals['_QUERYCANSTARTNEWROUNDRESPONSE']._serialized_start=1672
  _globals['_QUERYCANSTARTNEWROUNDRESPONSE']._serialized_end=1762
  _globals['_QUERYCANREGISTERASPROPOSERREQUEST']._serialized_start=1764
  _globals['_QUERYCANREGISTERASPROPOSERREQUEST']._serialized_end=1830
  _globals['_QUERYCANREGISTERASPROPOSERRESPONSE']._serialized_start=1832
  _globals['_QUERYCANREGISTERASPROPOSERRESPONSE']._serialized_end=1927
  _globals['_QUERYCANREGISTERASVALIDATORREQUEST']._serialized_start=1929
  _globals['_QUERYCANREGISTERASVALIDATORREQUEST']._serialized_end=1996
  _globals['_QUERYCANREGISTERASVALIDATORRESPONSE']._serialized_start=1998
  _globals['_QUERYCANREGISTERASVALIDATORRESPONSE']._serialized_end=2094
  _globals['_QUERYISPROPOSERREQUEST']._serialized_start=2096
  _globals['_QUERYISPROPOSERREQUEST']._serialized_end=2151
  _globals['_QUERYISPROPOSERRESPONSE']._serialized_start=2153
  _globals['_QUERYISPROPOSERRESPONSE']._serialized_end=2237
  _globals['_QUERYISVALIDATORREQUEST']._serialized_start=2239
  _globals['_QUERYISVALIDATORREQUEST']._serialized_end=2295
  _globals['_QUERYISVALIDATORRESPONSE']._serialized_start=2297
  _globals['_QUERYISVALIDATORRESPONSE']._serialized_end=2382
  _globals['_QUERYCANPROPOSEMODELREQUEST']._serialized_start=2384
  _globals['_QUERYCANPROPOSEMODELREQUEST']._serialized_end=2459
  _globals['_QUERYCANPROPOSEMODELRESPONSE']._serialized_start=2461
  _globals['_QUERYCANPROPOSEMODELRESPONSE']._serialized_end=2550
  _globals['_QUERYCANREQUESTVALIDATIONTASKREQUEST']._serialized_start=2552
  _globals['_QUERYCANREQUESTVALIDATIONTASKREQUEST']._serialized_end=2636
  _globals['_QUERYCANREQUESTVALIDATIONTASKRESPONSE']._serialized_start=2638
  _globals['_QUERYCANREQUESTVALIDATIONTASKRESPONSE']._serialized_end=2736
  _globals['_QUERYGETPENDINGVALIDATIONTASKSREQUEST']._serialized_start=2738
  _globals['_QUERYGETPENDINGVALIDATIONTASKSREQUEST']._serialized_end=2808
  _globals['_QUERYGETPENDINGVALIDATIONTASKSRESPONSE']._serialized_start=2810
  _globals['_QUERYGETPENDINGVALIDATIONTASKSRESPONSE']._serialized_end=2919
  _globals['_QUERYCANTERMINATEREQUEST']._serialized_start=2921
  _globals['_QUERYCANTERMINATEREQUEST']._serialized_end=2981
  _globals['_QUERYCANTERMINATERESPONSE']._serialized_start=2983
  _globals['_QUERYCANTERMINATERESPONSE']._serialized_end=3069
  _globals['_QUERYGETSCOREDISPUTEFROMUSERREQUEST']._serialized_start=3071
  _globals['_QUERYGETSCOREDISPUTEFROMUSERREQUEST']._serialized_end=3122
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE']._serialized_start=3124
  _globals['_QUERYGETSCOREDISPUTEFROMUSERRESPONSE']._serialized_end=3246
  _globals['_QUERY']._serialized_start=3249
  _globals['_QUERY']._serialized_end=6639
# @@protoc_insertion_point(module_scope)
